clear all;
close all;
clc;
clear global;

%global bet sig th rho alp TPLL TPLH TPHL TPHH TP zeta muL muH xib ns del Tr L nx n1 n0 sde nL eta0 eta1 etaL ...
%    v m N1 NE NL N0 PsiT Psi00 Psi10 PsiL0 Psi01 Psi11 PsiL1 di V R lam C  KE KL K0 K1 PH PF D EXN YN gam Iv W...
%    f0 f1 fE K P00 P01 P10 P11 PL0 PL1 PLL PE LE LL L0 L1 Lp...
%    YLL YL0 YL1 Y00 Y01 Y10 Y11 YE VE VL V0 V1 Edisadv XOP;        
%%  Parameter Values 
bet  = 0.96;          % time preference: real interest rate = 1 - 1/beta 
sig  = 2;             % CRRA coefficient 
th   = 6;             % Elasticity of demand across variety
rho  = 4;           % Elasticity of Substitution between Home and Foreign
alp  = 0.34;             % capital share 

TPLL = 0.8;
TPHH = 1.0;
TPLH = 1-TPLL;
TPHL = 1-TPHH;
TP = [TPLL, 1-TPLL; 1-TPHH, TPHH]; % Transition probability of mu  PLH = from L to H 
corrz = 0.25;
sdz = 0.013;
rhoz = 0.95^4;

zeta = 6;  % Pareto slope   output slope = zeta/(th-1)
muL = 1; % Low productivity 
muH = 1; % High productivity

xib  = 0.0001; % Bond cost parameter

ns  = 1-0.054;  % Survival rate

del  = 0.1;             % capital depreciation rate 
Tr   = 0.15;             % Steady state IM/Y ratio 
L    = 1/3;              % Steady state Labor supply 

nx   = 0.21;            % exporter ratio 
n1   = 0.17;          % 1-stopper rate: in simulations we re-define it to be stopper rate: 1-n_1  
Edisadv = 0.5;  % Entrants disadvantage
XOP   =  1.03; % Exporter premium

% To be corrected
n0   = nx*(1-ns*n1)/(1-ns*nx);  % starter rate: To be corrected
n0 = 0.9;
sde  = 0.4482;          %  SD of firm specific shocks: To be corrected
nL  = 0.999;  % starter rate of low mu: To be corrected

eta0 = norminv(n0,0,sde);  % marginal entrance productivity 
eta1 = norminv(n1,0,sde);  %  marginal exit productivity 
etaL = norminv(nL,0,sde);  %  marginal exit productivity 

v = 1/(1+alp*(th-1));
m = v*(th-1);

% ---- Integration ----
PsiT = exp(m^2*sde^2/2);
Psi00 = PsiT*normcdf(eta0,m*sde^2,sde);
Psi10 = PsiT*normcdf(eta1,m*sde^2,sde);
PsiL0 = PsiT*normcdf(etaL,m*sde^2,sde);
Psi01 = PsiT*(1-normcdf(eta0,m*sde^2,sde));
Psi11 = PsiT*(1-normcdf(eta1,m*sde^2,sde));
PsiL1 = PsiT*(1-normcdf(etaL,m*sde^2,sde));

di   = 1e-14;             % convergence tolerence


%% ================================================================================
%   Steady State Computation 
%  ================================================================================

V = bet;
R = 1/bet - 1 + del;

N =1;
NE  =  (1-ns)/ns;
NL  = ns*NE*ns*TPLL/(1-TPLL*ns);
N1 = nx;
N0 = N-NL-N1-ns*NE;


%---- Initial Values indm=1

KE    = 0.5;
KL    = 0.5;
K0    = 0.8;
K1    = 3;

eta0 = norminv(n0,0,sde);  % marginal entrance productivity 
eta1 = norminv(n1,0,sde);  %  marginal exit productivity 
etaL = norminv(nL,0,sde);  %  marginal exit productivity 

f0    = 0.1;
f1    = 0.03;
fE    = 0.7;

muL   = 0.95;
sde   = 0.5;


C    = 0.470; 
PH   = 1; 
PF   = 1;
gam  = 0.6;
lam = 0.3;

VE = 1;
VL = 0.1;
V0 = 0.1;
V1 = 1;

% --- Steady State Computation 



xpar = [bet, sig, th, rho, alp,    TPLL, TPLH, TPHL, TPHH, zeta,      muH, ns, del, Tr, L,     nx, n1, eta1, ...
        v, m,      N1, NE, NL, N0, Edisadv, XOP];  % parameters used in SteadyS 
save xpar;
    %x0= log([KE; KL; K0; K1; C;     gam; lam; PH; PF; exp(etaL);     exp(eta0); f0; f1; fE; VE;    VL; V0; V1; muL; sde]);
x0= log([KE; KL; K0; K1; C;     gam; lam; PH; PF; exp(etaL);     exp(eta0); f0; f1; fE; VE;    VL; V0; V1; muL; sde]);

 load x; 
 x0 =x;

options = optimoptions('fsolve','Display','iter','MaxFunctionEvaluations',10000);
[x,fval] = fsolve(@SS_M01,x0,options,xpar);
    
NE  =  (1-ns)/ns;
NL  = ns*NE*ns*TPLL/(1-TPLL*ns);
N1 = nx;
N0 = 1-NL-N1-ns*NE; 

KE    = exp(x(1));
KL    = exp(x(2));
K0    = exp(x(3));
K1    = exp(x(4));

C     = exp(x(5)); 
gam   = exp(x(6));
lam   = exp(x(7));
PH    = exp(x(8));
PF    = exp(x(9));

etaL  = x(10);
eta0  = x(11);

f0    = exp(x(12));
f1    = exp(x(13));
fE    = exp(x(14));

VE    = exp(x(15));
VL    = exp(x(16));
V0    = exp(x(17));
V1    = exp(x(18));

muL   = exp(x(19));
sde   = exp(x(20));

v = 1/(1+alp*(th-1));
m = v*(th-1);

eta1 = norminv(n1,0,sde);  %  marginal exit productivity 

PsiT = exp(m^2*sde^2/2);
Psi00 = PsiT*normcdf(eta0,m*sde^2,sde);
Psi10 = PsiT*normcdf(eta1,m*sde^2,sde);
PsiL0 = PsiT*normcdf(etaL,m*sde^2,sde);
Psi01 = PsiT*(1-normcdf(eta0,m*sde^2,sde));
Psi11 = PsiT*(1-normcdf(eta1,m*sde^2,sde));
PsiL1 = PsiT*(1-normcdf(etaL,m*sde^2,sde));

nL = normcdf(etaL,0,sde);
n0 = normcdf(eta0,0,sde);
n1 = normcdf(eta1,0,sde);

K = NE*KE+NL*KL+N0*K0+N1*K1;
Iv  = ns*del*K;

D = C+Iv;
W = (1-gam)/gam*C/(1-L);

P00 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*K0^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*Psi00*ns*N0 )^(1/(1-th));
P01 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*K0^(1-v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^(v-1)*Psi01*ns*N0 )^(1/(1-th));
P10 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*K1^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*Psi10*ns*N1 )^(1/(1-th));
P11 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*K1^(1-v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^(v-1)*Psi11*ns*N1 )^(1/(1-th));
PL0 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*KL^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*PsiL0*ns*NL*TPLH )^(1/(1-th));
PL1 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*KL^(1-v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^(v-1)*PsiL1*ns*NL*TPLH )^(1/(1-th));
PLL = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muL^(v*(th-1))*KL^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*PsiT*ns*NL*TPLL )^(1/(1-th));
PE0 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*KL^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*PsiL0*ns*ns*NE*TPLH )^(1/(1-th));
PE1 = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muH^(v*(th-1))*KL^(1-v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^(v-1)*PsiL1*ns*ns*NE*TPLH )^(1/(1-th));
PEL = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muL^(v*(th-1))*KL^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*PsiT*ns*ns*NE*TPLL )^(1/(1-th));
PE  = ( (th/(th-1)/(1-alp)*W)^(1-th*v)*muL^(v*(th-1))*KE^(1-v)*( lam^rho*PH^(th-rho)*D )^(v-1)*PsiT*ns*NE )^(1/(1-th));



LE = PsiT*muL^((th-1)*v)*KE^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)*( lam^rho*PH^(th-rho)*D )^v;
LL = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)*( TPLL*muL^(v*(th-1))*( lam^rho*PH^(th-rho)*D )^v*PsiT ...
    + TPLH*muH^(v*(th-1))*( ( lam^rho*PH^(th-rho)*D )^v*PsiL0 + ( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*PsiL1 ) );
L0 = K0^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)*muH^(v*(th-1))*( ( lam^rho*PH^(th-rho)*D )^v*Psi00 + ( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*Psi01 );
L1 = K1^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)*muH^(v*(th-1))*( ( lam^rho*PH^(th-rho)*D )^v*Psi10 + ( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*Psi11 );

Lp = ns*(NE*LE + (ns*NE+NL)*LL + N0*L0 + N1*L1);


YLL = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*PsiT*TPLL*NL*ns*muL^((th-1)*v);
YL0 = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*PsiL0*TPLH*NL*ns*muH^((th-1)*v);
YL1 = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*PsiL1*TPLH*NL*ns*muH^((th-1)*v);
YEL = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*PsiT*TPLL*NE*ns*ns*muL^((th-1)*v);
YE0 = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*PsiL0*TPLH*NE*ns*ns*muH^((th-1)*v);
YE1 = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*PsiL1*TPLH*NE*ns*ns*muH^((th-1)*v);
Y00 = K0^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*Psi00*N0*ns*muH^((th-1)*v);
Y01 = K0^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*Psi01*N0*ns*muH^((th-1)*v);
Y10 = K1^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*Psi10*N1*ns*muH^((th-1)*v);
Y11 = K1^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*Psi11*N1*ns*muH^((th-1)*v);
YE  = KE^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( lam^rho*PH^(th-rho)*D )^v*PsiT*NE*ns*muL^((th-1)*v);

YL1X = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( (1-lam)^rho*PF^(th-rho)*D )^v*PsiL1*TPLH*NL*ns*muH^((th-1)*v);
YE1X = KL^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( (1-lam)^rho*PF^(th-rho)*D )^v*PsiL1*TPLH*NE*ns*ns*muH^((th-1)*v);
Y01X = K0^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( (1-lam)^rho*PF^(th-rho)*D )^v*Psi01*N0*ns*muH^((th-1)*v);
Y11X = K1^(1-v)*(th/(th-1)/(1-alp)*W)^(1-th*v)*( (1-lam)^rho*PF^(th-rho)*D )^v*Psi11*N1*ns*muH^((th-1)*v);

EXN = (1-lam)^rho*PF^(1-rho)*D;
YN = YE+YLL+YL0+YL1+Y00+Y01+Y10+Y11+YEL+YE0+YE1;


PH = ( P00^(1-th)+P01^(1-th)+P10^(1-th)+P11^(1-th)+PL0^(1-th)+PL1^(1-th)+PLL^(1-th)+PE0^(1-th)+PE1^(1-th)+PEL^(1-th)+PE^(1-th) )^(1/(1-th));

PF = ( P01^(1-th)+P11^(1-th)+PL1^(1-th)+PE1^(1-th) )^(1/(1-th));

VL = (th/(th-1)/(1-alp)-1)*W*KL^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)...
        *( TPLH*( ( lam^rho*PH^(th-rho)*D )^v*PsiL0 + ( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*PsiL1 )*muH^((th-1)*v) ...
          + TPLL*( lam^rho*PH^(th-rho)*D )^v*PsiT*muL^((th-1)*v) ) + (1-del)*KL ...
        +TPLH*( (1-ns)*bet*(nL*K0 + (1-nL)*K1) + ns*bet*(nL*V0+(1-nL)*V1)- nL*K0 - (1-nL)*K1 - (1-nL)*W*f0 )...
        +TPLL*( (1-ns)*bet*KL + ns*bet*VL - KL );
    
V0 = (th/(th-1)/(1-alp)-1)*W*K0^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)...
        *( ( lam^rho*PH^(th-rho)*D )^v*Psi00 + ( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*Psi01 )*muH^((th-1)*v) ...
        + (1-del)*K0 + (1-ns)*bet*(n0*K0 + (1-n0)*K1) + ns*bet*(n0*V0+(1-n0)*V1)- n0*K0 - (1-n0)*K1 - (1-n0)*W*f0;

V1 = (th/(th-1)/(1-alp)-1)*W*K1^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)...
        *( ( lam^rho*PH^(th-rho)*D )^v*Psi10 + ( lam^rho*PH^(th-rho)*D + (1-lam)^rho*PF^(th-rho)*D )^v*Psi11 )*muH^((th-1)*v) ...
        +(1-del)*K1 + (1-ns)*bet*(n1*K0 + (1-n1)*K1) + ns*bet*(n1*V0+(1-n1)*V1)- n1*K0 - (1-n1)*K1 - (1-n1)*W*f1;
    
VE = (th/(th-1)/(1-alp)-1)*W*KE^(1-v)*(th/(th-1)/(1-alp)*W)^(-th*v)*muL^((th-1)*v)*( lam^rho*PH^(th-rho)*D )^v*PsiT + (1-del)*KE - KL+(1-ns)*bet*KL + bet*ns*VL;

ed = YE/(YLL+YL0+YL1+Y00+Y01+Y10+Y11+YEL+YE0+YE1)*(1-ns*NE)/(ns*NE);

xp = log( (YL1+Y01+Y11+YE1)/(YE+YLL+YL0+Y00+Y10+YEL+YE0)*((1-N1)/N1) );

NN = ns*NE;
YR = YN/PH;
IMN = EXN;
EXR = EXN/PF;
IMR = EXR;
UC = gam*C^(gam*(1-sig)-1)*(1-L)^((1-gam)*(1-sig));
UL = (1-gam)*C^(gam*(1-sig))*(1-L)^((1-gam)*(1-sig)-1);
nstop = n1;
nstart= ( ns*(1-TPLL)*(NN+NL)*(1-nL) + ns*N0*(1-n0) )/(ns*( NN+NL+N0 ) );


YRh    =YR    ;
Ch     =C     ;
Ivh    =Iv    ;
Lh     =L     ;
Dh     =D     ;
KEh    =KE    ;
KLh    =KL    ;
K0h    =K0    ;
K1h    =K1    ;
Kh     =K     ;
LEh    =LE    ;
LLh    =LL    ;
L0h    =L0    ;
L1h    =L1    ;
Lph    =Lp    ;
etaLh  =etaL  ;
eta0h  =eta0  ;
eta1h  =eta1  ;
nLh    =nL    ;
n0h    =n0    ;
n1h    =n1    ;
NEh    =NE    ;
NNh    =NN    ;
NLh    =NL    ;
N0h    =N0    ;
N1h    =N1    ;
Nh     =N     ;
Wh     =W     ;
Ph     =PH    ;
Phs    =PF   ;
VEh    =VE    ;
VLh    =VL    ;
V0h    =V0    ;
V1h    =V1    ;
YNh    =YN    ;
UCh    =UC    ;
ULh    =UL    ;
nstoph =nstop ;
nstarth=nstart;
zh     =0     ;
YRf    =YR    ;
Cf     =C     ;
Ivf    =Iv    ;
Lf     =L     ;
Df     =D     ;
KEf    =KE    ;
KLf    =KL    ;
K0f    =K0    ;
K1f    =K1    ;
Kf     =K     ;
LEf    =LE    ;
LLf    =LL    ;
L0f    =L0    ;
L1f    =L1    ;
Lpf    =Lp    ;
etaLf  =etaL  ;
eta0f  =eta0  ;
eta1f  =eta1  ;
nLf    =nL    ;
n0f    =n0    ;
n1f    =n1    ;
NEf    =NE    ;
NNf    =NN    ;
NLf    =NL    ;
N0f    =N0    ;
N1f    =N1    ;
Nf     =N     ;
Wf     =W     ;
Pfs    =PH    ;
Pf     =PF   ;
VEf    =VE    ;
VLf    =VL    ;
V0f    =V0    ;
V1f    =V1    ;
YNf    =YN    ;
UCf    =UC    ;
ULf    =UL    ;
nstopf =nstop ;
nstartf=nstart;
zf      =0    ;
q      =1;
NXY    =0;


%paras = [bet sig th rho alp     gam lam TPLL log(muL) log(muH)      ns del sde v m      sdz corrz rhoz fE f0   f1 PsiT]; 
paras = [bet,sig,th,rho,alp,gam,lam,TPLL,log(muL),log(muH),ns,del,sde,v,m,sdz,corrz,rhoz,fE,f0,f1,PsiT];

xss   = log([YRh YRf Ch Cf Ivh Ivf Lh Lf Dh Df ...
         KEh KEf KLh KLf K0h K0f K1h K1f Kh Kf ...
         LEh LEf LLh LLf L0h L0f L1h L1f Lph Lpf...
         exp(etaLh) exp(etaLf) exp(eta0h) exp(eta0f) exp(eta1h) exp(eta1f) nLh nLf n0h n0f...
         n1h n1f NEh NEf NNh NNf NLh NLf N0h N0f...
         N1h N1f Nh Nf Wh Wf Ph Pfs Phs Pf ...
         VEh VEf VLh VLf V0h V0f V1h V1f YNh YNf...
         UCh UCf ULh ULf nstoph nstopf nstarth nstartf exp(zh) exp(zf) ...
         q exp(NXY) EXN IMN EXR IMR ]);
save paras;
save xss;

%[xtemp,fvaltemp] = fsolve(@TEMP_Check,xss,options,xpar);
%fvaltemp = TEMP_Check(xss);
%[(1:86)',fvaltemp]


dynare dynare_M01.mod;
