function [residual, g1, g2, g3] = dynare_M01_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(86, 1);
T25 = params(3)/(params(3)-1)/(1-params(5));
T38 = (T25*exp(y(77)))^(params(14)*(-params(3)));
T40 = (params(3)-1)*params(14);
T44 = (T25-1)*exp(y(77)+(1-params(14))*y(3))*T38*exp(T40*y(101));
T46 = 1-params(8);
T49 = exp(T40*params(10));
T50 = T46*T49;
T56 = params(15)*params(13)^2;
T57 = normcdf(y(53),T56,params(13));
T61 = params(7)^params(4);
T68 = T61*exp((params(3)-params(4))*y(79)+y(31));
T69 = T68^params(14);
T74 = (1-params(7))^params(4);
T85 = (T68+T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32)))^params(14);
T93 = params(22)*params(8)*exp(T40*params(9));
T95 = T50*(params(22)*T57*T69+params(22)*(1-T57)*T85)+T69*T93;
T109 = (1-params(11))*params(1)*exp(y(127)-y(93));
T122 = exp(y(127)-y(93))*params(11)*params(1);
T131 = T109*(exp(y(59)+y(37))+(1-exp(y(59)))*exp(y(39)))+T122*(exp(y(59))*exp(y(123))+(1-exp(y(59)))*exp(y(125)));
T164 = (T25*exp(y(78)))^(params(14)*(-params(3)));
T168 = (T25-1)*exp(y(78)+(1-params(14))*y(4))*T164*exp(T40*y(102));
T170 = normcdf(y(54),T56,params(13));
T176 = T61*exp(y(32)+(params(3)-params(4))*y(80));
T177 = T176^params(14);
T180 = params(22)*(1-T170);
T188 = T176+T74*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82));
T189 = T188^params(14);
T192 = T50*(params(22)*T170*T177+T180*T189);
T202 = (1-params(11))*params(1)*exp(y(128)-y(94));
T214 = params(11)*params(1)*exp(y(128)-y(94));
T223 = T202*(exp(y(60)+y(38))+(1-exp(y(60)))*exp(y(40)))+T214*(exp(y(60))*exp(y(124))+(1-exp(y(60)))*exp(y(126)));
T256 = exp(T40*(y(101)+params(10)));
T257 = T38*(T25-1)*exp(y(77)+(1-params(14))*y(5))*T256;
T259 = normcdf(y(55),T56,params(13));
T263 = params(22)*(1-T259);
T265 = T69*params(22)*T259+T85*T263;
T300 = exp(T40*(params(10)+y(102)));
T301 = T164*(T25-1)*exp(y(78)+(1-params(14))*y(6))*T300;
T303 = normcdf(y(56),T56,params(13));
T307 = params(22)*(1-T303);
T309 = T177*params(22)*T303+T189*T307;
T342 = T256*T38*(T25-1)*exp(y(77)+(1-params(14))*y(7));
T344 = normcdf(y(57),T56,params(13));
T348 = params(22)*(1-T344);
T350 = T69*params(22)*T344+T85*T348;
T384 = T300*T164*(T25-1)*exp(y(78)+(1-params(14))*y(8));
T386 = normcdf(y(58),T56,params(13));
T390 = params(22)*(1-T386);
T392 = T177*params(22)*T386+T189*T390;
T428 = T38*(T25-1)*exp(y(77)+(1-params(14))*y(1))*exp(T40*(y(101)+params(9)));
T449 = T164*(T25-1)*exp(y(78)+(1-params(14))*y(2))*exp(T40*(params(9)+y(102)));
T461 = exp(T40*y(101)+T40*params(10));
T462 = (T25-1)*exp(y(77)+(1-params(14))*y(3))*T38*T461;
T479 = exp(T40*params(10)+T40*y(102));
T480 = (T25-1)*exp(y(78)+(1-params(14))*y(4))*T164*T479;
T495 = T38*(T25-1)*exp(y(77)+(1-params(14))*y(5))*T461;
T504 = T164*(T25-1)*exp(y(78)+(1-params(14))*y(6))*T479;
T514 = T38*(T25-1)*exp(y(77)+(1-params(14))*y(7))*T461;
T524 = T164*(T25-1)*exp(y(78)+(1-params(14))*y(8))*T479;
T533 = params(1)*exp(y(127)-y(93));
T535 = params(11)*params(5)/(1-params(5));
T548 = params(1)*exp(y(128)-y(94));
T634 = (1-exp(y(29)))^((1-params(6))*(1-params(2))-1);
T645 = (1-exp(y(30)))^((1-params(6))*(1-params(2))-1);
T667 = exp(y(13))+exp(y(15));
T676 = exp(y(14))+exp(y(16));
T714 = (1-exp(y(59)))*T667*T46*params(11)+(1-exp(y(61)))*params(11)*exp(y(17));
T722 = (1-exp(y(60)))*T676*T46*params(11)+(1-exp(y(62)))*params(11)*exp(y(18));
T760 = T38*exp((1-params(14))*y(3)+T40*y(101));
T763 = T50*(params(22)*T57*T69+params(22)*(1-T57)*T85)+params(22)*T69*params(8)*exp(T40*params(9));
T770 = T164*exp((1-params(14))*y(4)+T40*y(102));
T781 = T49*T38*exp(T40*y(101)+(1-params(14))*y(5));
T789 = T49*T164*exp(T40*y(102)+(1-params(14))*y(6));
T797 = T49*T38*exp(T40*y(101)+(1-params(14))*y(7));
T805 = T49*T164*exp(T40*y(102)+(1-params(14))*y(8));
T847 = (T25*exp(y(77)))^(1-params(3)*params(14));
T848 = exp(T40*y(101))*T847;
T849 = T49*T848;
T851 = T849*exp((1-params(14))*y(5));
T853 = T68^(params(14)-1);
T859 = (T68+T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32)))^(params(14)-1);
T867 = T849*exp((1-params(14))*y(7));
T878 = (1-T344)*params(22)*exp(y(19))*params(11)*T859*T867;
T881 = T849*exp((1-params(14))*y(3));
T914 = (T25*exp(y(78)))^(1-params(3)*params(14));
T915 = exp(T40*y(102))*T914;
T916 = T49*T915;
T918 = T916*exp((1-params(14))*y(6));
T919 = T176^(params(14)-1);
T925 = T188^(params(14)-1);
T933 = T916*exp((1-params(14))*y(8));
T944 = (1-T386)*params(22)*exp(y(20))*params(11)*T925*T933;
T947 = T916*exp((1-params(14))*y(4));
T960 = T46*(1-T170)*params(22)*T676*params(11)*T925*T947;
T1012 = (1-exp(y(29)))^((1-params(6))*(1-params(2)));
T1019 = (1-exp(y(30)))^((1-params(6))*(1-params(2)));
lhs =y(77);
rhs =y(95)-y(93);
residual(1)= lhs-rhs;
lhs =y(78);
rhs =y(96)-y(94);
residual(2)= lhs-rhs;
lhs =exp(y(85));
rhs =T44*T95+(1-params(12))*exp(y(3))+T46*(T131-exp(y(59)+y(37))-(1-exp(y(59)))*exp(y(39))-(1-exp(y(59)))*exp(y(78)+y(103)-y(102))*params(20))+params(8)*(T109*exp(y(35))+T122*exp(y(121))-exp(y(35)));
residual(3)= lhs-rhs;
lhs =exp(y(86));
rhs =params(8)*(T202*exp(y(36))+T214*exp(y(122))-exp(y(36)))+T168*(T192+T93*T177)+(1-params(12))*exp(y(4))+T46*(T223-exp(y(60)+y(38))-(1-exp(y(60)))*exp(y(40))-params(20)*(1-exp(y(60)))*exp(y(77)-y(103)-y(101)));
residual(4)= lhs-rhs;
lhs =exp(y(87));
rhs =T257*T265+(1-params(12))*exp(y(5))+T109*(exp(y(37)+y(61))+exp(y(39))*(1-exp(y(61))))+T122*(exp(y(123))*exp(y(61))+exp(y(125))*(1-exp(y(61))))-exp(y(37)+y(61))-exp(y(39))*(1-exp(y(61)))-params(20)*exp(y(78)+y(103)-y(102))*(1-exp(y(61)));
residual(5)= lhs-rhs;
lhs =exp(y(88));
rhs =T301*T309+(1-params(12))*exp(y(6))+T202*(exp(y(38)+y(62))+exp(y(40))*(1-exp(y(62))))+T214*(exp(y(124))*exp(y(62))+exp(y(126))*(1-exp(y(62))))-exp(y(38)+y(62))-exp(y(40))*(1-exp(y(62)))-params(20)*(1-exp(y(62)))*exp(y(77)-y(103)-y(101));
residual(6)= lhs-rhs;
lhs =exp(y(89));
rhs =T342*T350+(1-params(12))*exp(y(7))+T109*(exp(y(37)+y(63))+exp(y(39))*(1-exp(y(63))))+T122*(exp(y(123))*exp(y(63))+exp(y(125))*(1-exp(y(63))))-exp(y(37)+y(63))-exp(y(39))*(1-exp(y(63)))-exp(y(78)+y(103)-y(102))*(1-exp(y(63)))*params(21);
residual(7)= lhs-rhs;
lhs =exp(y(90));
rhs =T384*T392+(1-params(12))*exp(y(8))+T202*(exp(y(38)+y(64))+exp(y(40))*(1-exp(y(64))))+T214*(exp(y(124))*exp(y(64))+exp(y(126))*(1-exp(y(64))))-exp(y(38)+y(64))-exp(y(40))*(1-exp(y(64)))-params(21)*(1-exp(y(64)))*exp(y(77)-y(103)-y(101));
residual(8)= lhs-rhs;
lhs =exp(y(83));
rhs =T122*exp(y(121))+T109*exp(y(35))+params(22)*T69*T428+(1-params(12))*exp(y(1))-exp(y(35));
residual(9)= lhs-rhs;
lhs =exp(y(84));
rhs =T214*exp(y(122))+T202*exp(y(36))+params(22)*T177*T449+(1-params(12))*exp(y(2))-exp(y(36));
residual(10)= lhs-rhs;
lhs =exp(y(78)+y(103)-y(102))*params(20);
rhs =T462*(T85-T69)*exp(T40*y(53))-(exp(y(39))-exp(y(37)))+T109*(exp(y(39))-exp(y(37)))+T122*(exp(y(125))-exp(y(123)));
residual(11)= lhs-rhs;
lhs =params(20)*exp(y(77)-y(103)-y(101));
rhs =T480*(T189-T177)*exp(T40*y(54))-(exp(y(40))-exp(y(38)))+T202*(exp(y(40))-exp(y(38)))+T214*(exp(y(126))-exp(y(124)));
residual(12)= lhs-rhs;
lhs =exp(y(78)+y(103)-y(102))*params(20);
rhs =T122*(exp(y(125))-exp(y(123)))+T109*(exp(y(39))-exp(y(37)))+(T85-T69)*T495*exp(T40*y(55))-(exp(y(39))-exp(y(37)));
residual(13)= lhs-rhs;
lhs =params(20)*exp(y(77)-y(103)-y(101));
rhs =T214*(exp(y(126))-exp(y(124)))+T202*(exp(y(40))-exp(y(38)))+(T189-T177)*T504*exp(T40*y(56))-(exp(y(40))-exp(y(38)));
residual(14)= lhs-rhs;
lhs =exp(y(78)+y(103)-y(102))*params(21);
rhs =T122*(exp(y(125))-exp(y(123)))+T109*(exp(y(39))-exp(y(37)))+(T85-T69)*T514*exp(T40*y(57))-(exp(y(39))-exp(y(37)));
residual(15)= lhs-rhs;
lhs =params(21)*exp(y(77)-y(103)-y(101));
rhs =T214*(exp(y(126))-exp(y(124)))+T202*(exp(y(40))-exp(y(38)))+(T189-T177)*T524*exp(T40*y(58))-(exp(y(40))-exp(y(38)));
residual(16)= lhs-rhs;
lhs =1;
rhs =T533*(T535*exp(y(117)+y(109)-y(33))+1-params(12)*params(11));
residual(17)= lhs-rhs;
lhs =1;
rhs =T548*(1-params(12)*params(11)+T535*exp(y(118)+y(110)-y(34)));
residual(18)= lhs-rhs;
lhs =1;
rhs =T533*(1-params(12)*params(11)+T535*exp(y(117)+y(111)-y(35)));
residual(19)= lhs-rhs;
lhs =1;
rhs =T548*(1-params(12)*params(11)+T535*exp(y(118)+y(112)-y(36)));
residual(20)= lhs-rhs;
lhs =1;
rhs =T533*(1-params(12)*params(11)+T535*exp(y(117)+y(113)-y(37)));
residual(21)= lhs-rhs;
lhs =1;
rhs =T548*(1-params(12)*params(11)+T535*exp(y(118)+y(114)-y(38)));
residual(22)= lhs-rhs;
lhs =1;
rhs =T533*(1-params(12)*params(11)+T535*exp(y(117)+y(115)-y(39)));
residual(23)= lhs-rhs;
lhs =1;
rhs =T548*(1-params(12)*params(11)+T535*exp(y(118)+y(116)-y(40)));
residual(24)= lhs-rhs;
lhs =exp(y(59));
rhs =normcdf(y(53),0,params(13));
residual(25)= lhs-rhs;
lhs =exp(y(60));
rhs =normcdf(y(54),0,params(13));
residual(26)= lhs-rhs;
lhs =exp(y(61));
rhs =normcdf(y(55),0,params(13));
residual(27)= lhs-rhs;
lhs =exp(y(62));
rhs =normcdf(y(56),0,params(13));
residual(28)= lhs-rhs;
lhs =exp(y(63));
rhs =normcdf(y(57),0,params(13));
residual(29)= lhs-rhs;
lhs =exp(y(64));
rhs =normcdf(y(58),0,params(13));
residual(30)= lhs-rhs;
lhs =exp(y(95));
rhs =(1-params(6))*exp(params(6)*(1-params(2))*y(25))*T634;
residual(31)= lhs-rhs;
lhs =exp(y(96));
rhs =(1-params(6))*exp(params(6)*(1-params(2))*y(26))*T645;
residual(32)= lhs-rhs;
lhs =exp(y(67));
rhs =params(11)*exp(y(11));
residual(33)= lhs-rhs;
lhs =exp(y(68));
rhs =params(11)*exp(y(12));
residual(34)= lhs-rhs;
lhs =exp(y(69));
rhs =params(8)*params(11)*T667;
residual(35)= lhs-rhs;
lhs =exp(y(70));
rhs =params(8)*params(11)*T676;
residual(36)= lhs-rhs;
lhs =exp(y(71));
rhs =exp(y(59))*T667*T46*params(11)+exp(y(61))*params(11)*exp(y(17))+exp(y(63))*params(11)*exp(y(19));
residual(37)= lhs-rhs;
lhs =exp(y(72));
rhs =exp(y(60))*T676*T46*params(11)+exp(y(62))*params(11)*exp(y(18))+exp(y(64))*params(11)*exp(y(20));
residual(38)= lhs-rhs;
lhs =exp(y(73));
rhs =T714+(1-exp(y(63)))*params(11)*exp(y(19));
residual(39)= lhs-rhs;
lhs =exp(y(74));
rhs =T722+(1-exp(y(64)))*params(11)*exp(y(20));
residual(40)= lhs-rhs;
lhs =exp(y(75));
rhs =exp(y(73))+exp(y(71))+exp(y(67))+exp(y(69));
residual(41)= lhs-rhs;
lhs =exp(y(76));
rhs =exp(y(74))+exp(y(72))+exp(y(68))+exp(y(70));
residual(42)= lhs-rhs;
lhs =exp(y(43));
rhs =T69*T38*params(22)*exp((1-params(14))*y(1)+T40*y(101)+T40*params(9));
residual(43)= lhs-rhs;
lhs =exp(y(44));
rhs =T177*T164*params(22)*exp((1-params(14))*y(2)+T40*params(9)+T40*y(102));
residual(44)= lhs-rhs;
lhs =exp(y(45));
rhs =T760*T763;
residual(45)= lhs-rhs;
lhs =exp(y(46));
rhs =T770*(T192+params(22)*params(8)*exp(T40*params(9))*T177);
residual(46)= lhs-rhs;
lhs =exp(y(47));
rhs =T265*T781;
residual(47)= lhs-rhs;
lhs =exp(y(48));
rhs =T309*T789;
residual(48)= lhs-rhs;
lhs =exp(y(49));
rhs =T350*T797;
residual(49)= lhs-rhs;
lhs =exp(y(50));
rhs =T392*T805;
residual(50)= lhs-rhs;
lhs =exp(y(51));
rhs =params(11)*exp(y(11)+y(43))+exp(y(45))*params(11)*T667+params(11)*exp(y(17)+y(47))+params(11)*exp(y(19)+y(49));
residual(51)= lhs-rhs;
lhs =exp(y(52));
rhs =params(11)*exp(y(12)+y(44))+exp(y(46))*params(11)*T676+params(11)*exp(y(18)+y(48))+params(11)*exp(y(20)+y(50));
residual(52)= lhs-rhs;
lhs =exp(y(79)*(1-params(3)));
rhs =T259*params(22)*exp(y(17))*params(11)*T851*T853+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T859+T344*params(22)*exp(y(19))*params(11)*T853*T867+T878+T46*T57*params(22)*T667*params(11)*T853*T881+T46*(1-T57)*params(22)*T667*params(11)*T859*T881+params(8)*params(22)*T667*params(11)*T853*exp((1-params(14))*y(3))*exp(T40*params(9))*T848+params(22)*exp(y(11))*params(11)*T853*exp(T40*params(9))*T848*exp((1-params(14))*y(1));
residual(53)= lhs-rhs;
lhs =exp(y(80)*(1-params(3)));
rhs =T303*params(22)*exp(y(18))*params(11)*T918*T919+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T925+T386*params(22)*exp(y(20))*params(11)*T919*T933+T944+T46*T170*params(22)*T676*params(11)*T919*T947+T960+params(8)*params(22)*T676*params(11)*T919*exp((1-params(14))*y(4))*exp(T40*params(9))*T915+params(22)*exp(y(12))*params(11)*T919*exp(T40*params(9))*T915*exp((1-params(14))*y(2));
residual(54)= lhs-rhs;
lhs =exp((1-params(3))*(y(103)+y(81)));
rhs =T46*(1-T57)*params(22)*T667*params(11)*T859*T881+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T859+T878;
residual(55)= lhs-rhs;
lhs =exp((1-params(3))*(y(82)-y(103)));
rhs =T960+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T925+T944;
residual(56)= lhs-rhs;
lhs =1;
rhs =T61*exp(y(79)*(1-params(4)))+T74*exp(y(82)*(1-params(4)));
residual(57)= lhs-rhs;
lhs =1;
rhs =T61*exp(y(80)*(1-params(4)))+T74*exp(y(81)*(1-params(4)));
residual(58)= lhs-rhs;
lhs =exp(y(93));
rhs =params(6)*exp(y(25)*(params(6)*(1-params(2))-1))*T1012;
residual(59)= lhs-rhs;
lhs =exp(y(94));
rhs =params(6)*exp(y(26)*(params(6)*(1-params(2))-1))*T1019;
residual(60)= lhs-rhs;
lhs =exp(y(91));
rhs =T25*exp(y(77)+y(51));
residual(61)= lhs-rhs;
lhs =exp(y(92));
rhs =T25*exp(y(78)+y(52));
residual(62)= lhs-rhs;
lhs =exp(y(23));
rhs =exp(y(91)-y(79));
residual(63)= lhs-rhs;
lhs =exp(y(24));
rhs =exp(y(92)-y(80));
residual(64)= lhs-rhs;
lhs =exp(y(31));
rhs =exp(y(25))+exp(y(27));
residual(65)= lhs-rhs;
lhs =exp(y(32));
rhs =exp(y(26))+exp(y(28));
residual(66)= lhs-rhs;
lhs =exp(y(27));
rhs =exp(y(41))-(1-params(12)*params(11))*exp(y(9));
residual(67)= lhs-rhs;
lhs =exp(y(28));
rhs =exp(y(42))-(1-params(12)*params(11))*exp(y(10));
residual(68)= lhs-rhs;
lhs =y(105);
rhs =y(103)+y(32)+y(81)*(1-params(4))+params(4)*log(1-params(7));
residual(69)= lhs-rhs;
lhs =y(106);
rhs =y(31)+y(82)*(1-params(4))+params(4)*log(1-params(7));
residual(70)= lhs-rhs;
lhs =y(104);
rhs =(exp(y(105))-exp(y(106)))/exp(y(91));
residual(71)= lhs-rhs;
lhs =y(103);
rhs =y(94)-y(93);
residual(72)= lhs-rhs;
lhs =y(107);
rhs =y(105)-(y(103)+y(81));
residual(73)= lhs-rhs;
lhs =y(108);
rhs =y(106)-y(82);
residual(74)= lhs-rhs;
lhs =y(101);
rhs =params(18)*y(21)+params(16)*x(it_, 1);
residual(75)= lhs-rhs;
lhs =y(102);
rhs =params(18)*y(22)+params(16)*x(it_, 2);
residual(76)= lhs-rhs;
lhs =exp(y(99));
rhs =T714/(params(11)*(T667+exp(y(17))));
residual(77)= lhs-rhs;
lhs =exp(y(100));
rhs =T722/(params(11)*(T676+exp(y(18))));
residual(78)= lhs-rhs;
lhs =y(97);
rhs =y(63);
residual(79)= lhs-rhs;
lhs =y(98);
rhs =y(64);
residual(80)= lhs-rhs;
lhs =exp(y(41));
rhs =exp(y(33)+y(65))+exp(y(35)+y(67))+exp(y(35)+y(69))+exp(y(37)+y(71))+exp(y(39)+y(73));
residual(81)= lhs-rhs;
lhs =exp(y(42));
rhs =exp(y(34)+y(66))+exp(y(36)+y(68))+exp(y(36)+y(70))+exp(y(38)+y(72))+exp(y(40)+y(74));
residual(82)= lhs-rhs;
lhs =exp(y(77)-y(101))*params(19);
rhs =(-exp(y(33)))+params(11)*params(1)*exp(y(127)-y(93)+y(119))+(1-params(11))*params(1)*exp(y(127)-y(93)+y(33));
residual(83)= lhs-rhs;
lhs =params(19)*exp(y(78)-y(102));
rhs =(-exp(y(34)))+params(11)*params(1)*exp(y(128)-y(94)+y(120))+(1-params(11))*params(1)*exp(y(128)-y(94)+y(34));
residual(84)= lhs-rhs;
lhs =exp(y(29));
rhs =exp(y(51))+(1-exp(y(60)))*T676*T46*params(11)*params(20)*exp((-y(102)))+(1-exp(y(62)))*exp(y(18))*params(11)*params(20)*exp((-y(102)))+(1-exp(y(64)))*exp(y(20))*params(11)*params(21)*exp((-y(102)))+params(19)*exp((-y(101)))*exp(y(65));
residual(85)= lhs-rhs;
lhs =exp(y(30));
rhs =exp(y(52))+(1-exp(y(59)))*T667*T46*params(11)*params(20)*exp((-y(101)))+(1-exp(y(61)))*exp(y(17))*params(11)*params(20)*exp((-y(101)))+(1-exp(y(63)))*exp(y(19))*params(11)*params(21)*exp((-y(101)))+params(19)*exp((-y(102)))*exp(y(66));
residual(86)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(86, 130);

  %
  % Jacobian matrix
  %

T1291 = getPowerDeriv(T68,params(14),1);
T1292 = T68*T1291;
T1294 = getPowerDeriv(T68+T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32)),params(14),1);
T1303 = getPowerDeriv(T188,params(14),1);
T1304 = T74*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82))*T1303;
T1364 = getPowerDeriv(T68,params(14)-1,1);
T1365 = T68*T1364;
T1371 = getPowerDeriv(T68+T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32)),params(14)-1,1);
T1372 = T68*T1371;
T1417 = getPowerDeriv(T188,params(14)-1,1);
T1418 = T74*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82))*T1417;
T1437 = (-((1-T303)*params(22)*exp(y(18))*params(11)*T918*T1418+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T1418+T46*(1-T170)*params(22)*T676*params(11)*T947*T1418));
T1441 = T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))*T1294;
T1446 = getPowerDeriv(T176,params(14),1);
T1447 = T176*T1446;
T1452 = T50*(params(22)*T170*T1447+T180*T176*T1303);
T1462 = params(22)*T303*T1447+T307*T176*T1303;
T1470 = params(22)*T386*T1447+T390*T176*T1303;
T1531 = (-((1-T259)*params(22)*exp(y(17))*params(11)*T851*T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))*T1371+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))*T1371+T46*(1-T57)*params(22)*T667*params(11)*T881*T74*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))*T1371));
T1532 = getPowerDeriv(T176,params(14)-1,1);
T1533 = T176*T1532;
T1986 = 1/params(13);
T1988 = exp((-((y(53)-T56)/params(13)*(y(53)-T56)/params(13)))/2)/2.506628274631*T1986;
T2027 = T1986*exp((-((y(54)-T56)/params(13)*(y(54)-T56)/params(13)))/2)/2.506628274631;
T2066 = T1986*exp((-((y(55)-T56)/params(13)*(y(55)-T56)/params(13)))/2)/2.506628274631;
T2102 = T1986*exp((-((y(56)-T56)/params(13)*(y(56)-T56)/params(13)))/2)/2.506628274631;
T2138 = T1986*exp((-((y(57)-T56)/params(13)*(y(57)-T56)/params(13)))/2)/2.506628274631;
T2174 = T1986*exp((-((y(58)-T56)/params(13)*(y(58)-T56)/params(13)))/2)/2.506628274631;
T2507 = T25*exp(y(77))*getPowerDeriv(T25*exp(y(77)),params(14)*(-params(3)),1);
T2562 = exp(T40*y(101))*T25*exp(y(77))*getPowerDeriv(T25*exp(y(77)),1-params(3)*params(14),1);
T2563 = T49*T2562;
T2564 = exp((1-params(14))*y(5))*T2563;
T2626 = T25*exp(y(78))*getPowerDeriv(T25*exp(y(78)),params(14)*(-params(3)),1);
T2678 = exp(T40*y(102))*T25*exp(y(78))*getPowerDeriv(T25*exp(y(78)),1-params(3)*params(14),1);
T2679 = T49*T2678;
T2680 = exp((1-params(14))*y(6))*T2679;
T2740 = T1291*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31));
T2752 = params(22)*T259*T2740+T263*T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31));
T2757 = params(22)*T344*T2740+T348*T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31));
T2785 = T1364*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31));
T2845 = T1446*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80));
T2850 = T50*(params(22)*T170*T2845+T180*T1303*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80)));
T2857 = params(22)*T303*T2845+T307*T1303*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80));
T2862 = params(22)*T386*T2845+T390*T1303*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80));
T2890 = T1532*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80));
T2950 = T1294*T74*(params(3)-params(4))*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32));
T2994 = (1-T259)*params(22)*exp(y(17))*params(11)*T851*T1371*T74*(params(3)-params(4))*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T1371*T74*(params(3)-params(4))*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))+T46*(1-T57)*params(22)*T667*params(11)*T881*T1371*T74*(params(3)-params(4))*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32));
T3004 = T1303*T74*(params(3)-params(4))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82));
T3048 = (1-T303)*params(22)*exp(y(18))*params(11)*T918*T1417*T74*(params(3)-params(4))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82))+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T1417*T74*(params(3)-params(4))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82))+T46*(1-T170)*params(22)*T676*params(11)*T947*T1417*T74*(params(3)-params(4))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82));
T3131 = (-((exp(y(39))-exp(y(37)))*(1-params(11))*params(1)*(-exp(y(127)-y(93)))+(exp(y(125))-exp(y(123)))*params(11)*params(1)*(-exp(y(127)-y(93)))));
T3189 = (-((exp(y(40))-exp(y(38)))*(1-params(11))*params(1)*(-exp(y(128)-y(94)))+(exp(y(126))-exp(y(124)))*params(11)*params(1)*(-exp(y(128)-y(94)))));
T3509 = T1294*T74*params(3)*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32));
T3517 = T1303*T74*(-params(3))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82));
T3587 = (1-T259)*params(22)*exp(y(17))*params(11)*T851*T1371*T74*params(3)*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T1371*T74*params(3)*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32))+T46*(1-T57)*params(22)*T667*params(11)*T881*T1371*T74*params(3)*exp(params(3)*y(103)+(params(3)-params(4))*y(81)+y(32));
T3607 = (1-T303)*params(22)*exp(y(18))*params(11)*T918*T1417*T74*(-params(3))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82))+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T1417*T74*(-params(3))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82))+T46*(1-T170)*params(22)*T676*params(11)*T947*T1417*T74*(-params(3))*exp(y(31)+(-params(3))*y(103)+(params(3)-params(4))*y(82));
  g1(1,77)=1;
  g1(1,93)=1;
  g1(1,95)=(-1);
  g1(2,78)=1;
  g1(2,94)=1;
  g1(2,96)=(-1);
  g1(3,31)=(-(T44*(T50*(params(22)*T57*T1292+params(22)*(1-T57)*T68*T1294)+T93*T1292)));
  g1(3,32)=(-(T44*T50*params(22)*(1-T57)*T1441));
  g1(3,3)=(-((1-params(12))*exp(y(3))+T95*exp(T40*y(101))*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(3))));
  g1(3,35)=(-(params(8)*(T109*exp(y(35))-exp(y(35)))));
  g1(3,37)=(-(T46*(T109*exp(y(59)+y(37))-exp(y(59)+y(37)))));
  g1(3,39)=(-(T46*(T109*(1-exp(y(59)))*exp(y(39))-(1-exp(y(59)))*exp(y(39)))));
  g1(3,53)=(-(T44*T50*(T69*params(22)*T1988+T85*params(22)*(-T1988))));
  g1(3,59)=(-(T46*(T109*(exp(y(59)+y(37))+exp(y(39))*(-exp(y(59))))+T122*(exp(y(59))*exp(y(123))+exp(y(125))*(-exp(y(59))))-exp(y(59)+y(37))-exp(y(39))*(-exp(y(59)))-params(20)*exp(y(78)+y(103)-y(102))*(-exp(y(59))))));
  g1(3,77)=(-(T95*exp(T40*y(101))*((T25-1)*exp(y(77)+(1-params(14))*y(3))*T38+(T25-1)*exp(y(77)+(1-params(14))*y(3))*T2507)));
  g1(3,78)=(-(T46*(-((1-exp(y(59)))*exp(y(78)+y(103)-y(102))*params(20)))));
  g1(3,79)=(-(T44*(T50*(params(22)*T57*T2740+params(22)*(1-T57)*T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31)))+T93*T2740)));
  g1(3,81)=(-(T44*T50*params(22)*(1-T57)*T2950));
  g1(3,85)=exp(y(85));
  g1(3,121)=(-(params(8)*T122*exp(y(121))));
  g1(3,123)=(-(T46*T122*exp(y(59))*exp(y(123))));
  g1(3,125)=(-(T46*T122*(1-exp(y(59)))*exp(y(125))));
  g1(3,93)=(-(T46*((exp(y(59)+y(37))+(1-exp(y(59)))*exp(y(39)))*(1-params(11))*params(1)*(-exp(y(127)-y(93)))+(exp(y(59))*exp(y(123))+(1-exp(y(59)))*exp(y(125)))*params(11)*params(1)*(-exp(y(127)-y(93))))+params(8)*(exp(y(35))*(1-params(11))*params(1)*(-exp(y(127)-y(93)))+exp(y(121))*params(11)*params(1)*(-exp(y(127)-y(93))))));
  g1(3,127)=(-(T46*T131+params(8)*(T109*exp(y(35))+T122*exp(y(121)))));
  g1(3,101)=(-(T95*(T25-1)*exp(y(77)+(1-params(14))*y(3))*T38*T40*exp(T40*y(101))));
  g1(3,102)=(-(T46*(-(params(20)*(1-exp(y(59)))*(-exp(y(78)+y(103)-y(102)))))));
  g1(3,103)=(-(T46*(-((1-exp(y(59)))*exp(y(78)+y(103)-y(102))*params(20)))+T44*T50*params(22)*(1-T57)*T3509));
  g1(4,31)=(-(T168*T50*T180*T1304));
  g1(4,32)=(-(T168*(T1452+T93*T1447)));
  g1(4,4)=(-((1-params(12))*exp(y(4))+(T192+T93*T177)*exp(T40*y(102))*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(4))));
  g1(4,36)=(-(params(8)*(T202*exp(y(36))-exp(y(36)))));
  g1(4,38)=(-(T46*(T202*exp(y(60)+y(38))-exp(y(60)+y(38)))));
  g1(4,40)=(-(T46*(T202*(1-exp(y(60)))*exp(y(40))-(1-exp(y(60)))*exp(y(40)))));
  g1(4,54)=(-(T168*T50*(T177*params(22)*T2027+T189*params(22)*(-T2027))));
  g1(4,60)=(-(T46*(T202*(exp(y(60)+y(38))+exp(y(40))*(-exp(y(60))))+T214*(exp(y(60))*exp(y(124))+exp(y(126))*(-exp(y(60))))-exp(y(60)+y(38))-exp(y(40))*(-exp(y(60)))-params(20)*exp(y(77)-y(103)-y(101))*(-exp(y(60))))));
  g1(4,77)=(-(T46*(-(params(20)*(1-exp(y(60)))*exp(y(77)-y(103)-y(101))))));
  g1(4,78)=(-((T192+T93*T177)*exp(T40*y(102))*((T25-1)*exp(y(78)+(1-params(14))*y(4))*T164+(T25-1)*exp(y(78)+(1-params(14))*y(4))*T2626)));
  g1(4,80)=(-(T168*(T2850+T93*T2845)));
  g1(4,82)=(-(T168*T50*T180*T3004));
  g1(4,86)=exp(y(86));
  g1(4,122)=(-(params(8)*T214*exp(y(122))));
  g1(4,124)=(-(T46*T214*exp(y(60))*exp(y(124))));
  g1(4,126)=(-(T46*T214*(1-exp(y(60)))*exp(y(126))));
  g1(4,94)=(-(params(8)*(exp(y(36))*(1-params(11))*params(1)*(-exp(y(128)-y(94)))+exp(y(122))*params(11)*params(1)*(-exp(y(128)-y(94))))+T46*((exp(y(60)+y(38))+(1-exp(y(60)))*exp(y(40)))*(1-params(11))*params(1)*(-exp(y(128)-y(94)))+(exp(y(60))*exp(y(124))+(1-exp(y(60)))*exp(y(126)))*params(11)*params(1)*(-exp(y(128)-y(94))))));
  g1(4,128)=(-(params(8)*(T202*exp(y(36))+T214*exp(y(122)))+T46*T223));
  g1(4,101)=(-(T46*(-(params(20)*(1-exp(y(60)))*(-exp(y(77)-y(103)-y(101)))))));
  g1(4,102)=(-((T192+T93*T177)*(T25-1)*exp(y(78)+(1-params(14))*y(4))*T164*T40*exp(T40*y(102))));
  g1(4,103)=(-(T46*(-(params(20)*(1-exp(y(60)))*(-exp(y(77)-y(103)-y(101)))))+T168*T50*T180*T3517));
  g1(5,31)=(-(T257*(params(22)*T259*T1292+T263*T68*T1294)));
  g1(5,32)=(-(T257*T263*T1441));
  g1(5,5)=(-((1-params(12))*exp(y(5))+T265*T256*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(5))));
  g1(5,37)=(-(T109*exp(y(37)+y(61))-exp(y(37)+y(61))));
  g1(5,39)=(-(T109*exp(y(39))*(1-exp(y(61)))-exp(y(39))*(1-exp(y(61)))));
  g1(5,55)=(-(T257*(T69*params(22)*T2066+T85*params(22)*(-T2066))));
  g1(5,61)=(-(T109*(exp(y(37)+y(61))+exp(y(39))*(-exp(y(61))))+T122*(exp(y(123))*exp(y(61))+exp(y(125))*(-exp(y(61))))-exp(y(37)+y(61))-exp(y(39))*(-exp(y(61)))-params(20)*exp(y(78)+y(103)-y(102))*(-exp(y(61)))));
  g1(5,77)=(-(T265*T256*(T38*(T25-1)*exp(y(77)+(1-params(14))*y(5))+(T25-1)*exp(y(77)+(1-params(14))*y(5))*T2507)));
  g1(5,78)=params(20)*exp(y(78)+y(103)-y(102))*(1-exp(y(61)));
  g1(5,79)=(-(T257*T2752));
  g1(5,81)=(-(T257*T263*T2950));
  g1(5,87)=exp(y(87));
  g1(5,123)=(-(T122*exp(y(123))*exp(y(61))));
  g1(5,125)=(-(T122*exp(y(125))*(1-exp(y(61)))));
  g1(5,93)=(-((exp(y(37)+y(61))+exp(y(39))*(1-exp(y(61))))*(1-params(11))*params(1)*(-exp(y(127)-y(93)))+(exp(y(123))*exp(y(61))+exp(y(125))*(1-exp(y(61))))*params(11)*params(1)*(-exp(y(127)-y(93)))));
  g1(5,127)=(-(T109*(exp(y(37)+y(61))+exp(y(39))*(1-exp(y(61))))+T122*(exp(y(123))*exp(y(61))+exp(y(125))*(1-exp(y(61))))));
  g1(5,101)=(-(T265*T38*(T25-1)*exp(y(77)+(1-params(14))*y(5))*T40*T256));
  g1(5,102)=params(20)*(1-exp(y(61)))*(-exp(y(78)+y(103)-y(102)));
  g1(5,103)=(-(T257*T263*T3509-params(20)*exp(y(78)+y(103)-y(102))*(1-exp(y(61)))));
  g1(6,31)=(-(T301*T307*T1304));
  g1(6,32)=(-(T301*T1462));
  g1(6,6)=(-((1-params(12))*exp(y(6))+T309*T300*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(6))));
  g1(6,38)=(-(T202*exp(y(38)+y(62))-exp(y(38)+y(62))));
  g1(6,40)=(-(T202*exp(y(40))*(1-exp(y(62)))-exp(y(40))*(1-exp(y(62)))));
  g1(6,56)=(-(T301*(T177*params(22)*T2102+T189*params(22)*(-T2102))));
  g1(6,62)=(-(T202*(exp(y(38)+y(62))+exp(y(40))*(-exp(y(62))))+T214*(exp(y(124))*exp(y(62))+exp(y(126))*(-exp(y(62))))-exp(y(38)+y(62))-exp(y(40))*(-exp(y(62)))-params(20)*exp(y(77)-y(103)-y(101))*(-exp(y(62)))));
  g1(6,77)=params(20)*(1-exp(y(62)))*exp(y(77)-y(103)-y(101));
  g1(6,78)=(-(T309*T300*(T164*(T25-1)*exp(y(78)+(1-params(14))*y(6))+(T25-1)*exp(y(78)+(1-params(14))*y(6))*T2626)));
  g1(6,80)=(-(T301*T2857));
  g1(6,82)=(-(T301*T307*T3004));
  g1(6,88)=exp(y(88));
  g1(6,124)=(-(T214*exp(y(124))*exp(y(62))));
  g1(6,126)=(-(T214*exp(y(126))*(1-exp(y(62)))));
  g1(6,94)=(-((exp(y(38)+y(62))+exp(y(40))*(1-exp(y(62))))*(1-params(11))*params(1)*(-exp(y(128)-y(94)))+(exp(y(124))*exp(y(62))+exp(y(126))*(1-exp(y(62))))*params(11)*params(1)*(-exp(y(128)-y(94)))));
  g1(6,128)=(-(T202*(exp(y(38)+y(62))+exp(y(40))*(1-exp(y(62))))+T214*(exp(y(124))*exp(y(62))+exp(y(126))*(1-exp(y(62))))));
  g1(6,101)=params(20)*(1-exp(y(62)))*(-exp(y(77)-y(103)-y(101)));
  g1(6,102)=(-(T309*T164*(T25-1)*exp(y(78)+(1-params(14))*y(6))*T40*T300));
  g1(6,103)=(-(T301*T307*T3517-params(20)*(1-exp(y(62)))*(-exp(y(77)-y(103)-y(101)))));
  g1(7,31)=(-(T342*(params(22)*T344*T1292+T348*T68*T1294)));
  g1(7,32)=(-(T342*T348*T1441));
  g1(7,37)=(-(T109*exp(y(37)+y(63))-exp(y(37)+y(63))));
  g1(7,7)=(-((1-params(12))*exp(y(7))+T350*T256*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(7))));
  g1(7,39)=(-(T109*exp(y(39))*(1-exp(y(63)))-exp(y(39))*(1-exp(y(63)))));
  g1(7,57)=(-(T342*(T69*params(22)*T2138+T85*params(22)*(-T2138))));
  g1(7,63)=(-(T109*(exp(y(37)+y(63))+exp(y(39))*(-exp(y(63))))+T122*(exp(y(123))*exp(y(63))+exp(y(125))*(-exp(y(63))))-exp(y(37)+y(63))-exp(y(39))*(-exp(y(63)))-params(21)*exp(y(78)+y(103)-y(102))*(-exp(y(63)))));
  g1(7,77)=(-(T350*T256*(T38*(T25-1)*exp(y(77)+(1-params(14))*y(7))+(T25-1)*exp(y(77)+(1-params(14))*y(7))*T2507)));
  g1(7,78)=exp(y(78)+y(103)-y(102))*(1-exp(y(63)))*params(21);
  g1(7,79)=(-(T342*T2757));
  g1(7,81)=(-(T342*T348*T2950));
  g1(7,123)=(-(T122*exp(y(123))*exp(y(63))));
  g1(7,89)=exp(y(89));
  g1(7,125)=(-(T122*exp(y(125))*(1-exp(y(63)))));
  g1(7,93)=(-((exp(y(37)+y(63))+exp(y(39))*(1-exp(y(63))))*(1-params(11))*params(1)*(-exp(y(127)-y(93)))+(exp(y(123))*exp(y(63))+exp(y(125))*(1-exp(y(63))))*params(11)*params(1)*(-exp(y(127)-y(93)))));
  g1(7,127)=(-(T109*(exp(y(37)+y(63))+exp(y(39))*(1-exp(y(63))))+T122*(exp(y(123))*exp(y(63))+exp(y(125))*(1-exp(y(63))))));
  g1(7,101)=(-(T350*T38*(T25-1)*exp(y(77)+(1-params(14))*y(7))*T40*T256));
  g1(7,102)=params(21)*(1-exp(y(63)))*(-exp(y(78)+y(103)-y(102)));
  g1(7,103)=(-(T342*T348*T3509-exp(y(78)+y(103)-y(102))*(1-exp(y(63)))*params(21)));
  g1(8,31)=(-(T384*T390*T1304));
  g1(8,32)=(-(T384*T1470));
  g1(8,38)=(-(T202*exp(y(38)+y(64))-exp(y(38)+y(64))));
  g1(8,8)=(-((1-params(12))*exp(y(8))+T392*T300*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(8))));
  g1(8,40)=(-(T202*exp(y(40))*(1-exp(y(64)))-exp(y(40))*(1-exp(y(64)))));
  g1(8,58)=(-(T384*(T177*params(22)*T2174+T189*params(22)*(-T2174))));
  g1(8,64)=(-(T202*(exp(y(38)+y(64))+exp(y(40))*(-exp(y(64))))+T214*(exp(y(124))*exp(y(64))+exp(y(126))*(-exp(y(64))))-exp(y(38)+y(64))-exp(y(40))*(-exp(y(64)))-params(21)*exp(y(77)-y(103)-y(101))*(-exp(y(64)))));
  g1(8,77)=params(21)*(1-exp(y(64)))*exp(y(77)-y(103)-y(101));
  g1(8,78)=(-(T392*T300*(T164*(T25-1)*exp(y(78)+(1-params(14))*y(8))+(T25-1)*exp(y(78)+(1-params(14))*y(8))*T2626)));
  g1(8,80)=(-(T384*T2862));
  g1(8,82)=(-(T384*T390*T3004));
  g1(8,124)=(-(T214*exp(y(124))*exp(y(64))));
  g1(8,90)=exp(y(90));
  g1(8,126)=(-(T214*exp(y(126))*(1-exp(y(64)))));
  g1(8,94)=(-((exp(y(38)+y(64))+exp(y(40))*(1-exp(y(64))))*(1-params(11))*params(1)*(-exp(y(128)-y(94)))+(exp(y(124))*exp(y(64))+exp(y(126))*(1-exp(y(64))))*params(11)*params(1)*(-exp(y(128)-y(94)))));
  g1(8,128)=(-(T202*(exp(y(38)+y(64))+exp(y(40))*(1-exp(y(64))))+T214*(exp(y(124))*exp(y(64))+exp(y(126))*(1-exp(y(64))))));
  g1(8,101)=params(21)*(1-exp(y(64)))*(-exp(y(77)-y(103)-y(101)));
  g1(8,102)=(-(T392*T164*(T25-1)*exp(y(78)+(1-params(14))*y(8))*T40*T300));
  g1(8,103)=(-(T384*T390*T3517-params(21)*(1-exp(y(64)))*(-exp(y(77)-y(103)-y(101)))));
  g1(9,31)=(-(params(22)*T428*T1292));
  g1(9,1)=(-((1-params(12))*exp(y(1))+params(22)*T69*exp(T40*(y(101)+params(9)))*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(1))));
  g1(9,35)=(-(T109*exp(y(35))-exp(y(35))));
  g1(9,77)=(-(params(22)*T69*exp(T40*(y(101)+params(9)))*(T38*(T25-1)*exp(y(77)+(1-params(14))*y(1))+(T25-1)*exp(y(77)+(1-params(14))*y(1))*T2507)));
  g1(9,79)=(-(params(22)*T428*T2740));
  g1(9,83)=exp(y(83));
  g1(9,121)=(-(T122*exp(y(121))));
  g1(9,93)=(-(exp(y(35))*(1-params(11))*params(1)*(-exp(y(127)-y(93)))+exp(y(121))*params(11)*params(1)*(-exp(y(127)-y(93)))));
  g1(9,127)=(-(T109*exp(y(35))+T122*exp(y(121))));
  g1(9,101)=(-(params(22)*T69*T38*(T25-1)*exp(y(77)+(1-params(14))*y(1))*T40*exp(T40*(y(101)+params(9)))));
  g1(10,32)=(-(params(22)*T449*T1447));
  g1(10,2)=(-((1-params(12))*exp(y(2))+params(22)*T177*exp(T40*(params(9)+y(102)))*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(2))));
  g1(10,36)=(-(T202*exp(y(36))-exp(y(36))));
  g1(10,78)=(-(params(22)*T177*exp(T40*(params(9)+y(102)))*(T164*(T25-1)*exp(y(78)+(1-params(14))*y(2))+(T25-1)*exp(y(78)+(1-params(14))*y(2))*T2626)));
  g1(10,80)=(-(params(22)*T449*T2845));
  g1(10,84)=exp(y(84));
  g1(10,122)=(-(T214*exp(y(122))));
  g1(10,94)=(-(exp(y(36))*(1-params(11))*params(1)*(-exp(y(128)-y(94)))+exp(y(122))*params(11)*params(1)*(-exp(y(128)-y(94)))));
  g1(10,128)=(-(T202*exp(y(36))+T214*exp(y(122))));
  g1(10,102)=(-(params(22)*T177*T164*(T25-1)*exp(y(78)+(1-params(14))*y(2))*T40*exp(T40*(params(9)+y(102)))));
  g1(11,31)=(-(exp(T40*y(53))*T462*(T68*T1294-T1292)));
  g1(11,32)=(-(exp(T40*y(53))*T462*T1441));
  g1(11,3)=(-(exp(T40*y(53))*(T85-T69)*T461*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(3))));
  g1(11,37)=(-(exp(y(37))+T109*(-exp(y(37)))));
  g1(11,39)=(-((-exp(y(39)))+T109*exp(y(39))));
  g1(11,53)=(-(T462*(T85-T69)*T40*exp(T40*y(53))));
  g1(11,77)=(-(exp(T40*y(53))*(T85-T69)*T461*((T25-1)*exp(y(77)+(1-params(14))*y(3))*T38+(T25-1)*exp(y(77)+(1-params(14))*y(3))*T2507)));
  g1(11,78)=exp(y(78)+y(103)-y(102))*params(20);
  g1(11,79)=(-(exp(T40*y(53))*T462*(T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))-T2740)));
  g1(11,81)=(-(exp(T40*y(53))*T462*T2950));
  g1(11,123)=(-(T122*(-exp(y(123)))));
  g1(11,125)=(-(T122*exp(y(125))));
  g1(11,93)=T3131;
  g1(11,127)=(-(T109*(exp(y(39))-exp(y(37)))+T122*(exp(y(125))-exp(y(123)))));
  g1(11,101)=(-(exp(T40*y(53))*(T85-T69)*(T25-1)*exp(y(77)+(1-params(14))*y(3))*T38*T40*T461));
  g1(11,102)=params(20)*(-exp(y(78)+y(103)-y(102)));
  g1(11,103)=exp(y(78)+y(103)-y(102))*params(20)-exp(T40*y(53))*T462*T3509;
  g1(12,31)=(-(exp(T40*y(54))*T480*T1304));
  g1(12,32)=(-(exp(T40*y(54))*T480*(T176*T1303-T1447)));
  g1(12,4)=(-(exp(T40*y(54))*(T189-T177)*T479*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(4))));
  g1(12,38)=(-(exp(y(38))+T202*(-exp(y(38)))));
  g1(12,40)=(-((-exp(y(40)))+T202*exp(y(40))));
  g1(12,54)=(-(T480*(T189-T177)*T40*exp(T40*y(54))));
  g1(12,77)=params(20)*exp(y(77)-y(103)-y(101));
  g1(12,78)=(-(exp(T40*y(54))*(T189-T177)*T479*((T25-1)*exp(y(78)+(1-params(14))*y(4))*T164+(T25-1)*exp(y(78)+(1-params(14))*y(4))*T2626)));
  g1(12,80)=(-(exp(T40*y(54))*T480*(T1303*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))-T2845)));
  g1(12,82)=(-(exp(T40*y(54))*T480*T3004));
  g1(12,124)=(-(T214*(-exp(y(124)))));
  g1(12,126)=(-(T214*exp(y(126))));
  g1(12,94)=T3189;
  g1(12,128)=(-(T202*(exp(y(40))-exp(y(38)))+T214*(exp(y(126))-exp(y(124)))));
  g1(12,101)=params(20)*(-exp(y(77)-y(103)-y(101)));
  g1(12,102)=(-(exp(T40*y(54))*(T189-T177)*(T25-1)*exp(y(78)+(1-params(14))*y(4))*T164*T40*T479));
  g1(12,103)=params(20)*(-exp(y(77)-y(103)-y(101)))-exp(T40*y(54))*T480*T3517;
  g1(13,31)=(-(exp(T40*y(55))*T495*(T68*T1294-T1292)));
  g1(13,32)=(-(exp(T40*y(55))*T495*T1441));
  g1(13,5)=(-(exp(T40*y(55))*(T85-T69)*T461*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(5))));
  g1(13,37)=(-(exp(y(37))+T109*(-exp(y(37)))));
  g1(13,39)=(-(T109*exp(y(39))-exp(y(39))));
  g1(13,55)=(-((T85-T69)*T495*T40*exp(T40*y(55))));
  g1(13,77)=(-(exp(T40*y(55))*(T85-T69)*T461*(T38*(T25-1)*exp(y(77)+(1-params(14))*y(5))+(T25-1)*exp(y(77)+(1-params(14))*y(5))*T2507)));
  g1(13,78)=exp(y(78)+y(103)-y(102))*params(20);
  g1(13,79)=(-(exp(T40*y(55))*T495*(T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))-T2740)));
  g1(13,81)=(-(exp(T40*y(55))*T495*T2950));
  g1(13,123)=(-(T122*(-exp(y(123)))));
  g1(13,125)=(-(T122*exp(y(125))));
  g1(13,93)=T3131;
  g1(13,127)=(-(T109*(exp(y(39))-exp(y(37)))+T122*(exp(y(125))-exp(y(123)))));
  g1(13,101)=(-(exp(T40*y(55))*(T85-T69)*T38*(T25-1)*exp(y(77)+(1-params(14))*y(5))*T40*T461));
  g1(13,102)=params(20)*(-exp(y(78)+y(103)-y(102)));
  g1(13,103)=exp(y(78)+y(103)-y(102))*params(20)-exp(T40*y(55))*T495*T3509;
  g1(14,31)=(-(exp(T40*y(56))*T504*T1304));
  g1(14,32)=(-(exp(T40*y(56))*T504*(T176*T1303-T1447)));
  g1(14,6)=(-(exp(T40*y(56))*(T189-T177)*T479*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(6))));
  g1(14,38)=(-(exp(y(38))+T202*(-exp(y(38)))));
  g1(14,40)=(-(T202*exp(y(40))-exp(y(40))));
  g1(14,56)=(-((T189-T177)*T504*T40*exp(T40*y(56))));
  g1(14,77)=params(20)*exp(y(77)-y(103)-y(101));
  g1(14,78)=(-(exp(T40*y(56))*(T189-T177)*T479*(T164*(T25-1)*exp(y(78)+(1-params(14))*y(6))+(T25-1)*exp(y(78)+(1-params(14))*y(6))*T2626)));
  g1(14,80)=(-(exp(T40*y(56))*T504*(T1303*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))-T2845)));
  g1(14,82)=(-(exp(T40*y(56))*T504*T3004));
  g1(14,124)=(-(T214*(-exp(y(124)))));
  g1(14,126)=(-(T214*exp(y(126))));
  g1(14,94)=T3189;
  g1(14,128)=(-(T202*(exp(y(40))-exp(y(38)))+T214*(exp(y(126))-exp(y(124)))));
  g1(14,101)=params(20)*(-exp(y(77)-y(103)-y(101)));
  g1(14,102)=(-(exp(T40*y(56))*(T189-T177)*T164*(T25-1)*exp(y(78)+(1-params(14))*y(6))*T40*T479));
  g1(14,103)=params(20)*(-exp(y(77)-y(103)-y(101)))-exp(T40*y(56))*T504*T3517;
  g1(15,31)=(-(exp(T40*y(57))*T514*(T68*T1294-T1292)));
  g1(15,32)=(-(exp(T40*y(57))*T514*T1441));
  g1(15,37)=(-(exp(y(37))+T109*(-exp(y(37)))));
  g1(15,7)=(-(exp(T40*y(57))*(T85-T69)*T461*T38*(T25-1)*(1-params(14))*exp(y(77)+(1-params(14))*y(7))));
  g1(15,39)=(-(T109*exp(y(39))-exp(y(39))));
  g1(15,57)=(-((T85-T69)*T514*T40*exp(T40*y(57))));
  g1(15,77)=(-(exp(T40*y(57))*(T85-T69)*T461*(T38*(T25-1)*exp(y(77)+(1-params(14))*y(7))+(T25-1)*exp(y(77)+(1-params(14))*y(7))*T2507)));
  g1(15,78)=exp(y(78)+y(103)-y(102))*params(21);
  g1(15,79)=(-(exp(T40*y(57))*T514*(T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))-T2740)));
  g1(15,81)=(-(exp(T40*y(57))*T514*T2950));
  g1(15,123)=(-(T122*(-exp(y(123)))));
  g1(15,125)=(-(T122*exp(y(125))));
  g1(15,93)=T3131;
  g1(15,127)=(-(T109*(exp(y(39))-exp(y(37)))+T122*(exp(y(125))-exp(y(123)))));
  g1(15,101)=(-(exp(T40*y(57))*(T85-T69)*T38*(T25-1)*exp(y(77)+(1-params(14))*y(7))*T40*T461));
  g1(15,102)=params(21)*(-exp(y(78)+y(103)-y(102)));
  g1(15,103)=exp(y(78)+y(103)-y(102))*params(21)-exp(T40*y(57))*T514*T3509;
  g1(16,31)=(-(exp(T40*y(58))*T524*T1304));
  g1(16,32)=(-(exp(T40*y(58))*T524*(T176*T1303-T1447)));
  g1(16,38)=(-(exp(y(38))+T202*(-exp(y(38)))));
  g1(16,8)=(-(exp(T40*y(58))*(T189-T177)*T479*T164*(T25-1)*(1-params(14))*exp(y(78)+(1-params(14))*y(8))));
  g1(16,40)=(-(T202*exp(y(40))-exp(y(40))));
  g1(16,58)=(-((T189-T177)*T524*T40*exp(T40*y(58))));
  g1(16,77)=params(21)*exp(y(77)-y(103)-y(101));
  g1(16,78)=(-(exp(T40*y(58))*(T189-T177)*T479*(T164*(T25-1)*exp(y(78)+(1-params(14))*y(8))+(T25-1)*exp(y(78)+(1-params(14))*y(8))*T2626)));
  g1(16,80)=(-(exp(T40*y(58))*T524*(T1303*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))-T2845)));
  g1(16,82)=(-(exp(T40*y(58))*T524*T3004));
  g1(16,124)=(-(T214*(-exp(y(124)))));
  g1(16,126)=(-(T214*exp(y(126))));
  g1(16,94)=T3189;
  g1(16,128)=(-(T202*(exp(y(40))-exp(y(38)))+T214*(exp(y(126))-exp(y(124)))));
  g1(16,101)=params(21)*(-exp(y(77)-y(103)-y(101)));
  g1(16,102)=(-(exp(T40*y(58))*(T189-T177)*T164*(T25-1)*exp(y(78)+(1-params(14))*y(8))*T40*T479));
  g1(16,103)=params(21)*(-exp(y(77)-y(103)-y(101)))-exp(T40*y(58))*T524*T3517;
  g1(17,33)=(-(T533*T535*(-exp(y(117)+y(109)-y(33)))));
  g1(17,109)=(-(T533*T535*exp(y(117)+y(109)-y(33))));
  g1(17,117)=(-(T533*T535*exp(y(117)+y(109)-y(33))));
  g1(17,93)=(-((T535*exp(y(117)+y(109)-y(33))+1-params(12)*params(11))*params(1)*(-exp(y(127)-y(93)))));
  g1(17,127)=(-(T533*(T535*exp(y(117)+y(109)-y(33))+1-params(12)*params(11))));
  g1(18,34)=(-(T548*T535*(-exp(y(118)+y(110)-y(34)))));
  g1(18,110)=(-(T548*T535*exp(y(118)+y(110)-y(34))));
  g1(18,118)=(-(T548*T535*exp(y(118)+y(110)-y(34))));
  g1(18,94)=(-((1-params(12)*params(11)+T535*exp(y(118)+y(110)-y(34)))*params(1)*(-exp(y(128)-y(94)))));
  g1(18,128)=(-(T548*(1-params(12)*params(11)+T535*exp(y(118)+y(110)-y(34)))));
  g1(19,35)=(-(T533*T535*(-exp(y(117)+y(111)-y(35)))));
  g1(19,111)=(-(T533*T535*exp(y(117)+y(111)-y(35))));
  g1(19,117)=(-(T533*T535*exp(y(117)+y(111)-y(35))));
  g1(19,93)=(-((1-params(12)*params(11)+T535*exp(y(117)+y(111)-y(35)))*params(1)*(-exp(y(127)-y(93)))));
  g1(19,127)=(-(T533*(1-params(12)*params(11)+T535*exp(y(117)+y(111)-y(35)))));
  g1(20,36)=(-(T548*T535*(-exp(y(118)+y(112)-y(36)))));
  g1(20,112)=(-(T548*T535*exp(y(118)+y(112)-y(36))));
  g1(20,118)=(-(T548*T535*exp(y(118)+y(112)-y(36))));
  g1(20,94)=(-((1-params(12)*params(11)+T535*exp(y(118)+y(112)-y(36)))*params(1)*(-exp(y(128)-y(94)))));
  g1(20,128)=(-(T548*(1-params(12)*params(11)+T535*exp(y(118)+y(112)-y(36)))));
  g1(21,37)=(-(T533*T535*(-exp(y(117)+y(113)-y(37)))));
  g1(21,113)=(-(T533*T535*exp(y(117)+y(113)-y(37))));
  g1(21,117)=(-(T533*T535*exp(y(117)+y(113)-y(37))));
  g1(21,93)=(-((1-params(12)*params(11)+T535*exp(y(117)+y(113)-y(37)))*params(1)*(-exp(y(127)-y(93)))));
  g1(21,127)=(-(T533*(1-params(12)*params(11)+T535*exp(y(117)+y(113)-y(37)))));
  g1(22,38)=(-(T548*T535*(-exp(y(118)+y(114)-y(38)))));
  g1(22,114)=(-(T548*T535*exp(y(118)+y(114)-y(38))));
  g1(22,118)=(-(T548*T535*exp(y(118)+y(114)-y(38))));
  g1(22,94)=(-((1-params(12)*params(11)+T535*exp(y(118)+y(114)-y(38)))*params(1)*(-exp(y(128)-y(94)))));
  g1(22,128)=(-(T548*(1-params(12)*params(11)+T535*exp(y(118)+y(114)-y(38)))));
  g1(23,39)=(-(T533*T535*(-exp(y(117)+y(115)-y(39)))));
  g1(23,115)=(-(T533*T535*exp(y(117)+y(115)-y(39))));
  g1(23,117)=(-(T533*T535*exp(y(117)+y(115)-y(39))));
  g1(23,93)=(-((1-params(12)*params(11)+T535*exp(y(117)+y(115)-y(39)))*params(1)*(-exp(y(127)-y(93)))));
  g1(23,127)=(-(T533*(1-params(12)*params(11)+T535*exp(y(117)+y(115)-y(39)))));
  g1(24,40)=(-(T548*T535*(-exp(y(118)+y(116)-y(40)))));
  g1(24,116)=(-(T548*T535*exp(y(118)+y(116)-y(40))));
  g1(24,118)=(-(T548*T535*exp(y(118)+y(116)-y(40))));
  g1(24,94)=(-((1-params(12)*params(11)+T535*exp(y(118)+y(116)-y(40)))*params(1)*(-exp(y(128)-y(94)))));
  g1(24,128)=(-(T548*(1-params(12)*params(11)+T535*exp(y(118)+y(116)-y(40)))));
  g1(25,53)=(-(T1986*exp((-(y(53)/params(13)*y(53)/params(13)))/2)/2.506628274631));
  g1(25,59)=exp(y(59));
  g1(26,54)=(-(T1986*exp((-(y(54)/params(13)*y(54)/params(13)))/2)/2.506628274631));
  g1(26,60)=exp(y(60));
  g1(27,55)=(-(T1986*exp((-(y(55)/params(13)*y(55)/params(13)))/2)/2.506628274631));
  g1(27,61)=exp(y(61));
  g1(28,56)=(-(T1986*exp((-(y(56)/params(13)*y(56)/params(13)))/2)/2.506628274631));
  g1(28,62)=exp(y(62));
  g1(29,57)=(-(T1986*exp((-(y(57)/params(13)*y(57)/params(13)))/2)/2.506628274631));
  g1(29,63)=exp(y(63));
  g1(30,58)=(-(T1986*exp((-(y(58)/params(13)*y(58)/params(13)))/2)/2.506628274631));
  g1(30,64)=exp(y(64));
  g1(31,25)=(-(T634*(1-params(6))*params(6)*(1-params(2))*exp(params(6)*(1-params(2))*y(25))));
  g1(31,29)=(-((1-params(6))*exp(params(6)*(1-params(2))*y(25))*(-exp(y(29)))*getPowerDeriv(1-exp(y(29)),(1-params(6))*(1-params(2))-1,1)));
  g1(31,95)=exp(y(95));
  g1(32,26)=(-(T645*(1-params(6))*params(6)*(1-params(2))*exp(params(6)*(1-params(2))*y(26))));
  g1(32,30)=(-((1-params(6))*exp(params(6)*(1-params(2))*y(26))*(-exp(y(30)))*getPowerDeriv(1-exp(y(30)),(1-params(6))*(1-params(2))-1,1)));
  g1(32,96)=exp(y(96));
  g1(33,11)=(-(params(11)*exp(y(11))));
  g1(33,67)=exp(y(67));
  g1(34,12)=(-(params(11)*exp(y(12))));
  g1(34,68)=exp(y(68));
  g1(35,13)=(-(params(8)*params(11)*exp(y(13))));
  g1(35,15)=(-(params(8)*params(11)*exp(y(15))));
  g1(35,69)=exp(y(69));
  g1(36,14)=(-(params(8)*params(11)*exp(y(14))));
  g1(36,16)=(-(params(8)*params(11)*exp(y(16))));
  g1(36,70)=exp(y(70));
  g1(37,59)=(-(exp(y(59))*T667*T46*params(11)));
  g1(37,61)=(-(exp(y(61))*params(11)*exp(y(17))));
  g1(37,63)=(-(exp(y(63))*params(11)*exp(y(19))));
  g1(37,13)=(-(exp(y(59))*exp(y(13))*T46*params(11)));
  g1(37,15)=(-(exp(y(59))*exp(y(15))*T46*params(11)));
  g1(37,17)=(-(exp(y(61))*params(11)*exp(y(17))));
  g1(37,71)=exp(y(71));
  g1(37,19)=(-(exp(y(63))*params(11)*exp(y(19))));
  g1(38,60)=(-(exp(y(60))*T676*T46*params(11)));
  g1(38,62)=(-(exp(y(62))*params(11)*exp(y(18))));
  g1(38,64)=(-(exp(y(64))*params(11)*exp(y(20))));
  g1(38,14)=(-(exp(y(60))*exp(y(14))*T46*params(11)));
  g1(38,16)=(-(exp(y(60))*exp(y(16))*T46*params(11)));
  g1(38,18)=(-(exp(y(62))*params(11)*exp(y(18))));
  g1(38,72)=exp(y(72));
  g1(38,20)=(-(exp(y(64))*params(11)*exp(y(20))));
  g1(39,59)=(-(T667*T46*params(11)*(-exp(y(59)))));
  g1(39,61)=(-(params(11)*exp(y(17))*(-exp(y(61)))));
  g1(39,63)=(-(params(11)*exp(y(19))*(-exp(y(63)))));
  g1(39,13)=(-((1-exp(y(59)))*exp(y(13))*T46*params(11)));
  g1(39,15)=(-((1-exp(y(59)))*exp(y(15))*T46*params(11)));
  g1(39,17)=(-((1-exp(y(61)))*params(11)*exp(y(17))));
  g1(39,19)=(-((1-exp(y(63)))*params(11)*exp(y(19))));
  g1(39,73)=exp(y(73));
  g1(40,60)=(-(T676*T46*params(11)*(-exp(y(60)))));
  g1(40,62)=(-(params(11)*exp(y(18))*(-exp(y(62)))));
  g1(40,64)=(-(params(11)*exp(y(20))*(-exp(y(64)))));
  g1(40,14)=(-((1-exp(y(60)))*exp(y(14))*T46*params(11)));
  g1(40,16)=(-((1-exp(y(60)))*exp(y(16))*T46*params(11)));
  g1(40,18)=(-((1-exp(y(62)))*params(11)*exp(y(18))));
  g1(40,20)=(-((1-exp(y(64)))*params(11)*exp(y(20))));
  g1(40,74)=exp(y(74));
  g1(41,67)=(-exp(y(67)));
  g1(41,69)=(-exp(y(69)));
  g1(41,71)=(-exp(y(71)));
  g1(41,73)=(-exp(y(73)));
  g1(41,75)=exp(y(75));
  g1(42,68)=(-exp(y(68)));
  g1(42,70)=(-exp(y(70)));
  g1(42,72)=(-exp(y(72)));
  g1(42,74)=(-exp(y(74)));
  g1(42,76)=exp(y(76));
  g1(43,31)=(-(T38*params(22)*exp((1-params(14))*y(1)+T40*y(101)+T40*params(9))*T1292));
  g1(43,1)=(-(T69*T38*params(22)*(1-params(14))*exp((1-params(14))*y(1)+T40*y(101)+T40*params(9))));
  g1(43,43)=exp(y(43));
  g1(43,77)=(-(T69*params(22)*exp((1-params(14))*y(1)+T40*y(101)+T40*params(9))*T2507));
  g1(43,79)=(-(T38*params(22)*exp((1-params(14))*y(1)+T40*y(101)+T40*params(9))*T2740));
  g1(43,101)=(-(T69*T38*params(22)*T40*exp((1-params(14))*y(1)+T40*y(101)+T40*params(9))));
  g1(44,32)=(-(T164*params(22)*exp((1-params(14))*y(2)+T40*params(9)+T40*y(102))*T1447));
  g1(44,2)=(-(T177*T164*params(22)*(1-params(14))*exp((1-params(14))*y(2)+T40*params(9)+T40*y(102))));
  g1(44,44)=exp(y(44));
  g1(44,78)=(-(T177*params(22)*exp((1-params(14))*y(2)+T40*params(9)+T40*y(102))*T2626));
  g1(44,80)=(-(T164*params(22)*exp((1-params(14))*y(2)+T40*params(9)+T40*y(102))*T2845));
  g1(44,102)=(-(T177*T164*params(22)*T40*exp((1-params(14))*y(2)+T40*params(9)+T40*y(102))));
  g1(45,31)=(-(T760*(T50*(params(22)*T57*T1292+params(22)*(1-T57)*T68*T1294)+params(22)*params(8)*exp(T40*params(9))*T1292)));
  g1(45,32)=(-(T760*T50*params(22)*(1-T57)*T1441));
  g1(45,3)=(-(T763*T38*(1-params(14))*exp((1-params(14))*y(3)+T40*y(101))));
  g1(45,45)=exp(y(45));
  g1(45,53)=(-(T760*T50*(T69*params(22)*T1988+T85*params(22)*(-T1988))));
  g1(45,77)=(-(T763*exp((1-params(14))*y(3)+T40*y(101))*T2507));
  g1(45,79)=(-(T760*(T50*(params(22)*T57*T2740+params(22)*(1-T57)*T1294*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31)))+params(22)*params(8)*exp(T40*params(9))*T2740)));
  g1(45,81)=(-(T760*T50*params(22)*(1-T57)*T2950));
  g1(45,101)=(-(T763*T38*T40*exp((1-params(14))*y(3)+T40*y(101))));
  g1(45,103)=(-(T760*T50*params(22)*(1-T57)*T3509));
  g1(46,31)=(-(T770*T50*T180*T1304));
  g1(46,32)=(-(T770*(T1452+params(22)*params(8)*exp(T40*params(9))*T1447)));
  g1(46,4)=(-((T192+params(22)*params(8)*exp(T40*params(9))*T177)*T164*(1-params(14))*exp((1-params(14))*y(4)+T40*y(102))));
  g1(46,46)=exp(y(46));
  g1(46,54)=(-(T770*T50*(T177*params(22)*T2027+T189*params(22)*(-T2027))));
  g1(46,78)=(-((T192+params(22)*params(8)*exp(T40*params(9))*T177)*exp((1-params(14))*y(4)+T40*y(102))*T2626));
  g1(46,80)=(-(T770*(T2850+params(22)*params(8)*exp(T40*params(9))*T2845)));
  g1(46,82)=(-(T770*T50*T180*T3004));
  g1(46,102)=(-((T192+params(22)*params(8)*exp(T40*params(9))*T177)*T164*T40*exp((1-params(14))*y(4)+T40*y(102))));
  g1(46,103)=(-(T770*T50*T180*T3517));
  g1(47,31)=(-(T781*(params(22)*T259*T1292+T263*T68*T1294)));
  g1(47,32)=(-(T781*T263*T1441));
  g1(47,5)=(-(T265*T49*T38*(1-params(14))*exp(T40*y(101)+(1-params(14))*y(5))));
  g1(47,47)=exp(y(47));
  g1(47,55)=(-(T781*(T69*params(22)*T2066+T85*params(22)*(-T2066))));
  g1(47,77)=(-(T265*T49*exp(T40*y(101)+(1-params(14))*y(5))*T2507));
  g1(47,79)=(-(T781*T2752));
  g1(47,81)=(-(T781*T263*T2950));
  g1(47,101)=(-(T265*T49*T38*T40*exp(T40*y(101)+(1-params(14))*y(5))));
  g1(47,103)=(-(T781*T263*T3509));
  g1(48,31)=(-(T789*T307*T1304));
  g1(48,32)=(-(T789*T1462));
  g1(48,6)=(-(T309*T49*T164*(1-params(14))*exp(T40*y(102)+(1-params(14))*y(6))));
  g1(48,48)=exp(y(48));
  g1(48,56)=(-(T789*(T177*params(22)*T2102+T189*params(22)*(-T2102))));
  g1(48,78)=(-(T309*T49*exp(T40*y(102)+(1-params(14))*y(6))*T2626));
  g1(48,80)=(-(T789*T2857));
  g1(48,82)=(-(T789*T307*T3004));
  g1(48,102)=(-(T309*T49*T164*T40*exp(T40*y(102)+(1-params(14))*y(6))));
  g1(48,103)=(-(T789*T307*T3517));
  g1(49,31)=(-(T797*(params(22)*T344*T1292+T348*T68*T1294)));
  g1(49,32)=(-(T797*T348*T1441));
  g1(49,7)=(-(T350*T49*T38*(1-params(14))*exp(T40*y(101)+(1-params(14))*y(7))));
  g1(49,49)=exp(y(49));
  g1(49,57)=(-(T797*(T69*params(22)*T2138+T85*params(22)*(-T2138))));
  g1(49,77)=(-(T350*T49*exp(T40*y(101)+(1-params(14))*y(7))*T2507));
  g1(49,79)=(-(T797*T2757));
  g1(49,81)=(-(T797*T348*T2950));
  g1(49,101)=(-(T350*T49*T38*T40*exp(T40*y(101)+(1-params(14))*y(7))));
  g1(49,103)=(-(T797*T348*T3509));
  g1(50,31)=(-(T805*T390*T1304));
  g1(50,32)=(-(T805*T1470));
  g1(50,8)=(-(T392*T49*T164*(1-params(14))*exp(T40*y(102)+(1-params(14))*y(8))));
  g1(50,50)=exp(y(50));
  g1(50,58)=(-(T805*(T177*params(22)*T2174+T189*params(22)*(-T2174))));
  g1(50,78)=(-(T392*T49*exp(T40*y(102)+(1-params(14))*y(8))*T2626));
  g1(50,80)=(-(T805*T2862));
  g1(50,82)=(-(T805*T390*T3004));
  g1(50,102)=(-(T392*T49*T164*T40*exp(T40*y(102)+(1-params(14))*y(8))));
  g1(50,103)=(-(T805*T390*T3517));
  g1(51,43)=(-(params(11)*exp(y(11)+y(43))));
  g1(51,45)=(-(exp(y(45))*params(11)*T667));
  g1(51,47)=(-(params(11)*exp(y(17)+y(47))));
  g1(51,49)=(-(params(11)*exp(y(19)+y(49))));
  g1(51,51)=exp(y(51));
  g1(51,11)=(-(params(11)*exp(y(11)+y(43))));
  g1(51,13)=(-(exp(y(45))*params(11)*exp(y(13))));
  g1(51,15)=(-(exp(y(45))*params(11)*exp(y(15))));
  g1(51,17)=(-(params(11)*exp(y(17)+y(47))));
  g1(51,19)=(-(params(11)*exp(y(19)+y(49))));
  g1(52,44)=(-(params(11)*exp(y(12)+y(44))));
  g1(52,46)=(-(exp(y(46))*params(11)*T676));
  g1(52,48)=(-(params(11)*exp(y(18)+y(48))));
  g1(52,50)=(-(params(11)*exp(y(20)+y(50))));
  g1(52,52)=exp(y(52));
  g1(52,12)=(-(params(11)*exp(y(12)+y(44))));
  g1(52,14)=(-(exp(y(46))*params(11)*exp(y(14))));
  g1(52,16)=(-(exp(y(46))*params(11)*exp(y(16))));
  g1(52,18)=(-(params(11)*exp(y(18)+y(48))));
  g1(52,20)=(-(params(11)*exp(y(20)+y(50))));
  g1(53,31)=(-(T259*params(22)*exp(y(17))*params(11)*T851*T1365+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T1372+T344*params(22)*exp(y(19))*params(11)*T867*T1365+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T1372+T46*T57*params(22)*T667*params(11)*T881*T1365+T46*(1-T57)*params(22)*T667*params(11)*T881*T1372+params(8)*params(22)*T667*params(11)*exp((1-params(14))*y(3))*exp(T40*params(9))*T848*T1365+params(22)*exp(y(11))*params(11)*exp(T40*params(9))*T848*exp((1-params(14))*y(1))*T1365));
  g1(53,32)=T1531;
  g1(53,1)=(-(params(22)*exp(y(11))*params(11)*T853*exp(T40*params(9))*T848*(1-params(14))*exp((1-params(14))*y(1))));
  g1(53,3)=(-(T46*T57*params(22)*T667*params(11)*T853*T849*(1-params(14))*exp((1-params(14))*y(3))+T46*(1-T57)*params(22)*T667*params(11)*T859*T849*(1-params(14))*exp((1-params(14))*y(3))+params(8)*params(22)*T667*params(11)*T853*exp(T40*params(9))*T848*(1-params(14))*exp((1-params(14))*y(3))));
  g1(53,5)=(-(T259*params(22)*exp(y(17))*params(11)*T853*T849*(1-params(14))*exp((1-params(14))*y(5))+(1-T259)*params(22)*exp(y(17))*params(11)*T859*T849*(1-params(14))*exp((1-params(14))*y(5))));
  g1(53,7)=(-(T344*params(22)*exp(y(19))*params(11)*T853*T849*(1-params(14))*exp((1-params(14))*y(7))+(1-T344)*params(22)*exp(y(19))*params(11)*T859*T849*(1-params(14))*exp((1-params(14))*y(7))));
  g1(53,53)=(-(T46*params(22)*T667*params(11)*T853*T881*T1988+T46*params(22)*T667*params(11)*T859*T881*(-T1988)));
  g1(53,55)=(-(params(22)*exp(y(17))*params(11)*T851*T853*T2066+params(22)*exp(y(17))*params(11)*T851*T859*(-T2066)));
  g1(53,57)=(-(params(22)*exp(y(19))*params(11)*T853*T867*T2138+params(22)*exp(y(19))*params(11)*T859*T867*(-T2138)));
  g1(53,11)=(-(params(22)*exp(y(11))*params(11)*T853*exp(T40*params(9))*T848*exp((1-params(14))*y(1))));
  g1(53,13)=(-(T46*T57*params(22)*exp(y(13))*params(11)*T853*T881+T46*(1-T57)*params(22)*exp(y(13))*params(11)*T859*T881+params(8)*params(22)*exp(y(13))*params(11)*T853*exp((1-params(14))*y(3))*exp(T40*params(9))*T848));
  g1(53,15)=(-(T46*T57*params(22)*exp(y(15))*params(11)*T853*T881+T46*(1-T57)*params(22)*exp(y(15))*params(11)*T859*T881+params(8)*params(22)*exp(y(15))*params(11)*T853*exp((1-params(14))*y(3))*exp(T40*params(9))*T848));
  g1(53,17)=(-(T259*params(22)*exp(y(17))*params(11)*T851*T853+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T859));
  g1(53,19)=(-(T344*params(22)*exp(y(19))*params(11)*T853*T867+T878));
  g1(53,77)=(-(T259*params(22)*exp(y(17))*params(11)*T853*T2564+(1-T259)*params(22)*exp(y(17))*params(11)*T859*T2564+T344*params(22)*exp(y(19))*params(11)*T853*exp((1-params(14))*y(7))*T2563+(1-T344)*params(22)*exp(y(19))*params(11)*T859*exp((1-params(14))*y(7))*T2563+T46*T57*params(22)*T667*params(11)*T853*exp((1-params(14))*y(3))*T2563+T46*(1-T57)*params(22)*T667*params(11)*T859*exp((1-params(14))*y(3))*T2563+params(8)*params(22)*T667*params(11)*T853*exp((1-params(14))*y(3))*exp(T40*params(9))*T2562+params(22)*exp(y(11))*params(11)*T853*exp((1-params(14))*y(1))*exp(T40*params(9))*T2562));
  g1(53,79)=(1-params(3))*exp(y(79)*(1-params(3)))-(T259*params(22)*exp(y(17))*params(11)*T851*T2785+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T1371*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))+T344*params(22)*exp(y(19))*params(11)*T867*T2785+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T1371*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))+T46*T57*params(22)*T667*params(11)*T881*T2785+T46*(1-T57)*params(22)*T667*params(11)*T881*T1371*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))+params(8)*params(22)*T667*params(11)*exp((1-params(14))*y(3))*exp(T40*params(9))*T848*T2785+params(22)*exp(y(11))*params(11)*exp(T40*params(9))*T848*exp((1-params(14))*y(1))*T2785);
  g1(53,81)=(-T2994);
  g1(53,101)=(-(T259*params(22)*exp(y(17))*params(11)*T853*exp((1-params(14))*y(5))*T49*T847*T40*exp(T40*y(101))+(1-T259)*params(22)*exp(y(17))*params(11)*T859*exp((1-params(14))*y(5))*T49*T847*T40*exp(T40*y(101))+T344*params(22)*exp(y(19))*params(11)*T853*exp((1-params(14))*y(7))*T49*T847*T40*exp(T40*y(101))+(1-T344)*params(22)*exp(y(19))*params(11)*T859*exp((1-params(14))*y(7))*T49*T847*T40*exp(T40*y(101))+T46*T57*params(22)*T667*params(11)*T853*exp((1-params(14))*y(3))*T49*T847*T40*exp(T40*y(101))+T46*(1-T57)*params(22)*T667*params(11)*T859*exp((1-params(14))*y(3))*T49*T847*T40*exp(T40*y(101))+params(8)*params(22)*T667*params(11)*T853*exp((1-params(14))*y(3))*exp(T40*params(9))*T847*T40*exp(T40*y(101))+params(22)*exp(y(11))*params(11)*T853*exp((1-params(14))*y(1))*exp(T40*params(9))*T847*T40*exp(T40*y(101))));
  g1(53,103)=(-T3587);
  g1(54,31)=T1437;
  g1(54,32)=(-(T303*params(22)*exp(y(18))*params(11)*T918*T1533+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T176*T1417+T386*params(22)*exp(y(20))*params(11)*T933*T1533+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T176*T1417+T46*T170*params(22)*T676*params(11)*T947*T1533+T46*(1-T170)*params(22)*T676*params(11)*T947*T176*T1417+params(8)*params(22)*T676*params(11)*exp((1-params(14))*y(4))*exp(T40*params(9))*T915*T1533+params(22)*exp(y(12))*params(11)*exp(T40*params(9))*T915*exp((1-params(14))*y(2))*T1533));
  g1(54,2)=(-(params(22)*exp(y(12))*params(11)*T919*exp(T40*params(9))*T915*(1-params(14))*exp((1-params(14))*y(2))));
  g1(54,4)=(-(T46*T170*params(22)*T676*params(11)*T919*T916*(1-params(14))*exp((1-params(14))*y(4))+T46*(1-T170)*params(22)*T676*params(11)*T925*T916*(1-params(14))*exp((1-params(14))*y(4))+params(8)*params(22)*T676*params(11)*T919*exp(T40*params(9))*T915*(1-params(14))*exp((1-params(14))*y(4))));
  g1(54,6)=(-(T303*params(22)*exp(y(18))*params(11)*T919*T916*(1-params(14))*exp((1-params(14))*y(6))+(1-T303)*params(22)*exp(y(18))*params(11)*T925*T916*(1-params(14))*exp((1-params(14))*y(6))));
  g1(54,8)=(-(T386*params(22)*exp(y(20))*params(11)*T919*T916*(1-params(14))*exp((1-params(14))*y(8))+(1-T386)*params(22)*exp(y(20))*params(11)*T925*T916*(1-params(14))*exp((1-params(14))*y(8))));
  g1(54,54)=(-(T46*params(22)*T676*params(11)*T919*T947*T2027+T46*params(22)*T676*params(11)*T925*T947*(-T2027)));
  g1(54,56)=(-(params(22)*exp(y(18))*params(11)*T918*T919*T2102+params(22)*exp(y(18))*params(11)*T918*T925*(-T2102)));
  g1(54,58)=(-(params(22)*exp(y(20))*params(11)*T919*T933*T2174+params(22)*exp(y(20))*params(11)*T925*T933*(-T2174)));
  g1(54,12)=(-(params(22)*exp(y(12))*params(11)*T919*exp(T40*params(9))*T915*exp((1-params(14))*y(2))));
  g1(54,14)=(-(T46*T170*params(22)*exp(y(14))*params(11)*T919*T947+T46*(1-T170)*params(22)*exp(y(14))*params(11)*T925*T947+params(8)*params(22)*exp(y(14))*params(11)*T919*exp((1-params(14))*y(4))*exp(T40*params(9))*T915));
  g1(54,16)=(-(T46*T170*params(22)*exp(y(16))*params(11)*T919*T947+T46*(1-T170)*params(22)*exp(y(16))*params(11)*T925*T947+params(8)*params(22)*exp(y(16))*params(11)*T919*exp((1-params(14))*y(4))*exp(T40*params(9))*T915));
  g1(54,18)=(-(T303*params(22)*exp(y(18))*params(11)*T918*T919+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T925));
  g1(54,20)=(-(T386*params(22)*exp(y(20))*params(11)*T919*T933+T944));
  g1(54,78)=(-(T303*params(22)*exp(y(18))*params(11)*T919*T2680+(1-T303)*params(22)*exp(y(18))*params(11)*T925*T2680+T386*params(22)*exp(y(20))*params(11)*T919*exp((1-params(14))*y(8))*T2679+(1-T386)*params(22)*exp(y(20))*params(11)*T925*exp((1-params(14))*y(8))*T2679+T46*T170*params(22)*T676*params(11)*T919*exp((1-params(14))*y(4))*T2679+T46*(1-T170)*params(22)*T676*params(11)*T925*exp((1-params(14))*y(4))*T2679+params(8)*params(22)*T676*params(11)*T919*exp((1-params(14))*y(4))*exp(T40*params(9))*T2678+params(22)*exp(y(12))*params(11)*T919*exp((1-params(14))*y(2))*exp(T40*params(9))*T2678));
  g1(54,80)=(1-params(3))*exp(y(80)*(1-params(3)))-(T303*params(22)*exp(y(18))*params(11)*T918*T2890+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T1417*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))+T386*params(22)*exp(y(20))*params(11)*T933*T2890+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T1417*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))+T46*T170*params(22)*T676*params(11)*T947*T2890+T46*(1-T170)*params(22)*T676*params(11)*T947*T1417*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))+params(8)*params(22)*T676*params(11)*exp((1-params(14))*y(4))*exp(T40*params(9))*T915*T2890+params(22)*exp(y(12))*params(11)*exp(T40*params(9))*T915*exp((1-params(14))*y(2))*T2890);
  g1(54,82)=(-T3048);
  g1(54,102)=(-(T303*params(22)*exp(y(18))*params(11)*T919*exp((1-params(14))*y(6))*T49*T914*T40*exp(T40*y(102))+(1-T303)*params(22)*exp(y(18))*params(11)*T925*exp((1-params(14))*y(6))*T49*T914*T40*exp(T40*y(102))+T386*params(22)*exp(y(20))*params(11)*T919*exp((1-params(14))*y(8))*T49*T914*T40*exp(T40*y(102))+(1-T386)*params(22)*exp(y(20))*params(11)*T925*exp((1-params(14))*y(8))*T49*T914*T40*exp(T40*y(102))+T46*T170*params(22)*T676*params(11)*T919*exp((1-params(14))*y(4))*T49*T914*T40*exp(T40*y(102))+T46*(1-T170)*params(22)*T676*params(11)*T925*exp((1-params(14))*y(4))*T49*T914*T40*exp(T40*y(102))+params(8)*params(22)*T676*params(11)*T919*exp((1-params(14))*y(4))*exp(T40*params(9))*T914*T40*exp(T40*y(102))+params(22)*exp(y(12))*params(11)*T919*exp((1-params(14))*y(2))*exp(T40*params(9))*T914*T40*exp(T40*y(102))));
  g1(54,103)=(-T3607);
  g1(55,31)=(-(T46*(1-T57)*params(22)*T667*params(11)*T881*T1372+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T1372+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T1372));
  g1(55,32)=T1531;
  g1(55,3)=(-(T46*(1-T57)*params(22)*T667*params(11)*T859*T849*(1-params(14))*exp((1-params(14))*y(3))));
  g1(55,5)=(-((1-T259)*params(22)*exp(y(17))*params(11)*T859*T849*(1-params(14))*exp((1-params(14))*y(5))));
  g1(55,7)=(-((1-T344)*params(22)*exp(y(19))*params(11)*T859*T849*(1-params(14))*exp((1-params(14))*y(7))));
  g1(55,53)=(-(T46*params(22)*T667*params(11)*T859*T881*(-T1988)));
  g1(55,55)=(-(params(22)*exp(y(17))*params(11)*T851*T859*(-T2066)));
  g1(55,57)=(-(params(22)*exp(y(19))*params(11)*T859*T867*(-T2138)));
  g1(55,13)=(-(T46*(1-T57)*params(22)*exp(y(13))*params(11)*T859*T881));
  g1(55,15)=(-(T46*(1-T57)*params(22)*exp(y(15))*params(11)*T859*T881));
  g1(55,17)=(-((1-T259)*params(22)*exp(y(17))*params(11)*T851*T859));
  g1(55,19)=(-T878);
  g1(55,77)=(-(T46*(1-T57)*params(22)*T667*params(11)*T859*exp((1-params(14))*y(3))*T2563+(1-T259)*params(22)*exp(y(17))*params(11)*T859*T2564+(1-T344)*params(22)*exp(y(19))*params(11)*T859*exp((1-params(14))*y(7))*T2563));
  g1(55,79)=(-(T46*(1-T57)*params(22)*T667*params(11)*T881*T1371*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))+(1-T259)*params(22)*exp(y(17))*params(11)*T851*T1371*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))+(1-T344)*params(22)*exp(y(19))*params(11)*T867*T1371*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(79)+y(31))));
  g1(55,81)=(1-params(3))*exp((1-params(3))*(y(103)+y(81)))-T2994;
  g1(55,101)=(-(T46*(1-T57)*params(22)*T667*params(11)*T859*exp((1-params(14))*y(3))*T49*T847*T40*exp(T40*y(101))+(1-T259)*params(22)*exp(y(17))*params(11)*T859*exp((1-params(14))*y(5))*T49*T847*T40*exp(T40*y(101))+(1-T344)*params(22)*exp(y(19))*params(11)*T859*exp((1-params(14))*y(7))*T49*T847*T40*exp(T40*y(101))));
  g1(55,103)=(1-params(3))*exp((1-params(3))*(y(103)+y(81)))-T3587;
  g1(56,31)=T1437;
  g1(56,32)=(-(T46*(1-T170)*params(22)*T676*params(11)*T947*T176*T1417+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T176*T1417+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T176*T1417));
  g1(56,4)=(-(T46*(1-T170)*params(22)*T676*params(11)*T925*T916*(1-params(14))*exp((1-params(14))*y(4))));
  g1(56,6)=(-((1-T303)*params(22)*exp(y(18))*params(11)*T925*T916*(1-params(14))*exp((1-params(14))*y(6))));
  g1(56,8)=(-((1-T386)*params(22)*exp(y(20))*params(11)*T925*T916*(1-params(14))*exp((1-params(14))*y(8))));
  g1(56,54)=(-(T46*params(22)*T676*params(11)*T925*T947*(-T2027)));
  g1(56,56)=(-(params(22)*exp(y(18))*params(11)*T918*T925*(-T2102)));
  g1(56,58)=(-(params(22)*exp(y(20))*params(11)*T925*T933*(-T2174)));
  g1(56,14)=(-(T46*(1-T170)*params(22)*exp(y(14))*params(11)*T925*T947));
  g1(56,16)=(-(T46*(1-T170)*params(22)*exp(y(16))*params(11)*T925*T947));
  g1(56,18)=(-((1-T303)*params(22)*exp(y(18))*params(11)*T918*T925));
  g1(56,20)=(-T944);
  g1(56,78)=(-(T46*(1-T170)*params(22)*T676*params(11)*T925*exp((1-params(14))*y(4))*T2679+(1-T303)*params(22)*exp(y(18))*params(11)*T925*T2680+(1-T386)*params(22)*exp(y(20))*params(11)*T925*exp((1-params(14))*y(8))*T2679));
  g1(56,80)=(-(T46*(1-T170)*params(22)*T676*params(11)*T947*T1417*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))+(1-T303)*params(22)*exp(y(18))*params(11)*T918*T1417*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))+(1-T386)*params(22)*exp(y(20))*params(11)*T933*T1417*T61*(params(3)-params(4))*exp(y(32)+(params(3)-params(4))*y(80))));
  g1(56,82)=(1-params(3))*exp((1-params(3))*(y(82)-y(103)))-T3048;
  g1(56,102)=(-(T46*(1-T170)*params(22)*T676*params(11)*T925*exp((1-params(14))*y(4))*T49*T914*T40*exp(T40*y(102))+(1-T303)*params(22)*exp(y(18))*params(11)*T925*exp((1-params(14))*y(6))*T49*T914*T40*exp(T40*y(102))+(1-T386)*params(22)*exp(y(20))*params(11)*T925*exp((1-params(14))*y(8))*T49*T914*T40*exp(T40*y(102))));
  g1(56,103)=exp((1-params(3))*(y(82)-y(103)))*(-(1-params(3)))-T3607;
  g1(57,79)=(-(T61*(1-params(4))*exp(y(79)*(1-params(4)))));
  g1(57,82)=(-(T74*(1-params(4))*exp(y(82)*(1-params(4)))));
  g1(58,80)=(-(T61*(1-params(4))*exp(y(80)*(1-params(4)))));
  g1(58,81)=(-(T74*(1-params(4))*exp(y(81)*(1-params(4)))));
  g1(59,25)=(-(T1012*params(6)*(params(6)*(1-params(2))-1)*exp(y(25)*(params(6)*(1-params(2))-1))));
  g1(59,29)=(-(params(6)*exp(y(25)*(params(6)*(1-params(2))-1))*(-exp(y(29)))*getPowerDeriv(1-exp(y(29)),(1-params(6))*(1-params(2)),1)));
  g1(59,93)=exp(y(93));
  g1(60,26)=(-(T1019*params(6)*(params(6)*(1-params(2))-1)*exp(y(26)*(params(6)*(1-params(2))-1))));
  g1(60,30)=(-(params(6)*exp(y(26)*(params(6)*(1-params(2))-1))*(-exp(y(30)))*getPowerDeriv(1-exp(y(30)),(1-params(6))*(1-params(2)),1)));
  g1(60,94)=exp(y(94));
  g1(61,51)=(-(T25*exp(y(77)+y(51))));
  g1(61,77)=(-(T25*exp(y(77)+y(51))));
  g1(61,91)=exp(y(91));
  g1(62,52)=(-(T25*exp(y(78)+y(52))));
  g1(62,78)=(-(T25*exp(y(78)+y(52))));
  g1(62,92)=exp(y(92));
  g1(63,23)=exp(y(23));
  g1(63,79)=exp(y(91)-y(79));
  g1(63,91)=(-exp(y(91)-y(79)));
  g1(64,24)=exp(y(24));
  g1(64,80)=exp(y(92)-y(80));
  g1(64,92)=(-exp(y(92)-y(80)));
  g1(65,25)=(-exp(y(25)));
  g1(65,27)=(-exp(y(27)));
  g1(65,31)=exp(y(31));
  g1(66,26)=(-exp(y(26)));
  g1(66,28)=(-exp(y(28)));
  g1(66,32)=exp(y(32));
  g1(67,27)=exp(y(27));
  g1(67,9)=(1-params(12)*params(11))*exp(y(9));
  g1(67,41)=(-exp(y(41)));
  g1(68,28)=exp(y(28));
  g1(68,10)=(1-params(12)*params(11))*exp(y(10));
  g1(68,42)=(-exp(y(42)));
  g1(69,32)=(-1);
  g1(69,81)=(-(1-params(4)));
  g1(69,103)=(-1);
  g1(69,105)=1;
  g1(70,31)=(-1);
  g1(70,82)=(-(1-params(4)));
  g1(70,106)=1;
  g1(71,91)=(-((-(exp(y(91))*(exp(y(105))-exp(y(106)))))/(exp(y(91))*exp(y(91)))));
  g1(71,104)=1;
  g1(71,105)=(-(exp(y(105))/exp(y(91))));
  g1(71,106)=(-((-exp(y(106)))/exp(y(91))));
  g1(72,93)=1;
  g1(72,94)=(-1);
  g1(72,103)=1;
  g1(73,81)=1;
  g1(73,103)=1;
  g1(73,105)=(-1);
  g1(73,107)=1;
  g1(74,82)=1;
  g1(74,106)=(-1);
  g1(74,108)=1;
  g1(75,21)=(-params(18));
  g1(75,101)=1;
  g1(75,129)=(-params(16));
  g1(76,22)=(-params(18));
  g1(76,102)=1;
  g1(76,130)=(-params(16));
  g1(77,59)=(-(T667*T46*params(11)*(-exp(y(59)))/(params(11)*(T667+exp(y(17))))));
  g1(77,61)=(-(params(11)*exp(y(17))*(-exp(y(61)))/(params(11)*(T667+exp(y(17))))));
  g1(77,13)=(-((params(11)*(T667+exp(y(17)))*(1-exp(y(59)))*exp(y(13))*T46*params(11)-T714*params(11)*exp(y(13)))/(params(11)*(T667+exp(y(17)))*params(11)*(T667+exp(y(17))))));
  g1(77,15)=(-((params(11)*(T667+exp(y(17)))*(1-exp(y(59)))*exp(y(15))*T46*params(11)-T714*params(11)*exp(y(15)))/(params(11)*(T667+exp(y(17)))*params(11)*(T667+exp(y(17))))));
  g1(77,17)=(-(((1-exp(y(61)))*params(11)*exp(y(17))*params(11)*(T667+exp(y(17)))-params(11)*exp(y(17))*T714)/(params(11)*(T667+exp(y(17)))*params(11)*(T667+exp(y(17))))));
  g1(77,99)=exp(y(99));
  g1(78,60)=(-(T676*T46*params(11)*(-exp(y(60)))/(params(11)*(T676+exp(y(18))))));
  g1(78,62)=(-(params(11)*exp(y(18))*(-exp(y(62)))/(params(11)*(T676+exp(y(18))))));
  g1(78,14)=(-((params(11)*(T676+exp(y(18)))*(1-exp(y(60)))*exp(y(14))*T46*params(11)-T722*params(11)*exp(y(14)))/(params(11)*(T676+exp(y(18)))*params(11)*(T676+exp(y(18))))));
  g1(78,16)=(-((params(11)*(T676+exp(y(18)))*(1-exp(y(60)))*exp(y(16))*T46*params(11)-T722*params(11)*exp(y(16)))/(params(11)*(T676+exp(y(18)))*params(11)*(T676+exp(y(18))))));
  g1(78,18)=(-(((1-exp(y(62)))*params(11)*exp(y(18))*params(11)*(T676+exp(y(18)))-params(11)*exp(y(18))*T722)/(params(11)*(T676+exp(y(18)))*params(11)*(T676+exp(y(18))))));
  g1(78,100)=exp(y(100));
  g1(79,63)=(-1);
  g1(79,97)=1;
  g1(80,64)=(-1);
  g1(80,98)=1;
  g1(81,33)=(-exp(y(33)+y(65)));
  g1(81,35)=(-(exp(y(35)+y(67))+exp(y(35)+y(69))));
  g1(81,37)=(-exp(y(37)+y(71)));
  g1(81,39)=(-exp(y(39)+y(73)));
  g1(81,41)=exp(y(41));
  g1(81,65)=(-exp(y(33)+y(65)));
  g1(81,67)=(-exp(y(35)+y(67)));
  g1(81,69)=(-exp(y(35)+y(69)));
  g1(81,71)=(-exp(y(37)+y(71)));
  g1(81,73)=(-exp(y(39)+y(73)));
  g1(82,34)=(-exp(y(34)+y(66)));
  g1(82,36)=(-(exp(y(36)+y(68))+exp(y(36)+y(70))));
  g1(82,38)=(-exp(y(38)+y(72)));
  g1(82,40)=(-exp(y(40)+y(74)));
  g1(82,42)=exp(y(42));
  g1(82,66)=(-exp(y(34)+y(66)));
  g1(82,68)=(-exp(y(36)+y(68)));
  g1(82,70)=(-exp(y(36)+y(70)));
  g1(82,72)=(-exp(y(38)+y(72)));
  g1(82,74)=(-exp(y(40)+y(74)));
  g1(83,33)=(-((-exp(y(33)))+(1-params(11))*params(1)*exp(y(127)-y(93)+y(33))));
  g1(83,77)=exp(y(77)-y(101))*params(19);
  g1(83,119)=(-(params(11)*params(1)*exp(y(127)-y(93)+y(119))));
  g1(83,93)=(-(params(11)*params(1)*(-exp(y(127)-y(93)+y(119)))+(1-params(11))*params(1)*(-exp(y(127)-y(93)+y(33)))));
  g1(83,127)=(-(params(11)*params(1)*exp(y(127)-y(93)+y(119))+(1-params(11))*params(1)*exp(y(127)-y(93)+y(33))));
  g1(83,101)=params(19)*(-exp(y(77)-y(101)));
  g1(84,34)=(-((-exp(y(34)))+(1-params(11))*params(1)*exp(y(128)-y(94)+y(34))));
  g1(84,78)=params(19)*exp(y(78)-y(102));
  g1(84,120)=(-(params(11)*params(1)*exp(y(128)-y(94)+y(120))));
  g1(84,94)=(-(params(11)*params(1)*(-exp(y(128)-y(94)+y(120)))+(1-params(11))*params(1)*(-exp(y(128)-y(94)+y(34)))));
  g1(84,128)=(-(params(11)*params(1)*exp(y(128)-y(94)+y(120))+(1-params(11))*params(1)*exp(y(128)-y(94)+y(34))));
  g1(84,102)=params(19)*(-exp(y(78)-y(102)));
  g1(85,29)=exp(y(29));
  g1(85,51)=(-exp(y(51)));
  g1(85,60)=(-(T676*T46*params(11)*params(20)*exp((-y(102)))*(-exp(y(60)))));
  g1(85,62)=(-(exp(y(18))*params(11)*params(20)*exp((-y(102)))*(-exp(y(62)))));
  g1(85,64)=(-(exp(y(20))*params(11)*params(21)*exp((-y(102)))*(-exp(y(64)))));
  g1(85,65)=(-(params(19)*exp((-y(101)))*exp(y(65))));
  g1(85,14)=(-((1-exp(y(60)))*exp(y(14))*T46*params(11)*params(20)*exp((-y(102)))));
  g1(85,16)=(-((1-exp(y(60)))*exp(y(16))*T46*params(11)*params(20)*exp((-y(102)))));
  g1(85,18)=(-((1-exp(y(62)))*exp(y(18))*params(11)*params(20)*exp((-y(102)))));
  g1(85,20)=(-((1-exp(y(64)))*exp(y(20))*params(11)*params(21)*exp((-y(102)))));
  g1(85,101)=(-(exp(y(65))*params(19)*(-exp((-y(101))))));
  g1(85,102)=(-((1-exp(y(60)))*T676*T46*params(11)*params(20)*(-exp((-y(102))))+(1-exp(y(62)))*exp(y(18))*params(11)*params(20)*(-exp((-y(102))))+(1-exp(y(64)))*exp(y(20))*params(11)*params(21)*(-exp((-y(102))))));
  g1(86,30)=exp(y(30));
  g1(86,52)=(-exp(y(52)));
  g1(86,59)=(-(T667*T46*params(11)*params(20)*exp((-y(101)))*(-exp(y(59)))));
  g1(86,61)=(-(exp(y(17))*params(11)*params(20)*exp((-y(101)))*(-exp(y(61)))));
  g1(86,63)=(-(exp(y(19))*params(11)*params(21)*exp((-y(101)))*(-exp(y(63)))));
  g1(86,66)=(-(params(19)*exp((-y(102)))*exp(y(66))));
  g1(86,13)=(-((1-exp(y(59)))*exp(y(13))*T46*params(11)*params(20)*exp((-y(101)))));
  g1(86,15)=(-((1-exp(y(59)))*exp(y(15))*T46*params(11)*params(20)*exp((-y(101)))));
  g1(86,17)=(-((1-exp(y(61)))*exp(y(17))*params(11)*params(20)*exp((-y(101)))));
  g1(86,19)=(-((1-exp(y(63)))*exp(y(19))*params(11)*params(21)*exp((-y(101)))));
  g1(86,101)=(-((1-exp(y(59)))*T667*T46*params(11)*params(20)*(-exp((-y(101))))+(1-exp(y(61)))*exp(y(17))*params(11)*params(20)*(-exp((-y(101))))+(1-exp(y(63)))*exp(y(19))*params(11)*params(21)*(-exp((-y(101))))));
  g1(86,102)=(-(exp(y(66))*params(19)*(-exp((-y(102))))));

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],86,16900);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],86,2197000);
end
end
end
end
