function [residual, g1, g2, g3] = dynare_M01_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 86, 1);

%
% Model equations
%

T25 = params(3)/(params(3)-1)/(1-params(5));
T38 = (T25*exp(y(55)))^(params(14)*(-params(3)));
T40 = (params(3)-1)*params(14);
T44 = (T25-1)*exp(y(55)+(1-params(14))*y(13))*T38*exp(T40*y(79));
T46 = 1-params(8);
T49 = exp(T40*params(10));
T50 = T46*T49;
T56 = params(15)*params(13)^2;
T57 = normcdf(y(31),T56,params(13));
T61 = params(7)^params(4);
T68 = T61*exp((params(3)-params(4))*y(57)+y(9));
T69 = T68^params(14);
T74 = (1-params(7))^params(4);
T85 = (T68+T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10)))^params(14);
T93 = params(22)*params(8)*exp(T40*params(9));
T95 = T50*(params(22)*T57*T69+params(22)*(1-T57)*T85)+T69*T93;
T105 = (1-params(11))*params(1);
T161 = (T25*exp(y(56)))^(params(14)*(-params(3)));
T165 = (T25-1)*exp(y(56)+(1-params(14))*y(14))*T161*exp(T40*y(80));
T167 = normcdf(y(32),T56,params(13));
T173 = T61*exp(y(10)+(params(3)-params(4))*y(58));
T174 = T173^params(14);
T177 = params(22)*(1-T167);
T185 = T173+T74*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60));
T186 = T185^params(14);
T189 = T50*(params(22)*T167*T174+T177*T186);
T234 = exp(T40*(y(79)+params(10)));
T235 = T38*(T25-1)*exp(y(55)+(1-params(14))*y(15))*T234;
T237 = normcdf(y(33),T56,params(13));
T241 = params(22)*(1-T237);
T243 = T69*params(22)*T237+T85*T241;
T275 = exp(T40*(params(10)+y(80)));
T276 = T161*(T25-1)*exp(y(56)+(1-params(14))*y(16))*T275;
T278 = normcdf(y(34),T56,params(13));
T282 = params(22)*(1-T278);
T284 = T174*params(22)*T278+T186*T282;
T314 = T234*T38*(T25-1)*exp(y(55)+(1-params(14))*y(17));
T316 = normcdf(y(35),T56,params(13));
T320 = params(22)*(1-T316);
T322 = T69*params(22)*T316+T85*T320;
T352 = T275*T161*(T25-1)*exp(y(56)+(1-params(14))*y(18));
T354 = normcdf(y(36),T56,params(13));
T358 = params(22)*(1-T354);
T360 = T174*params(22)*T354+T186*T358;
T395 = T38*(T25-1)*exp(y(55)+(1-params(14))*y(11))*exp(T40*(y(79)+params(9)));
T416 = T161*(T25-1)*exp(y(56)+(1-params(14))*y(12))*exp(T40*(params(9)+y(80)));
T428 = exp(T40*y(79)+T40*params(10));
T429 = (T25-1)*exp(y(55)+(1-params(14))*y(13))*T38*T428;
T445 = exp(T40*params(10)+T40*y(80));
T446 = (T25-1)*exp(y(56)+(1-params(14))*y(14))*T161*T445;
T460 = T38*(T25-1)*exp(y(55)+(1-params(14))*y(15))*T428;
T469 = T161*(T25-1)*exp(y(56)+(1-params(14))*y(16))*T445;
T479 = T38*(T25-1)*exp(y(55)+(1-params(14))*y(17))*T428;
T489 = T161*(T25-1)*exp(y(56)+(1-params(14))*y(18))*T445;
T499 = params(11)*params(5)/(1-params(5));
T593 = (1-exp(y(7)))^((1-params(6))*(1-params(2))-1);
T604 = (1-exp(y(8)))^((1-params(6))*(1-params(2))-1);
T622 = exp(y(45))+exp(y(47));
T627 = exp(y(46))+exp(y(48));
T659 = (1-exp(y(37)))*T622*T46*params(11)+(1-exp(y(39)))*params(11)*exp(y(49));
T665 = (1-exp(y(38)))*T627*T46*params(11)+(1-exp(y(40)))*params(11)*exp(y(50));
T698 = T38*exp((1-params(14))*y(13)+T40*y(79));
T701 = T50*(params(22)*T57*T69+params(22)*(1-T57)*T85)+params(22)*T69*params(8)*exp(T40*params(9));
T707 = T161*exp((1-params(14))*y(14)+T40*y(80));
T717 = T49*T38*exp(T40*y(79)+(1-params(14))*y(15));
T724 = T49*T161*exp(T40*y(80)+(1-params(14))*y(16));
T731 = T49*T38*exp(T40*y(79)+(1-params(14))*y(17));
T738 = T49*T161*exp(T40*y(80)+(1-params(14))*y(18));
T780 = (T25*exp(y(55)))^(1-params(3)*params(14));
T781 = exp(T40*y(79))*T780;
T782 = T49*T781;
T784 = T782*exp((1-params(14))*y(15));
T786 = T68^(params(14)-1);
T792 = (T68+T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10)))^(params(14)-1);
T800 = T782*exp((1-params(14))*y(17));
T811 = (1-T316)*params(22)*exp(y(51))*params(11)*T792*T800;
T814 = T782*exp((1-params(14))*y(13));
T847 = (T25*exp(y(56)))^(1-params(3)*params(14));
T848 = exp(T40*y(80))*T847;
T849 = T49*T848;
T851 = T849*exp((1-params(14))*y(16));
T852 = T173^(params(14)-1);
T858 = T185^(params(14)-1);
T866 = T849*exp((1-params(14))*y(18));
T877 = (1-T354)*params(22)*exp(y(52))*params(11)*T858*T866;
T880 = T849*exp((1-params(14))*y(14));
T893 = T46*(1-T167)*params(22)*T627*params(11)*T858*T880;
T945 = (1-exp(y(7)))^((1-params(6))*(1-params(2)));
T952 = (1-exp(y(8)))^((1-params(6))*(1-params(2)));
lhs =y(55);
rhs =y(73)-y(71);
residual(1)= lhs-rhs;
lhs =y(56);
rhs =y(74)-y(72);
residual(2)= lhs-rhs;
lhs =exp(y(63));
rhs =T44*T95+(1-params(12))*exp(y(13))+T46*(T105*(exp(y(37)+y(15))+(1-exp(y(37)))*exp(y(17)))+params(11)*params(1)*(exp(y(37))*exp(y(65))+(1-exp(y(37)))*exp(y(67)))-exp(y(37)+y(15))-(1-exp(y(37)))*exp(y(17))-(1-exp(y(37)))*exp(y(56)+y(81)-y(80))*params(20))+params(8)*(exp(y(13))*T105+exp(y(63))*params(11)*params(1)-exp(y(13)));
residual(3)= lhs-rhs;
lhs =exp(y(64));
rhs =params(8)*(T105*exp(y(14))+params(11)*params(1)*exp(y(64))-exp(y(14)))+T165*(T189+T93*T174)+(1-params(12))*exp(y(14))+T46*(T105*(exp(y(38)+y(16))+(1-exp(y(38)))*exp(y(18)))+params(11)*params(1)*(exp(y(38))*exp(y(66))+(1-exp(y(38)))*exp(y(68)))-exp(y(38)+y(16))-(1-exp(y(38)))*exp(y(18))-params(20)*(1-exp(y(38)))*exp(y(55)-y(81)-y(79)));
residual(4)= lhs-rhs;
lhs =exp(y(65));
rhs =T235*T243+(1-params(12))*exp(y(15))+T105*(exp(y(15)+y(39))+exp(y(17))*(1-exp(y(39))))+params(11)*params(1)*(exp(y(65))*exp(y(39))+exp(y(67))*(1-exp(y(39))))-exp(y(15)+y(39))-exp(y(17))*(1-exp(y(39)))-params(20)*exp(y(56)+y(81)-y(80))*(1-exp(y(39)));
residual(5)= lhs-rhs;
lhs =exp(y(66));
rhs =T276*T284+(1-params(12))*exp(y(16))+T105*(exp(y(16)+y(40))+exp(y(18))*(1-exp(y(40))))+params(11)*params(1)*(exp(y(66))*exp(y(40))+exp(y(68))*(1-exp(y(40))))-exp(y(16)+y(40))-exp(y(18))*(1-exp(y(40)))-params(20)*exp(y(55)-y(81)-y(79))*(1-exp(y(40)));
residual(6)= lhs-rhs;
lhs =exp(y(67));
rhs =T314*T322+(1-params(12))*exp(y(17))+T105*(exp(y(15)+y(41))+exp(y(17))*(1-exp(y(41))))+params(11)*params(1)*(exp(y(65))*exp(y(41))+exp(y(67))*(1-exp(y(41))))-exp(y(15)+y(41))-exp(y(17))*(1-exp(y(41)))-exp(y(56)+y(81)-y(80))*(1-exp(y(41)))*params(21);
residual(7)= lhs-rhs;
lhs =exp(y(68));
rhs =T352*T360+(1-params(12))*exp(y(18))+T105*(exp(y(16)+y(42))+exp(y(18))*(1-exp(y(42))))+params(11)*params(1)*(exp(y(66))*exp(y(42))+exp(y(68))*(1-exp(y(42))))-exp(y(16)+y(42))-exp(y(18))*(1-exp(y(42)))-params(21)*exp(y(55)-y(81)-y(79))*(1-exp(y(42)));
residual(8)= lhs-rhs;
lhs =exp(y(61));
rhs =exp(y(63))*params(11)*params(1)+exp(y(13))*T105+params(22)*T69*T395+(1-params(12))*exp(y(11))-exp(y(13));
residual(9)= lhs-rhs;
lhs =exp(y(62));
rhs =params(11)*params(1)*exp(y(64))+T105*exp(y(14))+params(22)*T174*T416+(1-params(12))*exp(y(12))-exp(y(14));
residual(10)= lhs-rhs;
lhs =exp(y(56)+y(81)-y(80))*params(20);
rhs =T429*(T85-T69)*exp(T40*y(31))-(exp(y(17))-exp(y(15)))+T105*(exp(y(17))-exp(y(15)))+params(11)*params(1)*(exp(y(67))-exp(y(65)));
residual(11)= lhs-rhs;
lhs =params(20)*exp(y(55)-y(81)-y(79));
rhs =T446*(T186-T174)*exp(T40*y(32))-(exp(y(18))-exp(y(16)))+T105*(exp(y(18))-exp(y(16)))+params(11)*params(1)*(exp(y(68))-exp(y(66)));
residual(12)= lhs-rhs;
lhs =exp(y(56)+y(81)-y(80))*params(20);
rhs =params(11)*params(1)*(exp(y(67))-exp(y(65)))+T105*(exp(y(17))-exp(y(15)))+(T85-T69)*T460*exp(T40*y(33))-(exp(y(17))-exp(y(15)));
residual(13)= lhs-rhs;
lhs =params(20)*exp(y(55)-y(81)-y(79));
rhs =params(11)*params(1)*(exp(y(68))-exp(y(66)))+T105*(exp(y(18))-exp(y(16)))+(T186-T174)*T469*exp(T40*y(34))-(exp(y(18))-exp(y(16)));
residual(14)= lhs-rhs;
lhs =exp(y(56)+y(81)-y(80))*params(21);
rhs =params(11)*params(1)*(exp(y(67))-exp(y(65)))+T105*(exp(y(17))-exp(y(15)))+(T85-T69)*T479*exp(T40*y(35))-(exp(y(17))-exp(y(15)));
residual(15)= lhs-rhs;
lhs =exp(y(55)-y(81)-y(79))*params(21);
rhs =params(11)*params(1)*(exp(y(68))-exp(y(66)))+T105*(exp(y(18))-exp(y(16)))+(T186-T174)*T489*exp(T40*y(36))-(exp(y(18))-exp(y(16)));
residual(16)= lhs-rhs;
lhs =1;
rhs =params(1)*(T499*exp(y(55)+y(21)-y(11))+1-params(12)*params(11));
residual(17)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(56)+y(22)-y(12)));
residual(18)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(55)+y(23)-y(13)));
residual(19)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(56)+y(24)-y(14)));
residual(20)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(55)+y(25)-y(15)));
residual(21)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(56)+y(26)-y(16)));
residual(22)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(55)+y(27)-y(17)));
residual(23)= lhs-rhs;
lhs =1;
rhs =params(1)*(1-params(12)*params(11)+T499*exp(y(56)+y(28)-y(18)));
residual(24)= lhs-rhs;
lhs =exp(y(37));
rhs =normcdf(y(31),0,params(13));
residual(25)= lhs-rhs;
lhs =exp(y(38));
rhs =normcdf(y(32),0,params(13));
residual(26)= lhs-rhs;
lhs =exp(y(39));
rhs =normcdf(y(33),0,params(13));
residual(27)= lhs-rhs;
lhs =exp(y(40));
rhs =normcdf(y(34),0,params(13));
residual(28)= lhs-rhs;
lhs =exp(y(41));
rhs =normcdf(y(35),0,params(13));
residual(29)= lhs-rhs;
lhs =exp(y(42));
rhs =normcdf(y(36),0,params(13));
residual(30)= lhs-rhs;
lhs =exp(y(73));
rhs =(1-params(6))*exp(params(6)*(1-params(2))*y(3))*T593;
residual(31)= lhs-rhs;
lhs =exp(y(74));
rhs =(1-params(6))*exp(params(6)*(1-params(2))*y(4))*T604;
residual(32)= lhs-rhs;
lhs =exp(y(45));
rhs =params(11)*exp(y(43));
residual(33)= lhs-rhs;
lhs =exp(y(46));
rhs =params(11)*exp(y(44));
residual(34)= lhs-rhs;
lhs =exp(y(47));
rhs =params(8)*params(11)*T622;
residual(35)= lhs-rhs;
lhs =exp(y(48));
rhs =params(8)*params(11)*T627;
residual(36)= lhs-rhs;
lhs =exp(y(49));
rhs =exp(y(37))*T622*T46*params(11)+exp(y(39))*params(11)*exp(y(49))+exp(y(41))*params(11)*exp(y(51));
residual(37)= lhs-rhs;
lhs =exp(y(50));
rhs =exp(y(38))*T627*T46*params(11)+exp(y(40))*params(11)*exp(y(50))+exp(y(42))*params(11)*exp(y(52));
residual(38)= lhs-rhs;
lhs =exp(y(51));
rhs =T659+(1-exp(y(41)))*params(11)*exp(y(51));
residual(39)= lhs-rhs;
lhs =exp(y(52));
rhs =T665+(1-exp(y(42)))*params(11)*exp(y(52));
residual(40)= lhs-rhs;
lhs =exp(y(53));
rhs =exp(y(51))+T622+exp(y(49));
residual(41)= lhs-rhs;
lhs =exp(y(54));
rhs =exp(y(52))+T627+exp(y(50));
residual(42)= lhs-rhs;
lhs =exp(y(21));
rhs =T69*T38*params(22)*exp((1-params(14))*y(11)+T40*y(79)+T40*params(9));
residual(43)= lhs-rhs;
lhs =exp(y(22));
rhs =T174*T161*params(22)*exp((1-params(14))*y(12)+T40*params(9)+T40*y(80));
residual(44)= lhs-rhs;
lhs =exp(y(23));
rhs =T698*T701;
residual(45)= lhs-rhs;
lhs =exp(y(24));
rhs =T707*(T189+params(22)*params(8)*exp(T40*params(9))*T174);
residual(46)= lhs-rhs;
lhs =exp(y(25));
rhs =T243*T717;
residual(47)= lhs-rhs;
lhs =exp(y(26));
rhs =T284*T724;
residual(48)= lhs-rhs;
lhs =exp(y(27));
rhs =T322*T731;
residual(49)= lhs-rhs;
lhs =exp(y(28));
rhs =T360*T738;
residual(50)= lhs-rhs;
lhs =exp(y(29));
rhs =params(11)*exp(y(21)+y(43))+exp(y(23))*params(11)*T622+params(11)*exp(y(25)+y(49))+params(11)*exp(y(27)+y(51));
residual(51)= lhs-rhs;
lhs =exp(y(30));
rhs =params(11)*exp(y(22)+y(44))+exp(y(24))*params(11)*T627+params(11)*exp(y(26)+y(50))+params(11)*exp(y(28)+y(52));
residual(52)= lhs-rhs;
lhs =exp(y(57)*(1-params(3)));
rhs =T237*params(22)*exp(y(49))*params(11)*T784*T786+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T792+T316*params(22)*exp(y(51))*params(11)*T786*T800+T811+T46*T57*params(22)*T622*params(11)*T786*T814+T46*(1-T57)*params(22)*T622*params(11)*T792*T814+params(8)*params(22)*T622*params(11)*T786*exp((1-params(14))*y(13))*exp(T40*params(9))*T781+params(22)*exp(y(43))*params(11)*T786*exp(T40*params(9))*T781*exp((1-params(14))*y(11));
residual(53)= lhs-rhs;
lhs =exp(y(58)*(1-params(3)));
rhs =T278*params(22)*exp(y(50))*params(11)*T851*T852+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T858+T354*params(22)*exp(y(52))*params(11)*T852*T866+T877+T46*T167*params(22)*T627*params(11)*T852*T880+T893+params(8)*params(22)*T627*params(11)*T852*exp((1-params(14))*y(14))*exp(T40*params(9))*T848+params(22)*exp(y(44))*params(11)*T852*exp(T40*params(9))*T848*exp((1-params(14))*y(12));
residual(54)= lhs-rhs;
lhs =exp((1-params(3))*(y(81)+y(59)));
rhs =T46*(1-T57)*params(22)*T622*params(11)*T792*T814+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T792+T811;
residual(55)= lhs-rhs;
lhs =exp((1-params(3))*(y(60)-y(81)));
rhs =T893+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T858+T877;
residual(56)= lhs-rhs;
lhs =1;
rhs =T61*exp(y(57)*(1-params(4)))+T74*exp(y(60)*(1-params(4)));
residual(57)= lhs-rhs;
lhs =1;
rhs =T61*exp(y(58)*(1-params(4)))+T74*exp(y(59)*(1-params(4)));
residual(58)= lhs-rhs;
lhs =exp(y(71));
rhs =params(6)*exp(y(3)*(params(6)*(1-params(2))-1))*T945;
residual(59)= lhs-rhs;
lhs =exp(y(72));
rhs =params(6)*exp(y(4)*(params(6)*(1-params(2))-1))*T952;
residual(60)= lhs-rhs;
lhs =exp(y(69));
rhs =T25*exp(y(55)+y(29));
residual(61)= lhs-rhs;
lhs =exp(y(70));
rhs =T25*exp(y(56)+y(30));
residual(62)= lhs-rhs;
lhs =exp(y(1));
rhs =exp(y(69)-y(57));
residual(63)= lhs-rhs;
lhs =exp(y(2));
rhs =exp(y(70)-y(58));
residual(64)= lhs-rhs;
lhs =exp(y(9));
rhs =exp(y(3))+exp(y(5));
residual(65)= lhs-rhs;
lhs =exp(y(10));
rhs =exp(y(4))+exp(y(6));
residual(66)= lhs-rhs;
lhs =exp(y(5));
rhs =exp(y(19))-(1-params(12)*params(11))*exp(y(19));
residual(67)= lhs-rhs;
lhs =exp(y(6));
rhs =exp(y(20))-(1-params(12)*params(11))*exp(y(20));
residual(68)= lhs-rhs;
lhs =y(83);
rhs =y(81)+y(10)+y(59)*(1-params(4))+params(4)*log(1-params(7));
residual(69)= lhs-rhs;
lhs =y(84);
rhs =y(9)+y(60)*(1-params(4))+params(4)*log(1-params(7));
residual(70)= lhs-rhs;
lhs =y(82);
rhs =(exp(y(83))-exp(y(84)))/exp(y(69));
residual(71)= lhs-rhs;
lhs =y(81);
rhs =y(72)-y(71);
residual(72)= lhs-rhs;
lhs =y(85);
rhs =y(83)-(y(81)+y(59));
residual(73)= lhs-rhs;
lhs =y(86);
rhs =y(84)-y(60);
residual(74)= lhs-rhs;
lhs =y(79);
rhs =y(79)*params(18)+params(16)*x(1);
residual(75)= lhs-rhs;
lhs =y(80);
rhs =y(80)*params(18)+params(16)*x(2);
residual(76)= lhs-rhs;
lhs =exp(y(77));
rhs =T659/(params(11)*(T622+exp(y(49))));
residual(77)= lhs-rhs;
lhs =exp(y(78));
rhs =T665/(params(11)*(T627+exp(y(50))));
residual(78)= lhs-rhs;
lhs =y(75);
rhs =y(41);
residual(79)= lhs-rhs;
lhs =y(76);
rhs =y(42);
residual(80)= lhs-rhs;
lhs =exp(y(19));
rhs =exp(y(11)+y(43))+exp(y(13)+y(45))+exp(y(13)+y(47))+exp(y(15)+y(49))+exp(y(17)+y(51));
residual(81)= lhs-rhs;
lhs =exp(y(20));
rhs =exp(y(12)+y(44))+exp(y(14)+y(46))+exp(y(14)+y(48))+exp(y(16)+y(50))+exp(y(18)+y(52));
residual(82)= lhs-rhs;
lhs =exp(y(55)-y(79))*params(19);
rhs =(-exp(y(11)))+params(11)*params(1)*exp(y(61))+T105*exp(y(11));
residual(83)= lhs-rhs;
lhs =params(19)*exp(y(56)-y(80));
rhs =(-exp(y(12)))+params(11)*params(1)*exp(y(62))+T105*exp(y(12));
residual(84)= lhs-rhs;
lhs =exp(y(7));
rhs =exp(y(29))+(1-exp(y(38)))*T627*T46*params(11)*params(20)*exp((-y(80)))+(1-exp(y(40)))*exp(y(50))*params(11)*params(20)*exp((-y(80)))+(1-exp(y(42)))*exp(y(52))*params(11)*params(21)*exp((-y(80)))+exp(y(43))*params(19)*exp((-y(79)));
residual(85)= lhs-rhs;
lhs =exp(y(8));
rhs =exp(y(30))+(1-exp(y(37)))*T622*T46*params(11)*params(20)*exp((-y(79)))+(1-exp(y(39)))*exp(y(49))*params(11)*params(20)*exp((-y(79)))+(1-exp(y(41)))*exp(y(51))*params(11)*params(21)*exp((-y(79)))+exp(y(44))*params(19)*exp((-y(80)));
residual(86)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(86, 86);

  %
  % Jacobian matrix
  %

T1177 = getPowerDeriv(T68,params(14),1);
T1178 = T68*T1177;
T1180 = getPowerDeriv(T68+T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10)),params(14),1);
T1189 = getPowerDeriv(T185,params(14),1);
T1190 = T74*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60))*T1189;
T1250 = getPowerDeriv(T68,params(14)-1,1);
T1251 = T68*T1250;
T1257 = getPowerDeriv(T68+T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10)),params(14)-1,1);
T1258 = T68*T1257;
T1303 = getPowerDeriv(T185,params(14)-1,1);
T1304 = T74*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60))*T1303;
T1323 = (-((1-T278)*params(22)*exp(y(50))*params(11)*T851*T1304+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T1304+T46*(1-T167)*params(22)*T627*params(11)*T880*T1304));
T1327 = T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))*T1180;
T1332 = getPowerDeriv(T173,params(14),1);
T1333 = T173*T1332;
T1338 = T50*(params(22)*T167*T1333+T177*T173*T1189);
T1348 = params(22)*T278*T1333+T282*T173*T1189;
T1356 = params(22)*T354*T1333+T358*T173*T1189;
T1417 = (-((1-T237)*params(22)*exp(y(49))*params(11)*T784*T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))*T1257+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))*T1257+T46*(1-T57)*params(22)*T622*params(11)*T814*T74*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))*T1257));
T1418 = getPowerDeriv(T173,params(14)-1,1);
T1419 = T173*T1418;
T1878 = 1/params(13);
T1880 = exp((-((y(31)-T56)/params(13)*(y(31)-T56)/params(13)))/2)/2.506628274631*T1878;
T1919 = T1878*exp((-((y(32)-T56)/params(13)*(y(32)-T56)/params(13)))/2)/2.506628274631;
T1958 = T1878*exp((-((y(33)-T56)/params(13)*(y(33)-T56)/params(13)))/2)/2.506628274631;
T1994 = T1878*exp((-((y(34)-T56)/params(13)*(y(34)-T56)/params(13)))/2)/2.506628274631;
T2030 = T1878*exp((-((y(35)-T56)/params(13)*(y(35)-T56)/params(13)))/2)/2.506628274631;
T2066 = T1878*exp((-((y(36)-T56)/params(13)*(y(36)-T56)/params(13)))/2)/2.506628274631;
T2401 = T25*exp(y(55))*getPowerDeriv(T25*exp(y(55)),params(14)*(-params(3)),1);
T2456 = exp(T40*y(79))*T25*exp(y(55))*getPowerDeriv(T25*exp(y(55)),1-params(3)*params(14),1);
T2457 = T49*T2456;
T2458 = exp((1-params(14))*y(15))*T2457;
T2520 = T25*exp(y(56))*getPowerDeriv(T25*exp(y(56)),params(14)*(-params(3)),1);
T2572 = exp(T40*y(80))*T25*exp(y(56))*getPowerDeriv(T25*exp(y(56)),1-params(3)*params(14),1);
T2573 = T49*T2572;
T2574 = exp((1-params(14))*y(16))*T2573;
T2634 = T1177*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9));
T2646 = params(22)*T237*T2634+T241*T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9));
T2651 = params(22)*T316*T2634+T320*T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9));
T2679 = T1250*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9));
T2739 = T1332*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58));
T2744 = T50*(params(22)*T167*T2739+T177*T1189*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58)));
T2751 = params(22)*T278*T2739+T282*T1189*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58));
T2756 = params(22)*T354*T2739+T358*T1189*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58));
T2784 = T1418*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58));
T2844 = T1180*T74*(params(3)-params(4))*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10));
T2888 = (1-T237)*params(22)*exp(y(49))*params(11)*T784*T1257*T74*(params(3)-params(4))*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T1257*T74*(params(3)-params(4))*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))+T46*(1-T57)*params(22)*T622*params(11)*T814*T1257*T74*(params(3)-params(4))*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10));
T2898 = T1189*T74*(params(3)-params(4))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60));
T2942 = (1-T278)*params(22)*exp(y(50))*params(11)*T851*T1303*T74*(params(3)-params(4))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60))+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T1303*T74*(params(3)-params(4))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60))+T46*(1-T167)*params(22)*T627*params(11)*T880*T1303*T74*(params(3)-params(4))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60));
T3287 = T1180*T74*params(3)*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10));
T3295 = T1189*T74*(-params(3))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60));
T3365 = (1-T237)*params(22)*exp(y(49))*params(11)*T784*T1257*T74*params(3)*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T1257*T74*params(3)*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10))+T46*(1-T57)*params(22)*T622*params(11)*T814*T1257*T74*params(3)*exp(params(3)*y(81)+(params(3)-params(4))*y(59)+y(10));
T3385 = (1-T278)*params(22)*exp(y(50))*params(11)*T851*T1303*T74*(-params(3))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60))+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T1303*T74*(-params(3))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60))+T46*(1-T167)*params(22)*T627*params(11)*T880*T1303*T74*(-params(3))*exp(y(9)+(-params(3))*y(81)+(params(3)-params(4))*y(60));
  g1(1,55)=1;
  g1(1,71)=1;
  g1(1,73)=(-1);
  g1(2,56)=1;
  g1(2,72)=1;
  g1(2,74)=(-1);
  g1(3,9)=(-(T44*(T50*(params(22)*T57*T1178+params(22)*(1-T57)*T68*T1180)+T93*T1178)));
  g1(3,10)=(-(T44*T50*params(22)*(1-T57)*T1327));
  g1(3,13)=(-((1-params(12))*exp(y(13))+T95*exp(T40*y(79))*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(13))+params(8)*(exp(y(13))*T105-exp(y(13)))));
  g1(3,15)=(-(T46*(T105*exp(y(37)+y(15))-exp(y(37)+y(15)))));
  g1(3,17)=(-(T46*(T105*(1-exp(y(37)))*exp(y(17))-(1-exp(y(37)))*exp(y(17)))));
  g1(3,31)=(-(T44*T50*(T69*params(22)*T1880+T85*params(22)*(-T1880))));
  g1(3,37)=(-(T46*(T105*(exp(y(37)+y(15))+exp(y(17))*(-exp(y(37))))+params(11)*params(1)*(exp(y(37))*exp(y(65))+exp(y(67))*(-exp(y(37))))-exp(y(37)+y(15))-exp(y(17))*(-exp(y(37)))-params(20)*exp(y(56)+y(81)-y(80))*(-exp(y(37))))));
  g1(3,55)=(-(T95*exp(T40*y(79))*((T25-1)*exp(y(55)+(1-params(14))*y(13))*T38+(T25-1)*exp(y(55)+(1-params(14))*y(13))*T2401)));
  g1(3,56)=(-(T46*(-((1-exp(y(37)))*exp(y(56)+y(81)-y(80))*params(20)))));
  g1(3,57)=(-(T44*(T50*(params(22)*T57*T2634+params(22)*(1-T57)*T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9)))+T93*T2634)));
  g1(3,59)=(-(T44*T50*params(22)*(1-T57)*T2844));
  g1(3,63)=exp(y(63))-params(8)*exp(y(63))*params(11)*params(1);
  g1(3,65)=(-(T46*params(11)*params(1)*exp(y(37))*exp(y(65))));
  g1(3,67)=(-(T46*params(11)*params(1)*(1-exp(y(37)))*exp(y(67))));
  g1(3,79)=(-(T95*(T25-1)*exp(y(55)+(1-params(14))*y(13))*T38*T40*exp(T40*y(79))));
  g1(3,80)=(-(T46*(-(params(20)*(1-exp(y(37)))*(-exp(y(56)+y(81)-y(80)))))));
  g1(3,81)=(-(T46*(-((1-exp(y(37)))*exp(y(56)+y(81)-y(80))*params(20)))+T44*T50*params(22)*(1-T57)*T3287));
  g1(4,9)=(-(T165*T50*T177*T1190));
  g1(4,10)=(-(T165*(T1338+T93*T1333)));
  g1(4,14)=(-(params(8)*(T105*exp(y(14))-exp(y(14)))+(1-params(12))*exp(y(14))+(T189+T93*T174)*exp(T40*y(80))*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(14))));
  g1(4,16)=(-(T46*(T105*exp(y(38)+y(16))-exp(y(38)+y(16)))));
  g1(4,18)=(-(T46*(T105*(1-exp(y(38)))*exp(y(18))-(1-exp(y(38)))*exp(y(18)))));
  g1(4,32)=(-(T165*T50*(T174*params(22)*T1919+T186*params(22)*(-T1919))));
  g1(4,38)=(-(T46*(T105*(exp(y(38)+y(16))+exp(y(18))*(-exp(y(38))))+params(11)*params(1)*(exp(y(38))*exp(y(66))+exp(y(68))*(-exp(y(38))))-exp(y(38)+y(16))-exp(y(18))*(-exp(y(38)))-params(20)*exp(y(55)-y(81)-y(79))*(-exp(y(38))))));
  g1(4,55)=(-(T46*(-(params(20)*(1-exp(y(38)))*exp(y(55)-y(81)-y(79))))));
  g1(4,56)=(-((T189+T93*T174)*exp(T40*y(80))*((T25-1)*exp(y(56)+(1-params(14))*y(14))*T161+(T25-1)*exp(y(56)+(1-params(14))*y(14))*T2520)));
  g1(4,58)=(-(T165*(T2744+T93*T2739)));
  g1(4,60)=(-(T165*T50*T177*T2898));
  g1(4,64)=exp(y(64))-params(8)*params(11)*params(1)*exp(y(64));
  g1(4,66)=(-(T46*params(11)*params(1)*exp(y(38))*exp(y(66))));
  g1(4,68)=(-(T46*params(11)*params(1)*(1-exp(y(38)))*exp(y(68))));
  g1(4,79)=(-(T46*(-(params(20)*(1-exp(y(38)))*(-exp(y(55)-y(81)-y(79)))))));
  g1(4,80)=(-((T189+T93*T174)*(T25-1)*exp(y(56)+(1-params(14))*y(14))*T161*T40*exp(T40*y(80))));
  g1(4,81)=(-(T46*(-(params(20)*(1-exp(y(38)))*(-exp(y(55)-y(81)-y(79)))))+T165*T50*T177*T3295));
  g1(5,9)=(-(T235*(params(22)*T237*T1178+T241*T68*T1180)));
  g1(5,10)=(-(T235*T241*T1327));
  g1(5,15)=(-((1-params(12))*exp(y(15))+T243*T234*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(15))+T105*exp(y(15)+y(39))-exp(y(15)+y(39))));
  g1(5,17)=(-(T105*exp(y(17))*(1-exp(y(39)))-exp(y(17))*(1-exp(y(39)))));
  g1(5,33)=(-(T235*(T69*params(22)*T1958+T85*params(22)*(-T1958))));
  g1(5,39)=(-(T105*(exp(y(15)+y(39))+exp(y(17))*(-exp(y(39))))+params(11)*params(1)*(exp(y(65))*exp(y(39))+exp(y(67))*(-exp(y(39))))-exp(y(15)+y(39))-exp(y(17))*(-exp(y(39)))-params(20)*exp(y(56)+y(81)-y(80))*(-exp(y(39)))));
  g1(5,55)=(-(T243*T234*(T38*(T25-1)*exp(y(55)+(1-params(14))*y(15))+(T25-1)*exp(y(55)+(1-params(14))*y(15))*T2401)));
  g1(5,56)=params(20)*exp(y(56)+y(81)-y(80))*(1-exp(y(39)));
  g1(5,57)=(-(T235*T2646));
  g1(5,59)=(-(T235*T241*T2844));
  g1(5,65)=exp(y(65))-params(11)*params(1)*exp(y(65))*exp(y(39));
  g1(5,67)=(-(params(11)*params(1)*exp(y(67))*(1-exp(y(39)))));
  g1(5,79)=(-(T243*T38*(T25-1)*exp(y(55)+(1-params(14))*y(15))*T40*T234));
  g1(5,80)=params(20)*(1-exp(y(39)))*(-exp(y(56)+y(81)-y(80)));
  g1(5,81)=(-(T235*T241*T3287-params(20)*exp(y(56)+y(81)-y(80))*(1-exp(y(39)))));
  g1(6,9)=(-(T276*T282*T1190));
  g1(6,10)=(-(T276*T1348));
  g1(6,16)=(-((1-params(12))*exp(y(16))+T284*T275*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(16))+T105*exp(y(16)+y(40))-exp(y(16)+y(40))));
  g1(6,18)=(-(T105*exp(y(18))*(1-exp(y(40)))-exp(y(18))*(1-exp(y(40)))));
  g1(6,34)=(-(T276*(T174*params(22)*T1994+T186*params(22)*(-T1994))));
  g1(6,40)=(-(T105*(exp(y(16)+y(40))+exp(y(18))*(-exp(y(40))))+params(11)*params(1)*(exp(y(66))*exp(y(40))+exp(y(68))*(-exp(y(40))))-exp(y(16)+y(40))-exp(y(18))*(-exp(y(40)))-params(20)*exp(y(55)-y(81)-y(79))*(-exp(y(40)))));
  g1(6,55)=params(20)*exp(y(55)-y(81)-y(79))*(1-exp(y(40)));
  g1(6,56)=(-(T284*T275*(T161*(T25-1)*exp(y(56)+(1-params(14))*y(16))+(T25-1)*exp(y(56)+(1-params(14))*y(16))*T2520)));
  g1(6,58)=(-(T276*T2751));
  g1(6,60)=(-(T276*T282*T2898));
  g1(6,66)=exp(y(66))-params(11)*params(1)*exp(y(66))*exp(y(40));
  g1(6,68)=(-(params(11)*params(1)*exp(y(68))*(1-exp(y(40)))));
  g1(6,79)=params(20)*(1-exp(y(40)))*(-exp(y(55)-y(81)-y(79)));
  g1(6,80)=(-(T284*T161*(T25-1)*exp(y(56)+(1-params(14))*y(16))*T40*T275));
  g1(6,81)=(-(T276*T282*T3295-params(20)*(1-exp(y(40)))*(-exp(y(55)-y(81)-y(79)))));
  g1(7,9)=(-(T314*(params(22)*T316*T1178+T320*T68*T1180)));
  g1(7,10)=(-(T314*T320*T1327));
  g1(7,15)=(-(T105*exp(y(15)+y(41))-exp(y(15)+y(41))));
  g1(7,17)=(-((1-params(12))*exp(y(17))+T322*T234*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(17))+T105*exp(y(17))*(1-exp(y(41)))-exp(y(17))*(1-exp(y(41)))));
  g1(7,35)=(-(T314*(T69*params(22)*T2030+T85*params(22)*(-T2030))));
  g1(7,41)=(-(T105*(exp(y(15)+y(41))+exp(y(17))*(-exp(y(41))))+params(11)*params(1)*(exp(y(65))*exp(y(41))+exp(y(67))*(-exp(y(41))))-exp(y(15)+y(41))-exp(y(17))*(-exp(y(41)))-params(21)*exp(y(56)+y(81)-y(80))*(-exp(y(41)))));
  g1(7,55)=(-(T322*T234*(T38*(T25-1)*exp(y(55)+(1-params(14))*y(17))+(T25-1)*exp(y(55)+(1-params(14))*y(17))*T2401)));
  g1(7,56)=exp(y(56)+y(81)-y(80))*(1-exp(y(41)))*params(21);
  g1(7,57)=(-(T314*T2651));
  g1(7,59)=(-(T314*T320*T2844));
  g1(7,65)=(-(params(11)*params(1)*exp(y(65))*exp(y(41))));
  g1(7,67)=exp(y(67))-params(11)*params(1)*exp(y(67))*(1-exp(y(41)));
  g1(7,79)=(-(T322*T38*(T25-1)*exp(y(55)+(1-params(14))*y(17))*T40*T234));
  g1(7,80)=params(21)*(1-exp(y(41)))*(-exp(y(56)+y(81)-y(80)));
  g1(7,81)=(-(T314*T320*T3287-exp(y(56)+y(81)-y(80))*(1-exp(y(41)))*params(21)));
  g1(8,9)=(-(T352*T358*T1190));
  g1(8,10)=(-(T352*T1356));
  g1(8,16)=(-(T105*exp(y(16)+y(42))-exp(y(16)+y(42))));
  g1(8,18)=(-((1-params(12))*exp(y(18))+T360*T275*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(18))+T105*exp(y(18))*(1-exp(y(42)))-exp(y(18))*(1-exp(y(42)))));
  g1(8,36)=(-(T352*(T174*params(22)*T2066+T186*params(22)*(-T2066))));
  g1(8,42)=(-(T105*(exp(y(16)+y(42))+exp(y(18))*(-exp(y(42))))+params(11)*params(1)*(exp(y(66))*exp(y(42))+exp(y(68))*(-exp(y(42))))-exp(y(16)+y(42))-exp(y(18))*(-exp(y(42)))-params(21)*exp(y(55)-y(81)-y(79))*(-exp(y(42)))));
  g1(8,55)=params(21)*exp(y(55)-y(81)-y(79))*(1-exp(y(42)));
  g1(8,56)=(-(T360*T275*(T161*(T25-1)*exp(y(56)+(1-params(14))*y(18))+(T25-1)*exp(y(56)+(1-params(14))*y(18))*T2520)));
  g1(8,58)=(-(T352*T2756));
  g1(8,60)=(-(T352*T358*T2898));
  g1(8,66)=(-(params(11)*params(1)*exp(y(66))*exp(y(42))));
  g1(8,68)=exp(y(68))-params(11)*params(1)*exp(y(68))*(1-exp(y(42)));
  g1(8,79)=params(21)*(1-exp(y(42)))*(-exp(y(55)-y(81)-y(79)));
  g1(8,80)=(-(T360*T161*(T25-1)*exp(y(56)+(1-params(14))*y(18))*T40*T275));
  g1(8,81)=(-(T352*T358*T3295-params(21)*(1-exp(y(42)))*(-exp(y(55)-y(81)-y(79)))));
  g1(9,9)=(-(params(22)*T395*T1178));
  g1(9,11)=(-((1-params(12))*exp(y(11))+params(22)*T69*exp(T40*(y(79)+params(9)))*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(11))));
  g1(9,13)=(-(exp(y(13))*T105-exp(y(13))));
  g1(9,55)=(-(params(22)*T69*exp(T40*(y(79)+params(9)))*(T38*(T25-1)*exp(y(55)+(1-params(14))*y(11))+(T25-1)*exp(y(55)+(1-params(14))*y(11))*T2401)));
  g1(9,57)=(-(params(22)*T395*T2634));
  g1(9,61)=exp(y(61));
  g1(9,63)=(-(exp(y(63))*params(11)*params(1)));
  g1(9,79)=(-(params(22)*T69*T38*(T25-1)*exp(y(55)+(1-params(14))*y(11))*T40*exp(T40*(y(79)+params(9)))));
  g1(10,10)=(-(params(22)*T416*T1333));
  g1(10,12)=(-((1-params(12))*exp(y(12))+params(22)*T174*exp(T40*(params(9)+y(80)))*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(12))));
  g1(10,14)=(-(T105*exp(y(14))-exp(y(14))));
  g1(10,56)=(-(params(22)*T174*exp(T40*(params(9)+y(80)))*(T161*(T25-1)*exp(y(56)+(1-params(14))*y(12))+(T25-1)*exp(y(56)+(1-params(14))*y(12))*T2520)));
  g1(10,58)=(-(params(22)*T416*T2739));
  g1(10,62)=exp(y(62));
  g1(10,64)=(-(params(11)*params(1)*exp(y(64))));
  g1(10,80)=(-(params(22)*T174*T161*(T25-1)*exp(y(56)+(1-params(14))*y(12))*T40*exp(T40*(params(9)+y(80)))));
  g1(11,9)=(-(exp(T40*y(31))*T429*(T68*T1180-T1178)));
  g1(11,10)=(-(exp(T40*y(31))*T429*T1327));
  g1(11,13)=(-(exp(T40*y(31))*(T85-T69)*T428*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(13))));
  g1(11,15)=(-(exp(y(15))+T105*(-exp(y(15)))));
  g1(11,17)=(-((-exp(y(17)))+T105*exp(y(17))));
  g1(11,31)=(-(T429*(T85-T69)*T40*exp(T40*y(31))));
  g1(11,55)=(-(exp(T40*y(31))*(T85-T69)*T428*((T25-1)*exp(y(55)+(1-params(14))*y(13))*T38+(T25-1)*exp(y(55)+(1-params(14))*y(13))*T2401)));
  g1(11,56)=exp(y(56)+y(81)-y(80))*params(20);
  g1(11,57)=(-(exp(T40*y(31))*T429*(T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))-T2634)));
  g1(11,59)=(-(exp(T40*y(31))*T429*T2844));
  g1(11,65)=(-(params(11)*params(1)*(-exp(y(65)))));
  g1(11,67)=(-(params(11)*params(1)*exp(y(67))));
  g1(11,79)=(-(exp(T40*y(31))*(T85-T69)*(T25-1)*exp(y(55)+(1-params(14))*y(13))*T38*T40*T428));
  g1(11,80)=params(20)*(-exp(y(56)+y(81)-y(80)));
  g1(11,81)=exp(y(56)+y(81)-y(80))*params(20)-exp(T40*y(31))*T429*T3287;
  g1(12,9)=(-(exp(T40*y(32))*T446*T1190));
  g1(12,10)=(-(exp(T40*y(32))*T446*(T173*T1189-T1333)));
  g1(12,14)=(-(exp(T40*y(32))*(T186-T174)*T445*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(14))));
  g1(12,16)=(-(exp(y(16))+T105*(-exp(y(16)))));
  g1(12,18)=(-((-exp(y(18)))+T105*exp(y(18))));
  g1(12,32)=(-(T446*(T186-T174)*T40*exp(T40*y(32))));
  g1(12,55)=params(20)*exp(y(55)-y(81)-y(79));
  g1(12,56)=(-(exp(T40*y(32))*(T186-T174)*T445*((T25-1)*exp(y(56)+(1-params(14))*y(14))*T161+(T25-1)*exp(y(56)+(1-params(14))*y(14))*T2520)));
  g1(12,58)=(-(exp(T40*y(32))*T446*(T1189*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))-T2739)));
  g1(12,60)=(-(exp(T40*y(32))*T446*T2898));
  g1(12,66)=(-(params(11)*params(1)*(-exp(y(66)))));
  g1(12,68)=(-(params(11)*params(1)*exp(y(68))));
  g1(12,79)=params(20)*(-exp(y(55)-y(81)-y(79)));
  g1(12,80)=(-(exp(T40*y(32))*(T186-T174)*(T25-1)*exp(y(56)+(1-params(14))*y(14))*T161*T40*T445));
  g1(12,81)=params(20)*(-exp(y(55)-y(81)-y(79)))-exp(T40*y(32))*T446*T3295;
  g1(13,9)=(-(exp(T40*y(33))*T460*(T68*T1180-T1178)));
  g1(13,10)=(-(exp(T40*y(33))*T460*T1327));
  g1(13,15)=(-(T105*(-exp(y(15)))+exp(T40*y(33))*(T85-T69)*T428*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(15))-(-exp(y(15)))));
  g1(13,17)=(-(T105*exp(y(17))-exp(y(17))));
  g1(13,33)=(-((T85-T69)*T460*T40*exp(T40*y(33))));
  g1(13,55)=(-(exp(T40*y(33))*(T85-T69)*T428*(T38*(T25-1)*exp(y(55)+(1-params(14))*y(15))+(T25-1)*exp(y(55)+(1-params(14))*y(15))*T2401)));
  g1(13,56)=exp(y(56)+y(81)-y(80))*params(20);
  g1(13,57)=(-(exp(T40*y(33))*T460*(T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))-T2634)));
  g1(13,59)=(-(exp(T40*y(33))*T460*T2844));
  g1(13,65)=(-(params(11)*params(1)*(-exp(y(65)))));
  g1(13,67)=(-(params(11)*params(1)*exp(y(67))));
  g1(13,79)=(-(exp(T40*y(33))*(T85-T69)*T38*(T25-1)*exp(y(55)+(1-params(14))*y(15))*T40*T428));
  g1(13,80)=params(20)*(-exp(y(56)+y(81)-y(80)));
  g1(13,81)=exp(y(56)+y(81)-y(80))*params(20)-exp(T40*y(33))*T460*T3287;
  g1(14,9)=(-(exp(T40*y(34))*T469*T1190));
  g1(14,10)=(-(exp(T40*y(34))*T469*(T173*T1189-T1333)));
  g1(14,16)=(-(T105*(-exp(y(16)))+exp(T40*y(34))*(T186-T174)*T445*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(16))-(-exp(y(16)))));
  g1(14,18)=(-(T105*exp(y(18))-exp(y(18))));
  g1(14,34)=(-((T186-T174)*T469*T40*exp(T40*y(34))));
  g1(14,55)=params(20)*exp(y(55)-y(81)-y(79));
  g1(14,56)=(-(exp(T40*y(34))*(T186-T174)*T445*(T161*(T25-1)*exp(y(56)+(1-params(14))*y(16))+(T25-1)*exp(y(56)+(1-params(14))*y(16))*T2520)));
  g1(14,58)=(-(exp(T40*y(34))*T469*(T1189*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))-T2739)));
  g1(14,60)=(-(exp(T40*y(34))*T469*T2898));
  g1(14,66)=(-(params(11)*params(1)*(-exp(y(66)))));
  g1(14,68)=(-(params(11)*params(1)*exp(y(68))));
  g1(14,79)=params(20)*(-exp(y(55)-y(81)-y(79)));
  g1(14,80)=(-(exp(T40*y(34))*(T186-T174)*T161*(T25-1)*exp(y(56)+(1-params(14))*y(16))*T40*T445));
  g1(14,81)=params(20)*(-exp(y(55)-y(81)-y(79)))-exp(T40*y(34))*T469*T3295;
  g1(15,9)=(-(exp(T40*y(35))*T479*(T68*T1180-T1178)));
  g1(15,10)=(-(exp(T40*y(35))*T479*T1327));
  g1(15,15)=(-(exp(y(15))+T105*(-exp(y(15)))));
  g1(15,17)=(-(T105*exp(y(17))+exp(T40*y(35))*(T85-T69)*T428*T38*(T25-1)*(1-params(14))*exp(y(55)+(1-params(14))*y(17))-exp(y(17))));
  g1(15,35)=(-((T85-T69)*T479*T40*exp(T40*y(35))));
  g1(15,55)=(-(exp(T40*y(35))*(T85-T69)*T428*(T38*(T25-1)*exp(y(55)+(1-params(14))*y(17))+(T25-1)*exp(y(55)+(1-params(14))*y(17))*T2401)));
  g1(15,56)=exp(y(56)+y(81)-y(80))*params(21);
  g1(15,57)=(-(exp(T40*y(35))*T479*(T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))-T2634)));
  g1(15,59)=(-(exp(T40*y(35))*T479*T2844));
  g1(15,65)=(-(params(11)*params(1)*(-exp(y(65)))));
  g1(15,67)=(-(params(11)*params(1)*exp(y(67))));
  g1(15,79)=(-(exp(T40*y(35))*(T85-T69)*T38*(T25-1)*exp(y(55)+(1-params(14))*y(17))*T40*T428));
  g1(15,80)=params(21)*(-exp(y(56)+y(81)-y(80)));
  g1(15,81)=exp(y(56)+y(81)-y(80))*params(21)-exp(T40*y(35))*T479*T3287;
  g1(16,9)=(-(exp(T40*y(36))*T489*T1190));
  g1(16,10)=(-(exp(T40*y(36))*T489*(T173*T1189-T1333)));
  g1(16,16)=(-(exp(y(16))+T105*(-exp(y(16)))));
  g1(16,18)=(-(T105*exp(y(18))+exp(T40*y(36))*(T186-T174)*T445*T161*(T25-1)*(1-params(14))*exp(y(56)+(1-params(14))*y(18))-exp(y(18))));
  g1(16,36)=(-((T186-T174)*T489*T40*exp(T40*y(36))));
  g1(16,55)=exp(y(55)-y(81)-y(79))*params(21);
  g1(16,56)=(-(exp(T40*y(36))*(T186-T174)*T445*(T161*(T25-1)*exp(y(56)+(1-params(14))*y(18))+(T25-1)*exp(y(56)+(1-params(14))*y(18))*T2520)));
  g1(16,58)=(-(exp(T40*y(36))*T489*(T1189*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))-T2739)));
  g1(16,60)=(-(exp(T40*y(36))*T489*T2898));
  g1(16,66)=(-(params(11)*params(1)*(-exp(y(66)))));
  g1(16,68)=(-(params(11)*params(1)*exp(y(68))));
  g1(16,79)=params(21)*(-exp(y(55)-y(81)-y(79)));
  g1(16,80)=(-(exp(T40*y(36))*(T186-T174)*T161*(T25-1)*exp(y(56)+(1-params(14))*y(18))*T40*T445));
  g1(16,81)=params(21)*(-exp(y(55)-y(81)-y(79)))-exp(T40*y(36))*T489*T3295;
  g1(17,11)=(-(params(1)*T499*(-exp(y(55)+y(21)-y(11)))));
  g1(17,21)=(-(params(1)*T499*exp(y(55)+y(21)-y(11))));
  g1(17,55)=(-(params(1)*T499*exp(y(55)+y(21)-y(11))));
  g1(18,12)=(-(params(1)*T499*(-exp(y(56)+y(22)-y(12)))));
  g1(18,22)=(-(params(1)*T499*exp(y(56)+y(22)-y(12))));
  g1(18,56)=(-(params(1)*T499*exp(y(56)+y(22)-y(12))));
  g1(19,13)=(-(params(1)*T499*(-exp(y(55)+y(23)-y(13)))));
  g1(19,23)=(-(params(1)*T499*exp(y(55)+y(23)-y(13))));
  g1(19,55)=(-(params(1)*T499*exp(y(55)+y(23)-y(13))));
  g1(20,14)=(-(params(1)*T499*(-exp(y(56)+y(24)-y(14)))));
  g1(20,24)=(-(params(1)*T499*exp(y(56)+y(24)-y(14))));
  g1(20,56)=(-(params(1)*T499*exp(y(56)+y(24)-y(14))));
  g1(21,15)=(-(params(1)*T499*(-exp(y(55)+y(25)-y(15)))));
  g1(21,25)=(-(params(1)*T499*exp(y(55)+y(25)-y(15))));
  g1(21,55)=(-(params(1)*T499*exp(y(55)+y(25)-y(15))));
  g1(22,16)=(-(params(1)*T499*(-exp(y(56)+y(26)-y(16)))));
  g1(22,26)=(-(params(1)*T499*exp(y(56)+y(26)-y(16))));
  g1(22,56)=(-(params(1)*T499*exp(y(56)+y(26)-y(16))));
  g1(23,17)=(-(params(1)*T499*(-exp(y(55)+y(27)-y(17)))));
  g1(23,27)=(-(params(1)*T499*exp(y(55)+y(27)-y(17))));
  g1(23,55)=(-(params(1)*T499*exp(y(55)+y(27)-y(17))));
  g1(24,18)=(-(params(1)*T499*(-exp(y(56)+y(28)-y(18)))));
  g1(24,28)=(-(params(1)*T499*exp(y(56)+y(28)-y(18))));
  g1(24,56)=(-(params(1)*T499*exp(y(56)+y(28)-y(18))));
  g1(25,31)=(-(T1878*exp((-(y(31)/params(13)*y(31)/params(13)))/2)/2.506628274631));
  g1(25,37)=exp(y(37));
  g1(26,32)=(-(T1878*exp((-(y(32)/params(13)*y(32)/params(13)))/2)/2.506628274631));
  g1(26,38)=exp(y(38));
  g1(27,33)=(-(T1878*exp((-(y(33)/params(13)*y(33)/params(13)))/2)/2.506628274631));
  g1(27,39)=exp(y(39));
  g1(28,34)=(-(T1878*exp((-(y(34)/params(13)*y(34)/params(13)))/2)/2.506628274631));
  g1(28,40)=exp(y(40));
  g1(29,35)=(-(T1878*exp((-(y(35)/params(13)*y(35)/params(13)))/2)/2.506628274631));
  g1(29,41)=exp(y(41));
  g1(30,36)=(-(T1878*exp((-(y(36)/params(13)*y(36)/params(13)))/2)/2.506628274631));
  g1(30,42)=exp(y(42));
  g1(31,3)=(-(T593*(1-params(6))*params(6)*(1-params(2))*exp(params(6)*(1-params(2))*y(3))));
  g1(31,7)=(-((1-params(6))*exp(params(6)*(1-params(2))*y(3))*(-exp(y(7)))*getPowerDeriv(1-exp(y(7)),(1-params(6))*(1-params(2))-1,1)));
  g1(31,73)=exp(y(73));
  g1(32,4)=(-(T604*(1-params(6))*params(6)*(1-params(2))*exp(params(6)*(1-params(2))*y(4))));
  g1(32,8)=(-((1-params(6))*exp(params(6)*(1-params(2))*y(4))*(-exp(y(8)))*getPowerDeriv(1-exp(y(8)),(1-params(6))*(1-params(2))-1,1)));
  g1(32,74)=exp(y(74));
  g1(33,43)=(-(params(11)*exp(y(43))));
  g1(33,45)=exp(y(45));
  g1(34,44)=(-(params(11)*exp(y(44))));
  g1(34,46)=exp(y(46));
  g1(35,45)=(-(exp(y(45))*params(8)*params(11)));
  g1(35,47)=exp(y(47))-exp(y(47))*params(8)*params(11);
  g1(36,46)=(-(exp(y(46))*params(8)*params(11)));
  g1(36,48)=exp(y(48))-params(8)*params(11)*exp(y(48));
  g1(37,37)=(-(exp(y(37))*T622*T46*params(11)));
  g1(37,39)=(-(exp(y(39))*params(11)*exp(y(49))));
  g1(37,41)=(-(exp(y(41))*params(11)*exp(y(51))));
  g1(37,45)=(-(exp(y(37))*exp(y(45))*T46*params(11)));
  g1(37,47)=(-(exp(y(37))*exp(y(47))*T46*params(11)));
  g1(37,49)=exp(y(49))-exp(y(39))*params(11)*exp(y(49));
  g1(37,51)=(-(exp(y(41))*params(11)*exp(y(51))));
  g1(38,38)=(-(exp(y(38))*T627*T46*params(11)));
  g1(38,40)=(-(exp(y(40))*params(11)*exp(y(50))));
  g1(38,42)=(-(exp(y(42))*params(11)*exp(y(52))));
  g1(38,46)=(-(exp(y(38))*exp(y(46))*T46*params(11)));
  g1(38,48)=(-(exp(y(38))*exp(y(48))*T46*params(11)));
  g1(38,50)=exp(y(50))-exp(y(40))*params(11)*exp(y(50));
  g1(38,52)=(-(exp(y(42))*params(11)*exp(y(52))));
  g1(39,37)=(-(T622*T46*params(11)*(-exp(y(37)))));
  g1(39,39)=(-(params(11)*exp(y(49))*(-exp(y(39)))));
  g1(39,41)=(-(params(11)*exp(y(51))*(-exp(y(41)))));
  g1(39,45)=(-((1-exp(y(37)))*exp(y(45))*T46*params(11)));
  g1(39,47)=(-((1-exp(y(37)))*exp(y(47))*T46*params(11)));
  g1(39,49)=(-((1-exp(y(39)))*params(11)*exp(y(49))));
  g1(39,51)=exp(y(51))-(1-exp(y(41)))*params(11)*exp(y(51));
  g1(40,38)=(-(T627*T46*params(11)*(-exp(y(38)))));
  g1(40,40)=(-(params(11)*exp(y(50))*(-exp(y(40)))));
  g1(40,42)=(-(params(11)*exp(y(52))*(-exp(y(42)))));
  g1(40,46)=(-((1-exp(y(38)))*exp(y(46))*T46*params(11)));
  g1(40,48)=(-((1-exp(y(38)))*exp(y(48))*T46*params(11)));
  g1(40,50)=(-((1-exp(y(40)))*params(11)*exp(y(50))));
  g1(40,52)=exp(y(52))-(1-exp(y(42)))*params(11)*exp(y(52));
  g1(41,45)=(-exp(y(45)));
  g1(41,47)=(-exp(y(47)));
  g1(41,49)=(-exp(y(49)));
  g1(41,51)=(-exp(y(51)));
  g1(41,53)=exp(y(53));
  g1(42,46)=(-exp(y(46)));
  g1(42,48)=(-exp(y(48)));
  g1(42,50)=(-exp(y(50)));
  g1(42,52)=(-exp(y(52)));
  g1(42,54)=exp(y(54));
  g1(43,9)=(-(T38*params(22)*exp((1-params(14))*y(11)+T40*y(79)+T40*params(9))*T1178));
  g1(43,11)=(-(T69*T38*params(22)*(1-params(14))*exp((1-params(14))*y(11)+T40*y(79)+T40*params(9))));
  g1(43,21)=exp(y(21));
  g1(43,55)=(-(T69*params(22)*exp((1-params(14))*y(11)+T40*y(79)+T40*params(9))*T2401));
  g1(43,57)=(-(T38*params(22)*exp((1-params(14))*y(11)+T40*y(79)+T40*params(9))*T2634));
  g1(43,79)=(-(T69*T38*params(22)*T40*exp((1-params(14))*y(11)+T40*y(79)+T40*params(9))));
  g1(44,10)=(-(T161*params(22)*exp((1-params(14))*y(12)+T40*params(9)+T40*y(80))*T1333));
  g1(44,12)=(-(T174*T161*params(22)*(1-params(14))*exp((1-params(14))*y(12)+T40*params(9)+T40*y(80))));
  g1(44,22)=exp(y(22));
  g1(44,56)=(-(T174*params(22)*exp((1-params(14))*y(12)+T40*params(9)+T40*y(80))*T2520));
  g1(44,58)=(-(T161*params(22)*exp((1-params(14))*y(12)+T40*params(9)+T40*y(80))*T2739));
  g1(44,80)=(-(T174*T161*params(22)*T40*exp((1-params(14))*y(12)+T40*params(9)+T40*y(80))));
  g1(45,9)=(-(T698*(T50*(params(22)*T57*T1178+params(22)*(1-T57)*T68*T1180)+params(22)*params(8)*exp(T40*params(9))*T1178)));
  g1(45,10)=(-(T698*T50*params(22)*(1-T57)*T1327));
  g1(45,13)=(-(T701*T38*(1-params(14))*exp((1-params(14))*y(13)+T40*y(79))));
  g1(45,23)=exp(y(23));
  g1(45,31)=(-(T698*T50*(T69*params(22)*T1880+T85*params(22)*(-T1880))));
  g1(45,55)=(-(T701*exp((1-params(14))*y(13)+T40*y(79))*T2401));
  g1(45,57)=(-(T698*(T50*(params(22)*T57*T2634+params(22)*(1-T57)*T1180*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9)))+params(22)*params(8)*exp(T40*params(9))*T2634)));
  g1(45,59)=(-(T698*T50*params(22)*(1-T57)*T2844));
  g1(45,79)=(-(T701*T38*T40*exp((1-params(14))*y(13)+T40*y(79))));
  g1(45,81)=(-(T698*T50*params(22)*(1-T57)*T3287));
  g1(46,9)=(-(T707*T50*T177*T1190));
  g1(46,10)=(-(T707*(T1338+params(22)*params(8)*exp(T40*params(9))*T1333)));
  g1(46,14)=(-((T189+params(22)*params(8)*exp(T40*params(9))*T174)*T161*(1-params(14))*exp((1-params(14))*y(14)+T40*y(80))));
  g1(46,24)=exp(y(24));
  g1(46,32)=(-(T707*T50*(T174*params(22)*T1919+T186*params(22)*(-T1919))));
  g1(46,56)=(-((T189+params(22)*params(8)*exp(T40*params(9))*T174)*exp((1-params(14))*y(14)+T40*y(80))*T2520));
  g1(46,58)=(-(T707*(T2744+params(22)*params(8)*exp(T40*params(9))*T2739)));
  g1(46,60)=(-(T707*T50*T177*T2898));
  g1(46,80)=(-((T189+params(22)*params(8)*exp(T40*params(9))*T174)*T161*T40*exp((1-params(14))*y(14)+T40*y(80))));
  g1(46,81)=(-(T707*T50*T177*T3295));
  g1(47,9)=(-(T717*(params(22)*T237*T1178+T241*T68*T1180)));
  g1(47,10)=(-(T717*T241*T1327));
  g1(47,15)=(-(T243*T49*T38*(1-params(14))*exp(T40*y(79)+(1-params(14))*y(15))));
  g1(47,25)=exp(y(25));
  g1(47,33)=(-(T717*(T69*params(22)*T1958+T85*params(22)*(-T1958))));
  g1(47,55)=(-(T243*T49*exp(T40*y(79)+(1-params(14))*y(15))*T2401));
  g1(47,57)=(-(T717*T2646));
  g1(47,59)=(-(T717*T241*T2844));
  g1(47,79)=(-(T243*T49*T38*T40*exp(T40*y(79)+(1-params(14))*y(15))));
  g1(47,81)=(-(T717*T241*T3287));
  g1(48,9)=(-(T724*T282*T1190));
  g1(48,10)=(-(T724*T1348));
  g1(48,16)=(-(T284*T49*T161*(1-params(14))*exp(T40*y(80)+(1-params(14))*y(16))));
  g1(48,26)=exp(y(26));
  g1(48,34)=(-(T724*(T174*params(22)*T1994+T186*params(22)*(-T1994))));
  g1(48,56)=(-(T284*T49*exp(T40*y(80)+(1-params(14))*y(16))*T2520));
  g1(48,58)=(-(T724*T2751));
  g1(48,60)=(-(T724*T282*T2898));
  g1(48,80)=(-(T284*T49*T161*T40*exp(T40*y(80)+(1-params(14))*y(16))));
  g1(48,81)=(-(T724*T282*T3295));
  g1(49,9)=(-(T731*(params(22)*T316*T1178+T320*T68*T1180)));
  g1(49,10)=(-(T731*T320*T1327));
  g1(49,17)=(-(T322*T49*T38*(1-params(14))*exp(T40*y(79)+(1-params(14))*y(17))));
  g1(49,27)=exp(y(27));
  g1(49,35)=(-(T731*(T69*params(22)*T2030+T85*params(22)*(-T2030))));
  g1(49,55)=(-(T322*T49*exp(T40*y(79)+(1-params(14))*y(17))*T2401));
  g1(49,57)=(-(T731*T2651));
  g1(49,59)=(-(T731*T320*T2844));
  g1(49,79)=(-(T322*T49*T38*T40*exp(T40*y(79)+(1-params(14))*y(17))));
  g1(49,81)=(-(T731*T320*T3287));
  g1(50,9)=(-(T738*T358*T1190));
  g1(50,10)=(-(T738*T1356));
  g1(50,18)=(-(T360*T49*T161*(1-params(14))*exp(T40*y(80)+(1-params(14))*y(18))));
  g1(50,28)=exp(y(28));
  g1(50,36)=(-(T738*(T174*params(22)*T2066+T186*params(22)*(-T2066))));
  g1(50,56)=(-(T360*T49*exp(T40*y(80)+(1-params(14))*y(18))*T2520));
  g1(50,58)=(-(T738*T2756));
  g1(50,60)=(-(T738*T358*T2898));
  g1(50,80)=(-(T360*T49*T161*T40*exp(T40*y(80)+(1-params(14))*y(18))));
  g1(50,81)=(-(T738*T358*T3295));
  g1(51,21)=(-(params(11)*exp(y(21)+y(43))));
  g1(51,23)=(-(exp(y(23))*params(11)*T622));
  g1(51,25)=(-(params(11)*exp(y(25)+y(49))));
  g1(51,27)=(-(params(11)*exp(y(27)+y(51))));
  g1(51,29)=exp(y(29));
  g1(51,43)=(-(params(11)*exp(y(21)+y(43))));
  g1(51,45)=(-(exp(y(23))*params(11)*exp(y(45))));
  g1(51,47)=(-(exp(y(23))*params(11)*exp(y(47))));
  g1(51,49)=(-(params(11)*exp(y(25)+y(49))));
  g1(51,51)=(-(params(11)*exp(y(27)+y(51))));
  g1(52,22)=(-(params(11)*exp(y(22)+y(44))));
  g1(52,24)=(-(exp(y(24))*params(11)*T627));
  g1(52,26)=(-(params(11)*exp(y(26)+y(50))));
  g1(52,28)=(-(params(11)*exp(y(28)+y(52))));
  g1(52,30)=exp(y(30));
  g1(52,44)=(-(params(11)*exp(y(22)+y(44))));
  g1(52,46)=(-(exp(y(24))*params(11)*exp(y(46))));
  g1(52,48)=(-(exp(y(24))*params(11)*exp(y(48))));
  g1(52,50)=(-(params(11)*exp(y(26)+y(50))));
  g1(52,52)=(-(params(11)*exp(y(28)+y(52))));
  g1(53,9)=(-(T237*params(22)*exp(y(49))*params(11)*T784*T1251+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T1258+T316*params(22)*exp(y(51))*params(11)*T800*T1251+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T1258+T46*T57*params(22)*T622*params(11)*T814*T1251+T46*(1-T57)*params(22)*T622*params(11)*T814*T1258+params(8)*params(22)*T622*params(11)*exp((1-params(14))*y(13))*exp(T40*params(9))*T781*T1251+params(22)*exp(y(43))*params(11)*exp(T40*params(9))*T781*exp((1-params(14))*y(11))*T1251));
  g1(53,10)=T1417;
  g1(53,11)=(-(params(22)*exp(y(43))*params(11)*T786*exp(T40*params(9))*T781*(1-params(14))*exp((1-params(14))*y(11))));
  g1(53,13)=(-(T46*T57*params(22)*T622*params(11)*T786*T782*(1-params(14))*exp((1-params(14))*y(13))+T46*(1-T57)*params(22)*T622*params(11)*T792*T782*(1-params(14))*exp((1-params(14))*y(13))+params(8)*params(22)*T622*params(11)*T786*exp(T40*params(9))*T781*(1-params(14))*exp((1-params(14))*y(13))));
  g1(53,15)=(-(T237*params(22)*exp(y(49))*params(11)*T786*T782*(1-params(14))*exp((1-params(14))*y(15))+(1-T237)*params(22)*exp(y(49))*params(11)*T792*T782*(1-params(14))*exp((1-params(14))*y(15))));
  g1(53,17)=(-(T316*params(22)*exp(y(51))*params(11)*T786*T782*(1-params(14))*exp((1-params(14))*y(17))+(1-T316)*params(22)*exp(y(51))*params(11)*T792*T782*(1-params(14))*exp((1-params(14))*y(17))));
  g1(53,31)=(-(T46*params(22)*T622*params(11)*T786*T814*T1880+T46*params(22)*T622*params(11)*T792*T814*(-T1880)));
  g1(53,33)=(-(params(22)*exp(y(49))*params(11)*T784*T786*T1958+params(22)*exp(y(49))*params(11)*T784*T792*(-T1958)));
  g1(53,35)=(-(params(22)*exp(y(51))*params(11)*T786*T800*T2030+params(22)*exp(y(51))*params(11)*T792*T800*(-T2030)));
  g1(53,43)=(-(params(22)*exp(y(43))*params(11)*T786*exp(T40*params(9))*T781*exp((1-params(14))*y(11))));
  g1(53,45)=(-(T46*T57*params(22)*exp(y(45))*params(11)*T786*T814+T46*(1-T57)*params(22)*exp(y(45))*params(11)*T792*T814+params(8)*params(22)*exp(y(45))*params(11)*T786*exp((1-params(14))*y(13))*exp(T40*params(9))*T781));
  g1(53,47)=(-(T46*T57*params(22)*exp(y(47))*params(11)*T786*T814+T46*(1-T57)*params(22)*exp(y(47))*params(11)*T792*T814+params(8)*params(22)*exp(y(47))*params(11)*T786*exp((1-params(14))*y(13))*exp(T40*params(9))*T781));
  g1(53,49)=(-(T237*params(22)*exp(y(49))*params(11)*T784*T786+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T792));
  g1(53,51)=(-(T316*params(22)*exp(y(51))*params(11)*T786*T800+T811));
  g1(53,55)=(-(T237*params(22)*exp(y(49))*params(11)*T786*T2458+(1-T237)*params(22)*exp(y(49))*params(11)*T792*T2458+T316*params(22)*exp(y(51))*params(11)*T786*exp((1-params(14))*y(17))*T2457+(1-T316)*params(22)*exp(y(51))*params(11)*T792*exp((1-params(14))*y(17))*T2457+T46*T57*params(22)*T622*params(11)*T786*exp((1-params(14))*y(13))*T2457+T46*(1-T57)*params(22)*T622*params(11)*T792*exp((1-params(14))*y(13))*T2457+params(8)*params(22)*T622*params(11)*T786*exp((1-params(14))*y(13))*exp(T40*params(9))*T2456+params(22)*exp(y(43))*params(11)*T786*exp((1-params(14))*y(11))*exp(T40*params(9))*T2456));
  g1(53,57)=(1-params(3))*exp(y(57)*(1-params(3)))-(T237*params(22)*exp(y(49))*params(11)*T784*T2679+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T1257*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))+T316*params(22)*exp(y(51))*params(11)*T800*T2679+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T1257*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))+T46*T57*params(22)*T622*params(11)*T814*T2679+T46*(1-T57)*params(22)*T622*params(11)*T814*T1257*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))+params(8)*params(22)*T622*params(11)*exp((1-params(14))*y(13))*exp(T40*params(9))*T781*T2679+params(22)*exp(y(43))*params(11)*exp(T40*params(9))*T781*exp((1-params(14))*y(11))*T2679);
  g1(53,59)=(-T2888);
  g1(53,79)=(-(T237*params(22)*exp(y(49))*params(11)*T786*exp((1-params(14))*y(15))*T49*T780*T40*exp(T40*y(79))+(1-T237)*params(22)*exp(y(49))*params(11)*T792*exp((1-params(14))*y(15))*T49*T780*T40*exp(T40*y(79))+T316*params(22)*exp(y(51))*params(11)*T786*exp((1-params(14))*y(17))*T49*T780*T40*exp(T40*y(79))+(1-T316)*params(22)*exp(y(51))*params(11)*T792*exp((1-params(14))*y(17))*T49*T780*T40*exp(T40*y(79))+T46*T57*params(22)*T622*params(11)*T786*exp((1-params(14))*y(13))*T49*T780*T40*exp(T40*y(79))+T46*(1-T57)*params(22)*T622*params(11)*T792*exp((1-params(14))*y(13))*T49*T780*T40*exp(T40*y(79))+params(8)*params(22)*T622*params(11)*T786*exp((1-params(14))*y(13))*exp(T40*params(9))*T780*T40*exp(T40*y(79))+params(22)*exp(y(43))*params(11)*T786*exp((1-params(14))*y(11))*exp(T40*params(9))*T780*T40*exp(T40*y(79))));
  g1(53,81)=(-T3365);
  g1(54,9)=T1323;
  g1(54,10)=(-(T278*params(22)*exp(y(50))*params(11)*T851*T1419+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T173*T1303+T354*params(22)*exp(y(52))*params(11)*T866*T1419+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T173*T1303+T46*T167*params(22)*T627*params(11)*T880*T1419+T46*(1-T167)*params(22)*T627*params(11)*T880*T173*T1303+params(8)*params(22)*T627*params(11)*exp((1-params(14))*y(14))*exp(T40*params(9))*T848*T1419+params(22)*exp(y(44))*params(11)*exp(T40*params(9))*T848*exp((1-params(14))*y(12))*T1419));
  g1(54,12)=(-(params(22)*exp(y(44))*params(11)*T852*exp(T40*params(9))*T848*(1-params(14))*exp((1-params(14))*y(12))));
  g1(54,14)=(-(T46*T167*params(22)*T627*params(11)*T852*T849*(1-params(14))*exp((1-params(14))*y(14))+T46*(1-T167)*params(22)*T627*params(11)*T858*T849*(1-params(14))*exp((1-params(14))*y(14))+params(8)*params(22)*T627*params(11)*T852*exp(T40*params(9))*T848*(1-params(14))*exp((1-params(14))*y(14))));
  g1(54,16)=(-(T278*params(22)*exp(y(50))*params(11)*T852*T849*(1-params(14))*exp((1-params(14))*y(16))+(1-T278)*params(22)*exp(y(50))*params(11)*T858*T849*(1-params(14))*exp((1-params(14))*y(16))));
  g1(54,18)=(-(T354*params(22)*exp(y(52))*params(11)*T852*T849*(1-params(14))*exp((1-params(14))*y(18))+(1-T354)*params(22)*exp(y(52))*params(11)*T858*T849*(1-params(14))*exp((1-params(14))*y(18))));
  g1(54,32)=(-(T46*params(22)*T627*params(11)*T852*T880*T1919+T46*params(22)*T627*params(11)*T858*T880*(-T1919)));
  g1(54,34)=(-(params(22)*exp(y(50))*params(11)*T851*T852*T1994+params(22)*exp(y(50))*params(11)*T851*T858*(-T1994)));
  g1(54,36)=(-(params(22)*exp(y(52))*params(11)*T852*T866*T2066+params(22)*exp(y(52))*params(11)*T858*T866*(-T2066)));
  g1(54,44)=(-(params(22)*exp(y(44))*params(11)*T852*exp(T40*params(9))*T848*exp((1-params(14))*y(12))));
  g1(54,46)=(-(T46*T167*params(22)*exp(y(46))*params(11)*T852*T880+T46*(1-T167)*params(22)*exp(y(46))*params(11)*T858*T880+params(8)*params(22)*exp(y(46))*params(11)*T852*exp((1-params(14))*y(14))*exp(T40*params(9))*T848));
  g1(54,48)=(-(T46*T167*params(22)*exp(y(48))*params(11)*T852*T880+T46*(1-T167)*params(22)*exp(y(48))*params(11)*T858*T880+params(8)*params(22)*exp(y(48))*params(11)*T852*exp((1-params(14))*y(14))*exp(T40*params(9))*T848));
  g1(54,50)=(-(T278*params(22)*exp(y(50))*params(11)*T851*T852+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T858));
  g1(54,52)=(-(T354*params(22)*exp(y(52))*params(11)*T852*T866+T877));
  g1(54,56)=(-(T278*params(22)*exp(y(50))*params(11)*T852*T2574+(1-T278)*params(22)*exp(y(50))*params(11)*T858*T2574+T354*params(22)*exp(y(52))*params(11)*T852*exp((1-params(14))*y(18))*T2573+(1-T354)*params(22)*exp(y(52))*params(11)*T858*exp((1-params(14))*y(18))*T2573+T46*T167*params(22)*T627*params(11)*T852*exp((1-params(14))*y(14))*T2573+T46*(1-T167)*params(22)*T627*params(11)*T858*exp((1-params(14))*y(14))*T2573+params(8)*params(22)*T627*params(11)*T852*exp((1-params(14))*y(14))*exp(T40*params(9))*T2572+params(22)*exp(y(44))*params(11)*T852*exp((1-params(14))*y(12))*exp(T40*params(9))*T2572));
  g1(54,58)=(1-params(3))*exp(y(58)*(1-params(3)))-(T278*params(22)*exp(y(50))*params(11)*T851*T2784+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T1303*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))+T354*params(22)*exp(y(52))*params(11)*T866*T2784+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T1303*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))+T46*T167*params(22)*T627*params(11)*T880*T2784+T46*(1-T167)*params(22)*T627*params(11)*T880*T1303*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))+params(8)*params(22)*T627*params(11)*exp((1-params(14))*y(14))*exp(T40*params(9))*T848*T2784+params(22)*exp(y(44))*params(11)*exp(T40*params(9))*T848*exp((1-params(14))*y(12))*T2784);
  g1(54,60)=(-T2942);
  g1(54,80)=(-(T278*params(22)*exp(y(50))*params(11)*T852*exp((1-params(14))*y(16))*T49*T847*T40*exp(T40*y(80))+(1-T278)*params(22)*exp(y(50))*params(11)*T858*exp((1-params(14))*y(16))*T49*T847*T40*exp(T40*y(80))+T354*params(22)*exp(y(52))*params(11)*T852*exp((1-params(14))*y(18))*T49*T847*T40*exp(T40*y(80))+(1-T354)*params(22)*exp(y(52))*params(11)*T858*exp((1-params(14))*y(18))*T49*T847*T40*exp(T40*y(80))+T46*T167*params(22)*T627*params(11)*T852*exp((1-params(14))*y(14))*T49*T847*T40*exp(T40*y(80))+T46*(1-T167)*params(22)*T627*params(11)*T858*exp((1-params(14))*y(14))*T49*T847*T40*exp(T40*y(80))+params(8)*params(22)*T627*params(11)*T852*exp((1-params(14))*y(14))*exp(T40*params(9))*T847*T40*exp(T40*y(80))+params(22)*exp(y(44))*params(11)*T852*exp((1-params(14))*y(12))*exp(T40*params(9))*T847*T40*exp(T40*y(80))));
  g1(54,81)=(-T3385);
  g1(55,9)=(-(T46*(1-T57)*params(22)*T622*params(11)*T814*T1258+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T1258+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T1258));
  g1(55,10)=T1417;
  g1(55,13)=(-(T46*(1-T57)*params(22)*T622*params(11)*T792*T782*(1-params(14))*exp((1-params(14))*y(13))));
  g1(55,15)=(-((1-T237)*params(22)*exp(y(49))*params(11)*T792*T782*(1-params(14))*exp((1-params(14))*y(15))));
  g1(55,17)=(-((1-T316)*params(22)*exp(y(51))*params(11)*T792*T782*(1-params(14))*exp((1-params(14))*y(17))));
  g1(55,31)=(-(T46*params(22)*T622*params(11)*T792*T814*(-T1880)));
  g1(55,33)=(-(params(22)*exp(y(49))*params(11)*T784*T792*(-T1958)));
  g1(55,35)=(-(params(22)*exp(y(51))*params(11)*T792*T800*(-T2030)));
  g1(55,45)=(-(T46*(1-T57)*params(22)*exp(y(45))*params(11)*T792*T814));
  g1(55,47)=(-(T46*(1-T57)*params(22)*exp(y(47))*params(11)*T792*T814));
  g1(55,49)=(-((1-T237)*params(22)*exp(y(49))*params(11)*T784*T792));
  g1(55,51)=(-T811);
  g1(55,55)=(-(T46*(1-T57)*params(22)*T622*params(11)*T792*exp((1-params(14))*y(13))*T2457+(1-T237)*params(22)*exp(y(49))*params(11)*T792*T2458+(1-T316)*params(22)*exp(y(51))*params(11)*T792*exp((1-params(14))*y(17))*T2457));
  g1(55,57)=(-(T46*(1-T57)*params(22)*T622*params(11)*T814*T1257*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))+(1-T237)*params(22)*exp(y(49))*params(11)*T784*T1257*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))+(1-T316)*params(22)*exp(y(51))*params(11)*T800*T1257*T61*(params(3)-params(4))*exp((params(3)-params(4))*y(57)+y(9))));
  g1(55,59)=(1-params(3))*exp((1-params(3))*(y(81)+y(59)))-T2888;
  g1(55,79)=(-(T46*(1-T57)*params(22)*T622*params(11)*T792*exp((1-params(14))*y(13))*T49*T780*T40*exp(T40*y(79))+(1-T237)*params(22)*exp(y(49))*params(11)*T792*exp((1-params(14))*y(15))*T49*T780*T40*exp(T40*y(79))+(1-T316)*params(22)*exp(y(51))*params(11)*T792*exp((1-params(14))*y(17))*T49*T780*T40*exp(T40*y(79))));
  g1(55,81)=(1-params(3))*exp((1-params(3))*(y(81)+y(59)))-T3365;
  g1(56,9)=T1323;
  g1(56,10)=(-(T46*(1-T167)*params(22)*T627*params(11)*T880*T173*T1303+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T173*T1303+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T173*T1303));
  g1(56,14)=(-(T46*(1-T167)*params(22)*T627*params(11)*T858*T849*(1-params(14))*exp((1-params(14))*y(14))));
  g1(56,16)=(-((1-T278)*params(22)*exp(y(50))*params(11)*T858*T849*(1-params(14))*exp((1-params(14))*y(16))));
  g1(56,18)=(-((1-T354)*params(22)*exp(y(52))*params(11)*T858*T849*(1-params(14))*exp((1-params(14))*y(18))));
  g1(56,32)=(-(T46*params(22)*T627*params(11)*T858*T880*(-T1919)));
  g1(56,34)=(-(params(22)*exp(y(50))*params(11)*T851*T858*(-T1994)));
  g1(56,36)=(-(params(22)*exp(y(52))*params(11)*T858*T866*(-T2066)));
  g1(56,46)=(-(T46*(1-T167)*params(22)*exp(y(46))*params(11)*T858*T880));
  g1(56,48)=(-(T46*(1-T167)*params(22)*exp(y(48))*params(11)*T858*T880));
  g1(56,50)=(-((1-T278)*params(22)*exp(y(50))*params(11)*T851*T858));
  g1(56,52)=(-T877);
  g1(56,56)=(-(T46*(1-T167)*params(22)*T627*params(11)*T858*exp((1-params(14))*y(14))*T2573+(1-T278)*params(22)*exp(y(50))*params(11)*T858*T2574+(1-T354)*params(22)*exp(y(52))*params(11)*T858*exp((1-params(14))*y(18))*T2573));
  g1(56,58)=(-(T46*(1-T167)*params(22)*T627*params(11)*T880*T1303*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))+(1-T278)*params(22)*exp(y(50))*params(11)*T851*T1303*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))+(1-T354)*params(22)*exp(y(52))*params(11)*T866*T1303*T61*(params(3)-params(4))*exp(y(10)+(params(3)-params(4))*y(58))));
  g1(56,60)=(1-params(3))*exp((1-params(3))*(y(60)-y(81)))-T2942;
  g1(56,80)=(-(T46*(1-T167)*params(22)*T627*params(11)*T858*exp((1-params(14))*y(14))*T49*T847*T40*exp(T40*y(80))+(1-T278)*params(22)*exp(y(50))*params(11)*T858*exp((1-params(14))*y(16))*T49*T847*T40*exp(T40*y(80))+(1-T354)*params(22)*exp(y(52))*params(11)*T858*exp((1-params(14))*y(18))*T49*T847*T40*exp(T40*y(80))));
  g1(56,81)=exp((1-params(3))*(y(60)-y(81)))*(-(1-params(3)))-T3385;
  g1(57,57)=(-(T61*(1-params(4))*exp(y(57)*(1-params(4)))));
  g1(57,60)=(-(T74*(1-params(4))*exp(y(60)*(1-params(4)))));
  g1(58,58)=(-(T61*(1-params(4))*exp(y(58)*(1-params(4)))));
  g1(58,59)=(-(T74*(1-params(4))*exp(y(59)*(1-params(4)))));
  g1(59,3)=(-(T945*params(6)*(params(6)*(1-params(2))-1)*exp(y(3)*(params(6)*(1-params(2))-1))));
  g1(59,7)=(-(params(6)*exp(y(3)*(params(6)*(1-params(2))-1))*(-exp(y(7)))*getPowerDeriv(1-exp(y(7)),(1-params(6))*(1-params(2)),1)));
  g1(59,71)=exp(y(71));
  g1(60,4)=(-(T952*params(6)*(params(6)*(1-params(2))-1)*exp(y(4)*(params(6)*(1-params(2))-1))));
  g1(60,8)=(-(params(6)*exp(y(4)*(params(6)*(1-params(2))-1))*(-exp(y(8)))*getPowerDeriv(1-exp(y(8)),(1-params(6))*(1-params(2)),1)));
  g1(60,72)=exp(y(72));
  g1(61,29)=(-(T25*exp(y(55)+y(29))));
  g1(61,55)=(-(T25*exp(y(55)+y(29))));
  g1(61,69)=exp(y(69));
  g1(62,30)=(-(T25*exp(y(56)+y(30))));
  g1(62,56)=(-(T25*exp(y(56)+y(30))));
  g1(62,70)=exp(y(70));
  g1(63,1)=exp(y(1));
  g1(63,57)=exp(y(69)-y(57));
  g1(63,69)=(-exp(y(69)-y(57)));
  g1(64,2)=exp(y(2));
  g1(64,58)=exp(y(70)-y(58));
  g1(64,70)=(-exp(y(70)-y(58)));
  g1(65,3)=(-exp(y(3)));
  g1(65,5)=(-exp(y(5)));
  g1(65,9)=exp(y(9));
  g1(66,4)=(-exp(y(4)));
  g1(66,6)=(-exp(y(6)));
  g1(66,10)=exp(y(10));
  g1(67,5)=exp(y(5));
  g1(67,19)=(-(exp(y(19))-(1-params(12)*params(11))*exp(y(19))));
  g1(68,6)=exp(y(6));
  g1(68,20)=(-(exp(y(20))-(1-params(12)*params(11))*exp(y(20))));
  g1(69,10)=(-1);
  g1(69,59)=(-(1-params(4)));
  g1(69,81)=(-1);
  g1(69,83)=1;
  g1(70,9)=(-1);
  g1(70,60)=(-(1-params(4)));
  g1(70,84)=1;
  g1(71,69)=(-((-(exp(y(69))*(exp(y(83))-exp(y(84)))))/(exp(y(69))*exp(y(69)))));
  g1(71,82)=1;
  g1(71,83)=(-(exp(y(83))/exp(y(69))));
  g1(71,84)=(-((-exp(y(84)))/exp(y(69))));
  g1(72,71)=1;
  g1(72,72)=(-1);
  g1(72,81)=1;
  g1(73,59)=1;
  g1(73,81)=1;
  g1(73,83)=(-1);
  g1(73,85)=1;
  g1(74,60)=1;
  g1(74,84)=(-1);
  g1(74,86)=1;
  g1(75,79)=1-params(18);
  g1(76,80)=1-params(18);
  g1(77,37)=(-(T622*T46*params(11)*(-exp(y(37)))/(params(11)*(T622+exp(y(49))))));
  g1(77,39)=(-(params(11)*exp(y(49))*(-exp(y(39)))/(params(11)*(T622+exp(y(49))))));
  g1(77,45)=(-((params(11)*(T622+exp(y(49)))*(1-exp(y(37)))*exp(y(45))*T46*params(11)-T659*params(11)*exp(y(45)))/(params(11)*(T622+exp(y(49)))*params(11)*(T622+exp(y(49))))));
  g1(77,47)=(-((params(11)*(T622+exp(y(49)))*(1-exp(y(37)))*exp(y(47))*T46*params(11)-T659*params(11)*exp(y(47)))/(params(11)*(T622+exp(y(49)))*params(11)*(T622+exp(y(49))))));
  g1(77,49)=(-(((1-exp(y(39)))*params(11)*exp(y(49))*params(11)*(T622+exp(y(49)))-params(11)*exp(y(49))*T659)/(params(11)*(T622+exp(y(49)))*params(11)*(T622+exp(y(49))))));
  g1(77,77)=exp(y(77));
  g1(78,38)=(-(T627*T46*params(11)*(-exp(y(38)))/(params(11)*(T627+exp(y(50))))));
  g1(78,40)=(-(params(11)*exp(y(50))*(-exp(y(40)))/(params(11)*(T627+exp(y(50))))));
  g1(78,46)=(-((params(11)*(T627+exp(y(50)))*(1-exp(y(38)))*exp(y(46))*T46*params(11)-T665*params(11)*exp(y(46)))/(params(11)*(T627+exp(y(50)))*params(11)*(T627+exp(y(50))))));
  g1(78,48)=(-((params(11)*(T627+exp(y(50)))*(1-exp(y(38)))*exp(y(48))*T46*params(11)-T665*params(11)*exp(y(48)))/(params(11)*(T627+exp(y(50)))*params(11)*(T627+exp(y(50))))));
  g1(78,50)=(-(((1-exp(y(40)))*params(11)*exp(y(50))*params(11)*(T627+exp(y(50)))-params(11)*exp(y(50))*T665)/(params(11)*(T627+exp(y(50)))*params(11)*(T627+exp(y(50))))));
  g1(78,78)=exp(y(78));
  g1(79,41)=(-1);
  g1(79,75)=1;
  g1(80,42)=(-1);
  g1(80,76)=1;
  g1(81,11)=(-exp(y(11)+y(43)));
  g1(81,13)=(-(exp(y(13)+y(45))+exp(y(13)+y(47))));
  g1(81,15)=(-exp(y(15)+y(49)));
  g1(81,17)=(-exp(y(17)+y(51)));
  g1(81,19)=exp(y(19));
  g1(81,43)=(-exp(y(11)+y(43)));
  g1(81,45)=(-exp(y(13)+y(45)));
  g1(81,47)=(-exp(y(13)+y(47)));
  g1(81,49)=(-exp(y(15)+y(49)));
  g1(81,51)=(-exp(y(17)+y(51)));
  g1(82,12)=(-exp(y(12)+y(44)));
  g1(82,14)=(-(exp(y(14)+y(46))+exp(y(14)+y(48))));
  g1(82,16)=(-exp(y(16)+y(50)));
  g1(82,18)=(-exp(y(18)+y(52)));
  g1(82,20)=exp(y(20));
  g1(82,44)=(-exp(y(12)+y(44)));
  g1(82,46)=(-exp(y(14)+y(46)));
  g1(82,48)=(-exp(y(14)+y(48)));
  g1(82,50)=(-exp(y(16)+y(50)));
  g1(82,52)=(-exp(y(18)+y(52)));
  g1(83,11)=(-((-exp(y(11)))+T105*exp(y(11))));
  g1(83,55)=exp(y(55)-y(79))*params(19);
  g1(83,61)=(-(params(11)*params(1)*exp(y(61))));
  g1(83,79)=params(19)*(-exp(y(55)-y(79)));
  g1(84,12)=(-((-exp(y(12)))+T105*exp(y(12))));
  g1(84,56)=params(19)*exp(y(56)-y(80));
  g1(84,62)=(-(params(11)*params(1)*exp(y(62))));
  g1(84,80)=params(19)*(-exp(y(56)-y(80)));
  g1(85,7)=exp(y(7));
  g1(85,29)=(-exp(y(29)));
  g1(85,38)=(-(T627*T46*params(11)*params(20)*exp((-y(80)))*(-exp(y(38)))));
  g1(85,40)=(-(exp(y(50))*params(11)*params(20)*exp((-y(80)))*(-exp(y(40)))));
  g1(85,42)=(-(exp(y(52))*params(11)*params(21)*exp((-y(80)))*(-exp(y(42)))));
  g1(85,43)=(-(exp(y(43))*params(19)*exp((-y(79)))));
  g1(85,46)=(-((1-exp(y(38)))*exp(y(46))*T46*params(11)*params(20)*exp((-y(80)))));
  g1(85,48)=(-((1-exp(y(38)))*exp(y(48))*T46*params(11)*params(20)*exp((-y(80)))));
  g1(85,50)=(-((1-exp(y(40)))*exp(y(50))*params(11)*params(20)*exp((-y(80)))));
  g1(85,52)=(-((1-exp(y(42)))*exp(y(52))*params(11)*params(21)*exp((-y(80)))));
  g1(85,79)=(-(exp(y(43))*params(19)*(-exp((-y(79))))));
  g1(85,80)=(-((1-exp(y(38)))*T627*T46*params(11)*params(20)*(-exp((-y(80))))+(1-exp(y(40)))*exp(y(50))*params(11)*params(20)*(-exp((-y(80))))+(1-exp(y(42)))*exp(y(52))*params(11)*params(21)*(-exp((-y(80))))));
  g1(86,8)=exp(y(8));
  g1(86,30)=(-exp(y(30)));
  g1(86,37)=(-(T622*T46*params(11)*params(20)*exp((-y(79)))*(-exp(y(37)))));
  g1(86,39)=(-(exp(y(49))*params(11)*params(20)*exp((-y(79)))*(-exp(y(39)))));
  g1(86,41)=(-(exp(y(51))*params(11)*params(21)*exp((-y(79)))*(-exp(y(41)))));
  g1(86,44)=(-(exp(y(44))*params(19)*exp((-y(80)))));
  g1(86,45)=(-((1-exp(y(37)))*exp(y(45))*T46*params(11)*params(20)*exp((-y(79)))));
  g1(86,47)=(-((1-exp(y(37)))*exp(y(47))*T46*params(11)*params(20)*exp((-y(79)))));
  g1(86,49)=(-((1-exp(y(39)))*exp(y(49))*params(11)*params(20)*exp((-y(79)))));
  g1(86,51)=(-((1-exp(y(41)))*exp(y(51))*params(11)*params(21)*exp((-y(79)))));
  g1(86,79)=(-((1-exp(y(37)))*T622*T46*params(11)*params(20)*(-exp((-y(79))))+(1-exp(y(39)))*exp(y(49))*params(11)*params(20)*(-exp((-y(79))))+(1-exp(y(41)))*exp(y(51))*params(11)*params(21)*(-exp((-y(79))))));
  g1(86,80)=(-(exp(y(44))*params(19)*(-exp((-y(80))))));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],86,7396);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],86,636056);
end
end
end
end
